/*     */ package com.netapp.asup.data.function.aggregation;
/*     */ 
/*     */ import com.netapp.asup.client.arma.data.ARMAObjectInstance;
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import com.netapp.asup.data.function.FunctionRegistry;
/*     */ import com.netapp.asup.data.function.InputType;
/*     */ import com.netapp.asup.data.function.RegisteredFunction;
/*     */ import com.netapp.asup.data.function.handler.StringOutputHandler;
/*     */ import com.netapp.asup.data.store.BaseContainer;
/*     */ import com.netapp.asup.exception.ARMAException;
/*     */ import java.util.Map;
/*     */ import org.apache.avro.generic.GenericArray;
/*     */ import org.apache.avro.generic.GenericRecord;
/*     */ import org.apache.avro.util.Utf8;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class Aggregator<T>
/*     */ {
/*     */   public static <E> Aggregator<E> getAggregator(GenericRecord aggregationField)
/*     */     throws ARMAException
/*     */   {
/*  29 */     AggregationType aggregationType = AggregationType.getAggregationType(aggregationField.get("aggregationFunction").toString());
/*  30 */     if (aggregationType == AggregationType.CONCAT) {
/*  31 */       return new ConcatFieldAggregator(aggregationType, aggregationField, getAggregator(aggregationType, aggregationField));
/*     */     }
/*  33 */     return getAggregator(aggregationType, aggregationField);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private static <E> Aggregator<E> getAggregator(AggregationType aggregationType, GenericRecord aggregationField)
/*     */     throws ARMAException
/*     */   {
/*  47 */     InputType aggregatorType = InputType.getInputType(aggregationField.get("aggregatorType").toString());
/*  48 */     switch (aggregatorType) {
/*     */     case FIELD: 
/*  50 */       return new FieldAggregator(aggregationType, aggregationField);
/*     */     case EXPRESSION: 
/*  52 */       return new ExpressionAggregator(aggregationType, aggregationField);
/*     */     case FUNCTION: 
/*  54 */       return new FunctionAggregator(aggregationType, aggregationField);
/*     */     }
/*  56 */     throw new ARMAException(logger, aggregationType.getName(), "Invalid aggregator type :" + aggregatorType.getName());
/*     */   }
/*     */   
/*     */ 
/*  60 */   protected static final AsupLogger logger = AsupLogger.getLogger(AggregateFunction.class);
/*     */   
/*  62 */   private static FunctionRegistry registory = BaseContainer.getInstance().getFunctionRegistry();
/*     */   
/*     */   protected T result;
/*     */   
/*     */   protected final AggregationType type;
/*     */   
/*     */   protected final String[] attributes;
/*     */   
/*     */   protected final Class<?>[] attributeTypes;
/*     */   protected final String expression;
/*     */   protected final Map<Utf8, Utf8> options;
/*     */   protected final RegisteredFunction<Map<Utf8, Utf8>, String> customFunction;
/*     */   
/*     */   Aggregator(AggregationType type, GenericRecord aggregationField)
/*     */     throws ARMAException
/*     */   {
/*  78 */     this.type = type;
/*  79 */     this.result = type.getObjectAggregationFunction().initializeResult();
/*  80 */     GenericArray<Utf8> attributes = (GenericArray)aggregationField.get("attributes");
/*  81 */     GenericArray<Utf8> attributeTypes = (GenericArray)aggregationField.get("attributeTypes");
/*  82 */     this.attributes = new String[attributes.size()];
/*  83 */     this.attributeTypes = new Class[attributeTypes.size()];
/*  84 */     for (int index = 0; index < attributes.size(); index++) {
/*  85 */       this.attributes[index] = ((Utf8)attributes.get(index)).toString();
/*  86 */       if (attributeTypes.size() > 0) {
/*     */         try {
/*  88 */           this.attributeTypes[index] = Class.forName(((Utf8)attributeTypes.get(index)).toString());
/*     */         } catch (ClassNotFoundException e) {
/*  90 */           throw new ARMAException(logger, this.type.getName(), "Class not found :" + ((Utf8)attributeTypes.get(index)).toString());
/*     */         }
/*     */       }
/*     */     }
/*  94 */     Utf8 expression = (Utf8)aggregationField.get("expression");
/*  95 */     if (expression != null) {
/*  96 */       this.expression = expression.toString();
/*     */     } else {
/*  98 */       this.expression = null;
/*     */     }
/* 100 */     this.options = ((Map)aggregationField.get("options"));
/* 101 */     Utf8 customFunction = (Utf8)aggregationField.get("customFunction");
/* 102 */     if (customFunction != null) {
/* 103 */       RegisteredFunction<Map<Utf8, Utf8>, String> registeredFunction = registory.getRegisteredFunction(customFunction.toString());
/* 104 */       if (registeredFunction != null)
/*     */       {
/* 106 */         if ((registeredFunction.getOutputHandler() != null) && ((registeredFunction.getOutputHandler() instanceof StringOutputHandler))) {
/* 107 */           this.customFunction = registeredFunction;
/*     */         } else {
/* 109 */           throw new ARMAException(logger, this.type.getName(), "Invalid function :" + customFunction + " its doesn't have a string output handler");
/*     */         }
/*     */       } else {
/* 112 */         throw new ARMAException(logger, this.type.getName(), "Function not registered :" + customFunction);
/*     */       }
/*     */     } else {
/* 115 */       this.customFunction = null;
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   protected void compute(String value)
/*     */   {
/* 123 */     if (value != null) {
/* 124 */       this.result = this.type.getInstanceAggregationFunction().compute(this.result, value);
/*     */     }
/*     */   }
/*     */   
/*     */   public abstract void compute(ARMAObjectInstance paramARMAObjectInstance) throws ARMAException;
/*     */   
/*     */   public String getResult() {
/* 131 */     return this.type.getObjectAggregationFunction().compute(this.result);
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\data\function\aggregation\Aggregator.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */