/*    */ package com.netapp.asup.data.function.filter;
/*    */ 
/*    */ import com.netapp.asup.client.arma.data.ARMAObjectInstance;
/*    */ import com.netapp.asup.common.AsupLogger;
/*    */ import com.netapp.asup.data.function.TypeConverter;
/*    */ import com.netapp.asup.data.function.aggregation.ExpressionAggregator.Converter;
/*    */ import com.netapp.asup.exception.ARMAException;
/*    */ import java.lang.reflect.InvocationTargetException;
/*    */ import java.util.Map;
/*    */ import org.apache.avro.generic.GenericData.Array;
/*    */ import org.apache.avro.generic.GenericRecord;
/*    */ import org.apache.avro.util.Utf8;
/*    */ import org.codehaus.commons.compiler.CompileException;
/*    */ import org.codehaus.janino.ExpressionEvaluator;
/*    */ 
/*    */ public class ExpressionFilterExecutor
/*    */   extends FilterExecutor
/*    */ {
/*    */   private String expression;
/*    */   private String expressionAttrName;
/*    */   private String[] paramNames;
/*    */   private Class<?>[] paramTypes;
/* 23 */   private ExpressionEvaluator eval = null;
/*    */   
/* 25 */   private static final AsupLogger LOGGER = AsupLogger.getLogger(ExpressionFilterExecutor.class);
/*    */   
/*    */ 
/*    */ 
/*    */   public ExpressionFilterExecutor(GenericRecord filterGR)
/*    */     throws ARMAException
/*    */   {
/* 32 */     this.expression = filterGR.get("expression").toString();
/* 33 */     this.expressionAttrName = filterGR.get("attributeName").toString();
/*    */     
/* 35 */     GenericData.Array<Utf8> attrs = (GenericData.Array)filterGR.get("attributes");
/*    */     
/* 37 */     GenericData.Array<Utf8> attrTypes = (GenericData.Array)filterGR.get("attributeTypes");
/*    */     
/*    */ 
/* 40 */     this.paramNames = new String[attrs.size()];
/* 41 */     this.paramTypes = new Class[attrTypes.size()];
/*    */     
/* 43 */     for (int i = 0; i < attrs.size(); i++) {
/* 44 */       this.paramNames[i] = ((Utf8)attrs.get(i)).toString();
/*    */       try {
/* 46 */         this.paramTypes[i] = Class.forName(((Utf8)attrTypes.get(i)).toString());
/*    */       } catch (ClassNotFoundException e) {
/* 48 */         throw new ARMAException(LOGGER, null, "unable to load class " + ((Utf8)attrTypes.get(i)).toString() + " during a expression filter computation..");
/*    */       }
/*    */     }
/*    */     
/*    */ 
/*    */     try
/*    */     {
/* 55 */       this.eval = new ExpressionEvaluator(this.expression, Object.class, this.paramNames, this.paramTypes);
/*    */     }
/*    */     catch (CompileException e) {
/* 58 */       throw new ARMAException(LOGGER, null, "Invalid expression caused by :" + e.getCause(), e);
/*    */     }
/*    */   }
/*    */   
/*    */ 
/*    */   boolean match(ARMAObjectInstance instance)
/*    */     throws ARMAException
/*    */   {
/* 66 */     Object[] arguments = new Object[this.paramNames.length];
/* 67 */     String filterValue = null;
/* 68 */     String attributeValue = null;
/*    */     
/*    */ 
/* 71 */     for (int index = 0; index < this.paramNames.length; index++) {
/* 72 */       attributeValue = instance.getAllAttribute(this.paramNames[index]);
/* 73 */       if (attributeValue == null) {
/* 74 */         LOGGER.warn(instance.getKey().toString(), "Attribute : " + this.paramNames[index] + " has null value");
/*    */         
/* 76 */         return false;
/*    */       }
/* 78 */       arguments[index] = ((ExpressionAggregator.Converter)TypeConverter.getConvertorclassmap().get(this.paramTypes[index])).convert(attributeValue);
/*    */     }
/*    */     Object result;
/*    */     try
/*    */     {
/* 83 */       result = this.eval.evaluate(arguments);
/*    */     } catch (InvocationTargetException e) {
/* 85 */       throw new ARMAException(LOGGER, this.expression, "Error in execution of expression :" + e.getCause(), e);
/*    */     }
/*    */     
/*    */ 
/* 89 */     if (result != null) {
/* 90 */       filterValue = result.toString();
/* 91 */       return filterValue.equals(instance.getAllAttribute(this.expressionAttrName));
/*    */     }
/*    */     
/*    */ 
/* 95 */     return false;
/*    */   }
/*    */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\data\function\filter\ExpressionFilterExecutor.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */