/*     */ package com.netapp.asupdata.client.ARMA;
/*     */ 
/*     */ import com.netapp.asup.client.arma.ARMAObject;
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import com.netapp.asup.data.function.RegisteredFunction;
/*     */ import com.netapp.asup.data.objects.AvroObject;
/*     */ import com.netapp.asup.data.objects.Filter;
/*     */ import com.netapp.asup.data.objects.FunctionData;
/*     */ import com.netapp.asup.data.objects.Functions;
/*     */ import com.netapp.asup.data.objects.Identifier;
/*     */ import com.netapp.asup.data.objects.LogEventData;
/*     */ import com.netapp.asup.data.objects.LogEvents;
/*     */ import com.netapp.asup.data.objects.ObjectData;
/*     */ import com.netapp.asup.data.objects.ObjectRequest;
/*     */ import com.netapp.asup.data.objects.Objects;
/*     */ import com.netapp.asup.data.objects.ObjectsRequest;
/*     */ import com.netapp.asup.data.objects.OptionData;
/*     */ import com.netapp.asup.data.objects.Options;
/*     */ import com.netapp.asup.data.objects.Path;
/*     */ import com.netapp.asup.data.objects.PerfCounters;
/*     */ import com.netapp.asup.data.objects.Request;
/*     */ import com.netapp.asup.data.objects.Response;
/*     */ import com.netapp.asup.data.objects.Response.ResponseField;
/*     */ import com.netapp.asup.data.store.BaseContainer;
/*     */ import com.netapp.asup.data.store.DataStore;
/*     */ import com.netapp.asup.data.store.StoreContainer;
/*     */ import com.netapp.asup.exception.ARMADataStoreException;
/*     */ import com.netapp.asup.exception.ARMAException;
/*     */ import com.netapp.asup.exception.ARMAIllegalArgumentException;
/*     */ import com.netapp.asup.metamodel.NodeObject;
/*     */ import com.netapp.asupdata.client.ARMA.utils.IdentifierUtils;
/*     */ import java.io.IOException;
/*     */ import java.util.HashMap;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.Set;
/*     */ import org.apache.avro.generic.GenericRecord;
/*     */ import org.apache.avro.util.Utf8;
/*     */ 
/*     */ 
/*     */ 
/*     */ public class ARMAClientSession
/*     */ {
/*     */   private static final String SYSTEM = "system";
/*     */   private static final String CLUSTER = "cluster";
/*  46 */   private final Map<Response.ResponseField, AvroObject<?>> sessionObjectMap = new HashMap();
/*     */   
/*  48 */   private final DataStore dataStore = BaseContainer.getInstance().getStoreContainer().getStore();
/*     */   
/*     */   private final ARMAObject rootObject;
/*     */   
/*     */   private final Filter filter;
/*     */   
/*     */   private final Path path;
/*  55 */   private final ARMAPathTracer tracer = new ARMAPathTracer();
/*     */   
/*     */   private final Identifier id;
/*     */   
/*     */   private Request request;
/*  60 */   private final ARMAObjectStore objectStore = new ARMAObjectStore();
/*     */   
/*  62 */   private boolean isClusterRoot = false;
/*     */   
/*  64 */   protected static final AsupLogger LOG = AsupLogger.getLogger(ARMAClientSession.class);
/*     */   
/*     */   public ARMAClientSession(Identifier id) throws ARMADataStoreException
/*     */   {
/*  68 */     this.id = id;
/*  69 */     this.isClusterRoot = Boolean.valueOf(id.getClusterRoot()).booleanValue();
/*     */     
/*  71 */     Identifier enhancedId = this.dataStore.getMetaData(id);
/*  72 */     String asupType = enhancedId.getAsupType();
/*  73 */     String sysVersion = enhancedId.getSysVersion();
/*  74 */     NodeObject nodeObj = this.dataStore.getMetaModel(sysVersion, asupType);
/*     */     
/*  76 */     if ((!this.isClusterRoot) && (nodeObj.getObjectName().equals("cluster"))) {
/*  77 */       nodeObj = nodeObj.getChildByName("system");
/*     */     }
/*  79 */     this.filter = new Filter(id);
/*  80 */     this.path = new Path(id);
/*  81 */     this.request = Request.initialize(id);
/*     */     
/*  83 */     this.rootObject = new ARMAObjectImpl(this, null, nodeObj, NodeType.Root);
/*  84 */     this.objectStore.addToStore(this.rootObject.getObjectName(), this.rootObject);
/*     */   }
/*     */   
/*     */ 
/*     */   public ARMAObject getRoot()
/*     */   {
/*  90 */     clearAll();
/*  91 */     return this.rootObject;
/*     */   }
/*     */   
/*     */   public ARMAObjectImpl getRootObject() {
/*  95 */     return (ARMAObjectImpl)this.rootObject;
/*     */   }
/*     */   
/*     */   public ARMAObjectStore getObjectStore() {
/*  99 */     return this.objectStore;
/*     */   }
/*     */   
/*     */   public String getRequestId() {
/* 103 */     return getRequest().getId();
/*     */   }
/*     */   
/*     */   public boolean removeAllFilterForPath() {
/* 107 */     return this.filter.clearFilters();
/*     */   }
/*     */   
/*     */   public Identifier getIdentifier() {
/* 111 */     return this.id;
/*     */   }
/*     */   
/*     */   private Request buildRequest(String... objectNames) throws ARMADataStoreException
/*     */   {
/* 116 */     this.filter.setFilterToIdentifier();
/* 117 */     this.path.setPathToIdentifier();
/*     */     
/* 119 */     for (String inputObject : objectNames) {
/* 120 */       addObjectToRequest(inputObject);
/*     */     }
/* 122 */     return this.request;
/*     */   }
/*     */   
/*     */   public void getData(String... objectNames) throws ARMAException
/*     */   {
/* 127 */     Request request = buildRequest(objectNames);
/* 128 */     ObjectsRequest requestObjects = getRequest().getRequestObject();
/* 129 */     List<Utf8> objects = requestObjects.getObjects();
/* 130 */     if ((null != objects) && (!objects.isEmpty())) {
/* 131 */       this.request = null;
/* 132 */       Response response = this.dataStore.getData(request);
/* 133 */       mergeToSession(response);
/*     */     }
/*     */     else {
/* 136 */       LOG.warn(this.id.getId(), "Get Data Call: No objects are being requested to be fetched!:" + objects);
/*     */     }
/*     */   }
/*     */   
/*     */   public void populateResponse(Response response) {
/* 141 */     this.sessionObjectMap.put(Response.ResponseField.OPTIONS, response.getField(Response.ResponseField.OPTIONS));
/*     */     
/* 143 */     this.sessionObjectMap.put(Response.ResponseField.OBJECTS, response.getField(Response.ResponseField.OBJECTS));
/*     */     
/* 145 */     this.sessionObjectMap.put(Response.ResponseField.PERFCOUNTERS, response.getField(Response.ResponseField.PERFCOUNTERS));
/* 146 */     this.sessionObjectMap.put(Response.ResponseField.LOGEVENTS, response.getField(Response.ResponseField.LOGEVENTS));
/*     */   }
/*     */   
/*     */   public ObjectData getObject(String objectName, NodeObject parentNodeObject)
/*     */     throws ARMAException
/*     */   {
/* 152 */     Identifier id = this.filter.setFilterToIdentifier();
/* 153 */     this.path.setPathToIdentifier();
/* 154 */     Response response = this.dataStore.getObject(id, objectName.toUpperCase(), parentNodeObject);
/*     */     
/* 156 */     ObjectData objectData = null;
/*     */     try
/*     */     {
/* 159 */       mergeToSession(response);
/*     */       
/* 161 */       objectData = response.getObjects().getObjectData(new Utf8(objectName.toUpperCase()));
/*     */     }
/*     */     catch (IOException e1) {
/* 164 */       throw new ARMADataStoreException(LOG, id.getId(), "Excetpion caused in retreiving data for object :" + objectName + " caused by :" + e1.getMessage(), e1);
/*     */     }
/*     */     
/*     */ 
/* 168 */     return objectData;
/*     */   }
/*     */   
/*     */   public ObjectData getObject(String objectName) throws ARMAException {
/* 172 */     Objects objects = (Objects)this.sessionObjectMap.get(Response.ResponseField.OBJECTS);
/*     */     
/*     */ 
/* 175 */     Utf8 objectNameInUTF = new Utf8(objectName.toUpperCase());
/*     */     
/* 177 */     ObjectData objectData = null;
/*     */     try {
/* 179 */       if ((null != objects) && 
/* 180 */         (objects.getObjectSet().contains(objectNameInUTF))) {
/* 181 */         objectData = objects.getObjectData(objectNameInUTF);
/*     */       }
/*     */       
/* 184 */       if (objectData != null) {
/* 185 */         return objectData;
/*     */       }
/* 187 */       Identifier id = this.filter.setFilterToIdentifier();
/* 188 */       this.path.setPathToIdentifier();
/*     */       
/* 190 */       Response response = this.dataStore.getObject(id, objectName, ObjectRequest.initialize(id.getId(), objectNameInUTF.toString()));
/*     */       
/*     */ 
/* 193 */       mergeToSession(response);
/*     */       
/* 195 */       return response.getObjects().getObjectData(objectNameInUTF);
/*     */ 
/*     */     }
/*     */     catch (IOException e)
/*     */     {
/*     */ 
/* 201 */       throw new ARMAException(LOG, getRequestId(), "Error in getting object data caused by :" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void mergeToSession(Response response)
/*     */     throws ARMAException
/*     */   {
/* 212 */     Response.ResponseField[] values = Response.ResponseField.values();
/*     */     try
/*     */     {
/* 215 */       for (Response.ResponseField filedName : values)
/*     */       {
/* 217 */         AvroObject<?> value = response.getField(filedName);
/*     */         
/* 219 */         AvroObject<?> existingField = (AvroObject)this.sessionObjectMap.get(filedName);
/*     */         
/* 221 */         if (null == existingField) {
/* 222 */           this.sessionObjectMap.put(filedName, value);
/*     */         } else {
/* 224 */           value.merge(existingField);
/*     */         }
/*     */       }
/*     */     } catch (IOException e) {
/* 228 */       throw new ARMAException(LOG, getRequestId(), "Error in merging the response data caused by :" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public Filter getFilter()
/*     */   {
/* 237 */     return this.filter;
/*     */   }
/*     */   
/*     */   public Path getPath() {
/* 241 */     return this.path;
/*     */   }
/*     */   
/*     */   public Request getRequest() {
/* 245 */     if (this.request != null) {
/* 246 */       return this.request;
/*     */     }
/* 248 */     this.request = Request.initialize(this.id);
/* 249 */     return this.request;
/*     */   }
/*     */   
/*     */   public Map<Utf8, GenericRecord> getOptions(String objectName, Utf8 optionGroupId)
/*     */     throws ARMAException
/*     */   {
/* 255 */     Options options = (Options)this.sessionObjectMap.get(Response.ResponseField.OPTIONS);
/*     */     
/* 257 */     String objectNameUpper = objectName.toUpperCase();
/* 258 */     Map<Utf8, GenericRecord> optionsMap = null;
/* 259 */     OptionData optionData = null;
/*     */     try {
/* 261 */       if (null != options) {
/* 262 */         optionData = options.getOptionData(optionGroupId);
/* 263 */         if (null != optionData) {
/* 264 */           optionsMap = optionData.getOptionNameValueMap();
/* 265 */           if (null != optionsMap) {
/* 266 */             return optionsMap;
/*     */           }
/*     */         }
/*     */       }
/* 270 */       Identifier id = this.filter.setFilterToIdentifier();
/*     */       
/* 272 */       ObjectRequest objReq = ObjectRequest.initialize(id.getId(), objectNameUpper);
/* 273 */       objReq.getALLOptions();
/*     */       
/* 275 */       Response response = this.dataStore.getObject(id, objectNameUpper, objReq);
/*     */       
/*     */ 
/* 278 */       mergeToSession(response);
/*     */       
/*     */ 
/* 281 */       options = response.getOptions();
/* 282 */       if (options != null) optionData = options.getOptionData(optionGroupId);
/* 283 */       if (optionData != null) {} return optionData.getOptionNameValueMap();
/*     */     }
/*     */     catch (IOException e)
/*     */     {
/* 287 */       throw new ARMAException(LOG, getRequestId(), "Error in getting option data caused by :" + e.getMessage(), e);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public <I, O> FunctionData getFunctionData(String objectName, String identifier, RegisteredFunction<I, O> registeredFunction)
/*     */     throws ARMAException
/*     */   {
/* 299 */     String uniqueFunctionIdentifier = IdentifierUtils.getUniqueFunctionIdentifier(objectName, identifier, registeredFunction.getFunctionName());
/*     */     
/*     */ 
/* 302 */     Functions functions = (Functions)this.sessionObjectMap.get(Response.ResponseField.FUNCTIONS);
/*     */     
/*     */ 
/* 305 */     FunctionData funcData = null;
/*     */     
/* 307 */     if (null != functions) {
/* 308 */       funcData = functions.getFunctionData(registeredFunction, new Utf8(uniqueFunctionIdentifier));
/*     */     }
/*     */     
/*     */ 
/* 312 */     if (null == funcData) {
/* 313 */       getData(new String[] { objectName });
/* 314 */       functions = (Functions)this.sessionObjectMap.get(Response.ResponseField.FUNCTIONS);
/*     */       
/* 316 */       funcData = functions.getFunctionData(registeredFunction, new Utf8(uniqueFunctionIdentifier));
/*     */     }
/*     */     
/*     */ 
/* 320 */     if (null == funcData) {
/* 321 */       throw new ARMAIllegalArgumentException(LOG, getRequestId(), "Function data not found :" + registeredFunction);
/*     */     }
/*     */     
/* 324 */     return funcData;
/*     */   }
/*     */   
/*     */   public void updateMyPath(ARMAObjectImpl myPrevious, NodeType nodeType) {
/* 328 */     traceMyPath(this.rootObject, myPrevious, nodeType);
/*     */   }
/*     */   
/*     */   public void traceMyPath(ARMAObject currentARMAObj, ARMAObject previousARMAObject, NodeType nodeType)
/*     */   {
/* 333 */     this.tracer.tracePath(currentARMAObj, previousARMAObject, nodeType);
/*     */   }
/*     */   
/*     */   public void addOptions(String objectName) {
/* 337 */     ObjectRequest reqObject = addObjectToRequest(objectName);
/* 338 */     reqObject.getALLOptions();
/*     */   }
/*     */   
/*     */   public void addLogEvents(String objectName, int intervalInDays, boolean addBizKeyToTags, String... eventNames) {
/* 342 */     ObjectRequest reqObject = addObjectToRequest(objectName);
/* 343 */     reqObject.addLogEventData(intervalInDays, addBizKeyToTags, eventNames);
/*     */   }
/*     */   
/*     */   public void addPerfCounters(String objectName, int intervalInDays, String... counterObjectNames) {
/* 347 */     ObjectRequest objectRequest = addObjectToRequest(objectName);
/* 348 */     String[] counterObjectNamesUpper = new String[counterObjectNames.length];
/* 349 */     for (int i = 0; i < counterObjectNames.length; i++)
/*     */     {
/* 351 */       counterObjectNamesUpper[i] = counterObjectNames[i].toUpperCase();
/*     */     }
/* 353 */     objectRequest.addPerfCounterData(intervalInDays, counterObjectNamesUpper);
/*     */   }
/*     */   
/*     */   public ObjectRequest addObjectToRequest(String objectName) {
/* 357 */     Utf8 objectNameInUpper = new Utf8(objectName.toUpperCase());
/* 358 */     ObjectsRequest requestObjects = getRequest().getRequestObject();
/* 359 */     ObjectRequest reqObject = null;
/* 360 */     if (requestObjects.getObjects().contains(objectNameInUpper)) {
/* 361 */       reqObject = requestObjects.getRequestObject(objectNameInUpper);
/*     */     } else {
/* 363 */       reqObject = ObjectRequest.initialize(this.request.getId(), objectNameInUpper.toString());
/* 364 */       requestObjects.addRequestObject(objectNameInUpper, reqObject);
/*     */     }
/* 366 */     return reqObject;
/*     */   }
/*     */   
/*     */   public boolean isClusterRoot() {
/* 370 */     return this.isClusterRoot;
/*     */   }
/*     */   
/*     */   public void clearAll()
/*     */   {
/* 375 */     this.filter.clearFilters();
/* 376 */     this.objectStore.clear();
/*     */     
/*     */ 
/* 379 */     this.objectStore.addToStore(this.rootObject.getObjectName(), this.rootObject);
/*     */     
/*     */ 
/* 382 */     this.path.clear();
/*     */     
/*     */ 
/* 385 */     traceMyPath(this.rootObject, null, NodeType.Root);
/*     */     
/* 387 */     clearSessionData();
/*     */   }
/*     */   
/*     */   public void clearSessionData() {
/* 391 */     this.sessionObjectMap.clear();
/*     */   }
/*     */   
/*     */   public void addDerivedAttribute(String objectName, Utf8 uniqueKey, String derAttrName, String derAttrValue) throws ARMAException
/*     */   {
/*     */     try
/*     */     {
/* 398 */       ObjectData object = getObject(objectName);
/*     */       
/* 400 */       object.addDerivedAttribute(uniqueKey, new Utf8(derAttrName), new Utf8(derAttrValue));
/*     */ 
/*     */     }
/*     */     catch (ARMAException e)
/*     */     {
/* 405 */       StringBuilder msg = new StringBuilder("Error in adding the derived attribute for the object:");
/*     */       
/* 407 */       msg.append(objectName);
/* 408 */       msg.append(",Derived attribute name:");
/* 409 */       msg.append(derAttrName);
/* 410 */       msg.append(",Derived attribute value:");
/* 411 */       msg.append(derAttrValue);
/*     */       
/* 413 */       throw new ARMAException(LOG, getRequestId(), msg.toString(), e);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   public String getDerivedAttribute(String objectName, Utf8 instanceKey, String derAttrName)
/*     */     throws ARMAException
/*     */   {
/* 421 */     Map<Utf8, Utf8> derivedAttrs = getAllDerivedAttribute(objectName, instanceKey);
/*     */     
/*     */ 
/* 424 */     Utf8 derAttrValue = (Utf8)derivedAttrs.get(new Utf8(derAttrName));
/* 425 */     if (null != derAttrValue) {
/* 426 */       return derAttrValue.toString();
/*     */     }
/*     */     
/* 429 */     return null;
/*     */   }
/*     */   
/*     */   public Map<Utf8, Utf8> getAllDerivedAttribute(String objectName, Utf8 instanceKey) throws ARMAException
/*     */   {
/*     */     try
/*     */     {
/* 436 */       ObjectData object = getObject(objectName);
/* 437 */       Map<Utf8, Utf8> derivedAttrs = (Map)object.getDerivedAttributes().get(instanceKey);
/*     */       
/*     */ 
/* 440 */       return null == derivedAttrs ? new HashMap() : derivedAttrs;
/*     */ 
/*     */     }
/*     */     catch (ARMAException e)
/*     */     {
/*     */ 
/* 446 */       StringBuilder msg = new StringBuilder("Error in getting the derived attributes:");
/*     */       
/* 448 */       msg.append(",for the object:");
/* 449 */       msg.append(objectName);
/* 450 */       msg.append(",with instance key:");
/* 451 */       msg.append(instanceKey);
/*     */       
/* 453 */       throw new ARMAException(LOG, getRequestId(), msg.toString(), e);
/*     */     }
/*     */   }
/*     */   
/*     */   public PerfCounters getPerfData(String objectName, String counterObjectName, int intervalInDays) throws ARMAException
/*     */   {
/* 459 */     PerfCounters perfCounters = (PerfCounters)this.sessionObjectMap.get(Response.ResponseField.PERFCOUNTERS);
/*     */     
/* 461 */     if ((perfCounters != null) && (!perfCounters.isEmpty())) {
/* 462 */       return perfCounters;
/*     */     }
/*     */     
/*     */ 
/* 466 */     addPerfCounters(objectName, intervalInDays, new String[] { counterObjectName });
/* 467 */     getData(new String[0]);
/* 468 */     perfCounters = (PerfCounters)this.sessionObjectMap.get(Response.ResponseField.PERFCOUNTERS);
/* 469 */     return perfCounters;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public LogEventData getLogData(String objectName, int intervalInDays, String... eventNames)
/*     */     throws ARMAException
/*     */   {
/* 488 */     return getLogData(objectName, intervalInDays, false, eventNames);
/*     */   }
/*     */   
/*     */   public LogEventData getLogData(String objectName, int intervalInDays, boolean addBizKeyFlag, String... eventNames) throws ARMAException
/*     */   {
/* 493 */     LogEvents logEvents = (LogEvents)this.sessionObjectMap.get(Response.ResponseField.LOGEVENTS);
/* 494 */     if (null != logEvents)
/*     */     {
/* 496 */       return logEvents.getLogEventData();
/*     */     }
/*     */     
/* 499 */     addLogEvents(objectName, intervalInDays, addBizKeyFlag, eventNames);
/* 500 */     getData(new String[0]);
/* 501 */     logEvents = (LogEvents)this.sessionObjectMap.get(Response.ResponseField.LOGEVENTS);
/* 502 */     return logEvents.getLogEventData();
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asupdata\client\ARMA\ARMAClientSession.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */