/*     */ package com.thoughtworks.paranamer;
/*     */ 
/*     */ import java.io.BufferedReader;
/*     */ import java.io.File;
/*     */ import java.io.FileInputStream;
/*     */ import java.io.FileNotFoundException;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.InputStreamReader;
/*     */ import java.io.StringReader;
/*     */ import java.io.UnsupportedEncodingException;
/*     */ import java.lang.reflect.AccessibleObject;
/*     */ import java.lang.reflect.Constructor;
/*     */ import java.lang.reflect.Method;
/*     */ import java.net.URI;
/*     */ import java.net.URISyntaxException;
/*     */ import java.net.URL;
/*     */ import java.net.URLConnection;
/*     */ import java.util.Enumeration;
/*     */ import java.util.HashSet;
/*     */ import java.util.Set;
/*     */ import java.util.SortedMap;
/*     */ import java.util.TreeMap;
/*     */ import java.util.regex.Matcher;
/*     */ import java.util.regex.Pattern;
/*     */ import java.util.zip.GZIPInputStream;
/*     */ import java.util.zip.Inflater;
/*     */ import java.util.zip.InflaterInputStream;
/*     */ import java.util.zip.ZipEntry;
/*     */ import java.util.zip.ZipFile;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class JavadocParanamer
/*     */   implements Paranamer
/*     */ {
/*     */   private static final String IE = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)";
/* 107 */   private static final ParameterNamesNotFoundException CLASS_NOT_SUPPORTED = new ParameterNamesNotFoundException("class not supported");
/*     */   
/*     */ 
/*     */ 
/* 111 */   private String base = null;
/*     */   
/*     */ 
/*     */   private final boolean isArchive;
/*     */   
/*     */ 
/*     */   private final boolean isDirectory;
/*     */   
/*     */ 
/*     */   private final boolean isURI;
/*     */   
/*     */   private final URI location;
/*     */   
/* 124 */   private final Set<String> packages = new HashSet();
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public static final String __PARANAMER_DATA = "<init> java.io.File archiveOrDirectory \n<init> java.net.URL url \nlookupParameterNames java.lang.reflect.AccessibleObject methodOrConstructor \nlookupParameterNames java.lang.reflect.AccessibleObject,boolean methodOrConstructor,throwExceptionIfMissing \n";
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JavadocParanamer(File archiveOrDirectory)
/*     */     throws IOException
/*     */   {
/* 145 */     if (archiveOrDirectory == null) {
/* 146 */       throw new NullPointerException();
/*     */     }
/* 148 */     if (!archiveOrDirectory.exists()) {
/* 149 */       throw new FileNotFoundException(archiveOrDirectory.getAbsolutePath());
/*     */     }
/*     */     
/* 152 */     this.isURI = false;
/* 153 */     this.location = archiveOrDirectory.toURI();
/*     */     
/* 155 */     if (archiveOrDirectory.isDirectory())
/*     */     {
/* 157 */       this.isArchive = false;
/* 158 */       this.isDirectory = true;
/*     */       
/* 160 */       File dir = archiveOrDirectory;
/* 161 */       File packageList = new File(dir.getAbsolutePath() + "/package-list");
/*     */       
/* 163 */       if (!packageList.isFile()) {
/* 164 */         throw new FileNotFoundException("No package-list found at " + dir.getAbsolutePath() + ". Not a valid Javadoc directory.");
/*     */       }
/*     */       
/*     */ 
/* 168 */       FileInputStream input = new FileInputStream(packageList);
/*     */       try {
/* 170 */         String packageListString = streamToString(input);
/* 171 */         parsePackageList(packageListString);
/*     */       } finally {
/* 173 */         input.close();
/*     */       }
/* 175 */     } else if (archiveOrDirectory.isFile())
/*     */     {
/* 177 */       this.isArchive = true;
/* 178 */       this.isDirectory = false;
/* 179 */       File archive = archiveOrDirectory;
/* 180 */       if (!archive.getAbsolutePath().toLowerCase().endsWith(".zip")) {
/* 181 */         throw new IllegalArgumentException(archive.getAbsolutePath() + " is not a zip file.");
/*     */       }
/*     */       
/* 184 */       ZipFile zip = new ZipFile(archive);
/*     */       
/*     */ 
/*     */ 
/*     */ 
/*     */       try
/*     */       {
/* 191 */         Enumeration<? extends ZipEntry> entries = zip.entries();
/*     */         
/*     */ 
/* 194 */         SortedMap<Long, ZipEntry> packageLists = new TreeMap();
/* 195 */         while (entries.hasMoreElements()) {
/* 196 */           ZipEntry entry = (ZipEntry)entries.nextElement();
/* 197 */           String name = entry.getName();
/* 198 */           if (name.endsWith("package-list")) {
/* 199 */             Long size = Long.valueOf(entry.getSize());
/* 200 */             packageLists.put(size, entry);
/*     */           }
/*     */         }
/* 203 */         if (packageLists.size() == 0) {
/* 204 */           throw new FileNotFoundException("no package-list found in archive");
/*     */         }
/*     */         
/*     */ 
/* 208 */         ZipEntry entry = (ZipEntry)packageLists.get(packageLists.lastKey());
/* 209 */         String name = entry.getName();
/* 210 */         this.base = name.substring(0, name.length() - "package-list".length());
/*     */         
/*     */ 
/* 213 */         InputStream input = zip.getInputStream(entry);
/*     */         try {
/* 215 */           String packageListString = streamToString(input);
/* 216 */           parsePackageList(packageListString);
/*     */         }
/*     */         finally {}
/*     */       }
/*     */       finally {
/* 221 */         zip.close();
/*     */       }
/*     */     } else {
/* 224 */       throw new IllegalArgumentException(archiveOrDirectory.getAbsolutePath() + " is neither a directory nor a file.");
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JavadocParanamer(URL url)
/*     */     throws IOException
/*     */   {
/* 239 */     if (url == null) {
/* 240 */       throw new NullPointerException();
/*     */     }
/* 242 */     this.isArchive = false;
/* 243 */     this.isDirectory = false;
/* 244 */     this.isURI = true;
/*     */     try {
/* 246 */       this.location = new URI(url.toString());
/*     */     } catch (URISyntaxException e) {
/* 248 */       throw new IOException(e.getMessage());
/*     */     }
/*     */     
/*     */ 
/* 252 */     URL packageListURL = new URL(url.toString() + "/package-list");
/* 253 */     InputStream input = urlToInputStream(packageListURL);
/*     */     try {
/* 255 */       String packageList = streamToString(input);
/* 256 */       parsePackageList(packageList);
/*     */     } finally {
/* 258 */       input.close();
/*     */     }
/*     */   }
/*     */   
/*     */   public String[] lookupParameterNames(AccessibleObject methodOrConstructor) {
/* 263 */     return lookupParameterNames(methodOrConstructor, true);
/*     */   }
/*     */   
/*     */   public String[] lookupParameterNames(AccessibleObject methodOrConstructor, boolean throwExceptionIfMissing) {
/* 267 */     if (methodOrConstructor == null) {
/* 268 */       throw new NullPointerException();
/*     */     }
/*     */     
/*     */ 
/*     */     Class<?>[] types;
/*     */     
/* 274 */     if ((methodOrConstructor instanceof Constructor)) {
/* 275 */       Constructor<?> constructor = (Constructor)methodOrConstructor;
/* 276 */       Class<?> klass = constructor.getDeclaringClass();
/* 277 */       String name = constructor.getName();
/* 278 */       types = constructor.getParameterTypes(); } else { Class<?>[] types;
/* 279 */       if ((methodOrConstructor instanceof Method)) {
/* 280 */         Method method = (Method)methodOrConstructor;
/* 281 */         Class<?> klass = method.getDeclaringClass();
/* 282 */         String name = method.getName();
/* 283 */         types = method.getParameterTypes();
/*     */       } else {
/* 285 */         throw new IllegalArgumentException(); } }
/*     */     Class<?>[] types;
/*     */     String name;
/* 288 */     Class<?> klass; if (!this.packages.contains(klass.getPackage().getName())) {
/* 289 */       throw CLASS_NOT_SUPPORTED;
/*     */     }
/*     */     try {
/* 292 */       String[] names = getParameterNames(klass, name, types);
/* 293 */       if (names == null) {
/* 294 */         if (throwExceptionIfMissing) {
/* 295 */           throw new ParameterNamesNotFoundException(methodOrConstructor.toString());
/*     */         }
/*     */         
/* 298 */         return Paranamer.EMPTY_NAMES;
/*     */       }
/*     */       
/* 301 */       return names;
/*     */     } catch (IOException e) {
/* 303 */       if (throwExceptionIfMissing) {
/* 304 */         throw new ParameterNamesNotFoundException(methodOrConstructor.toString() + " due to an I/O error: " + e.getMessage());
/*     */       }
/*     */     }
/*     */     
/* 308 */     return Paranamer.EMPTY_NAMES;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private String[] getParameterNames(Class<?> klass, String constructorOrMethodName, Class<?>[] types)
/*     */     throws IOException
/*     */   {
/* 318 */     if ((types != null) && (types.length == 0)) {
/* 319 */       return new String[0];
/*     */     }
/* 321 */     String path = getCanonicalName(klass).replace('.', '/');
/* 322 */     if (this.isArchive) {
/* 323 */       ZipFile archive = new ZipFile(new File(this.location));
/* 324 */       ZipEntry entry = archive.getEntry(this.base + path + ".html");
/* 325 */       if (entry == null)
/* 326 */         throw CLASS_NOT_SUPPORTED;
/* 327 */       InputStream input = archive.getInputStream(entry);
/* 328 */       return getParameterNames2(input, constructorOrMethodName, types); }
/* 329 */     if (this.isDirectory) {
/* 330 */       File file = new File(this.location.getPath() + "/" + path + ".html");
/* 331 */       if (!file.isFile())
/* 332 */         throw CLASS_NOT_SUPPORTED;
/* 333 */       FileInputStream input = new FileInputStream(file);
/* 334 */       return getParameterNames2(input, constructorOrMethodName, types); }
/* 335 */     if (this.isURI) {
/*     */       try {
/* 337 */         URL url = new URL(this.location.toString() + "/" + path + ".html");
/* 338 */         InputStream input = urlToInputStream(url);
/* 339 */         return getParameterNames2(input, constructorOrMethodName, types);
/*     */       } catch (FileNotFoundException e) {
/* 341 */         throw CLASS_NOT_SUPPORTED;
/*     */       }
/*     */     }
/* 344 */     throw new RuntimeException("bug in JavadocParanamer. Should not reach here.");
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private String[] getParameterNames2(InputStream input, String constructorOrMethodName, Class<?>[] types)
/*     */     throws IOException
/*     */   {
/* 356 */     String javadoc = streamToString(input);
/* 357 */     input.close();
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 374 */     StringBuffer regex = new StringBuffer();
/* 375 */     regex.append("NAME=\"");
/* 376 */     regex.append(constructorOrMethodName);
/*     */     
/* 378 */     regex.append("\\(\\Q");
/* 379 */     for (int i = 0; i < types.length; i++) {
/* 380 */       if (i != 0) {
/* 381 */         regex.append(", ");
/*     */       }
/* 383 */       regex.append(getCanonicalName(types[i]));
/*     */     }
/* 385 */     regex.append("\\E\\)\"");
/*     */     
/*     */ 
/*     */ 
/* 389 */     Pattern pattern = Pattern.compile(regex.toString());
/* 390 */     Matcher matcher = pattern.matcher(javadoc);
/* 391 */     if (!matcher.find())
/*     */     {
/* 393 */       return Paranamer.EMPTY_NAMES;
/*     */     }
/*     */     
/* 396 */     String[] names = new String[types.length];
/*     */     
/* 398 */     String regexParams = "<DD><CODE>([^<]*)</CODE>";
/* 399 */     Pattern patternParams = Pattern.compile(regexParams);
/* 400 */     int start = matcher.end();
/* 401 */     Matcher matcherParams = patternParams.matcher(javadoc);
/* 402 */     for (int i = 0; i < types.length; i++) {
/* 403 */       boolean find = matcherParams.find(start);
/* 404 */       if (!find)
/* 405 */         return Paranamer.EMPTY_NAMES;
/* 406 */       start = matcherParams.end();
/* 407 */       names[i] = matcherParams.group(1);
/*     */     }
/* 409 */     return names;
/*     */   }
/*     */   
/*     */   private String getCanonicalName(Class<?> klass)
/*     */   {
/* 414 */     if (klass.isArray()) {
/* 415 */       return getCanonicalName(klass.getComponentType()) + "[]";
/*     */     }
/* 417 */     return klass.getName();
/*     */   }
/*     */   
/*     */   private void parsePackageList(String packageList) throws IOException
/*     */   {
/* 422 */     StringReader reader = new StringReader(packageList);
/* 423 */     BufferedReader breader = new BufferedReader(reader);
/*     */     String line;
/* 425 */     while ((line = breader.readLine()) != null) {
/* 426 */       this.packages.add(line);
/*     */     }
/*     */   }
/*     */   
/*     */   private String streamToString(InputStream input) throws IOException
/*     */   {
/*     */     InputStreamReader reader;
/*     */     try {
/* 434 */       reader = new InputStreamReader(input, "UTF-8");
/*     */     }
/*     */     catch (UnsupportedEncodingException e) {
/* 437 */       reader = new InputStreamReader(input);
/*     */     }
/* 439 */     BufferedReader breader = new BufferedReader(reader);
/*     */     
/* 441 */     StringBuffer builder = new StringBuffer();
/* 442 */     String line; while ((line = breader.readLine()) != null) {
/* 443 */       builder.append(line);
/* 444 */       builder.append("\n");
/*     */     }
/* 446 */     return builder.toString();
/*     */   }
/*     */   
/*     */   private InputStream urlToInputStream(URL url) throws IOException {
/* 450 */     URLConnection conn = url.openConnection();
/*     */     
/* 452 */     conn.setRequestProperty("User-Agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)");
/*     */     
/* 454 */     conn.setRequestProperty("Accept-Encoding", "gzip, deflate");
/* 455 */     conn.connect();
/* 456 */     String encoding = conn.getContentEncoding();
/* 457 */     if ((encoding != null) && (encoding.equalsIgnoreCase("gzip")))
/* 458 */       return new GZIPInputStream(conn.getInputStream());
/* 459 */     if ((encoding != null) && (encoding.equalsIgnoreCase("deflate"))) {
/* 460 */       return new InflaterInputStream(conn.getInputStream(), new Inflater(true));
/*     */     }
/*     */     
/* 463 */     return conn.getInputStream();
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\thoughtworks\paranamer\JavadocParanamer.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */