/*     */ package net.rubyeye.xmemcached.command;
/*     */ 
/*     */ import java.net.InetSocketAddress;
/*     */ import java.util.Collection;
/*     */ import java.util.Iterator;
/*     */ import java.util.concurrent.CountDownLatch;
/*     */ import net.rubyeye.xmemcached.CommandFactory;
/*     */ import net.rubyeye.xmemcached.buffer.BufferAllocator;
/*     */ import net.rubyeye.xmemcached.command.text.TextCASCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextDeleteCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextFlushAllCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextGetMultiCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextGetOneCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextIncrDecrCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextQuitCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextStatsCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextStoreCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextTouchCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextVerbosityCommand;
/*     */ import net.rubyeye.xmemcached.command.text.TextVersionCommand;
/*     */ import net.rubyeye.xmemcached.transcoders.Transcoder;
/*     */ import net.rubyeye.xmemcached.utils.ByteUtils;
/*     */ import net.rubyeye.xmemcached.utils.Protocol;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class TextCommandFactory
/*     */   implements CommandFactory
/*     */ {
/*     */   public void setBufferAllocator(BufferAllocator bufferAllocator) {}
/*     */   
/*     */   public final Command createDeleteCommand(String key, byte[] keyBytes, int time, boolean noreply)
/*     */   {
/*  46 */     return new TextDeleteCommand(key, keyBytes, time, new CountDownLatch(1), noreply);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createVersionCommand(CountDownLatch latch, InetSocketAddress server)
/*     */   {
/*  57 */     return new TextVersionCommand(latch, server);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createFlushAllCommand(CountDownLatch latch, int exptime, boolean noreply)
/*     */   {
/*  69 */     return new TextFlushAllCommand(latch, exptime, noreply);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createVerbosityCommand(CountDownLatch latch, int level, boolean noreply)
/*     */   {
/*  82 */     return new TextVerbosityCommand(latch, level, noreply);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createStatsCommand(InetSocketAddress server, CountDownLatch latch, String itemName)
/*     */   {
/*  93 */     return new TextStatsCommand(server, latch, itemName);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createCASCommand(String key, byte[] keyBytes, int exp, Object value, long cas, boolean noreply, Transcoder transcoder)
/*     */   {
/* 109 */     return new TextCASCommand(key, keyBytes, CommandType.CAS, new CountDownLatch(1), exp, cas, value, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createSetCommand(String key, byte[] keyBytes, int exp, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/* 117 */     return createStoreCommand(key, keyBytes, exp, value, CommandType.SET, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createAddCommand(String key, byte[] keyBytes, int exp, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/* 125 */     return createStoreCommand(key, keyBytes, exp, value, CommandType.ADD, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createReplaceCommand(String key, byte[] keyBytes, int exp, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/* 133 */     return createStoreCommand(key, keyBytes, exp, value, CommandType.REPLACE, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createAppendCommand(String key, byte[] keyBytes, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/* 141 */     return createStoreCommand(key, keyBytes, 0, value, CommandType.APPEND, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createPrependCommand(String key, byte[] keyBytes, Object value, boolean noreply, Transcoder transcoder)
/*     */   {
/* 149 */     return createStoreCommand(key, keyBytes, 0, value, CommandType.PREPEND, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   final Command createStoreCommand(String key, byte[] keyBytes, int exp, Object value, CommandType cmdType, boolean noreply, Transcoder transcoder)
/*     */   {
/* 157 */     return new TextStoreCommand(key, keyBytes, cmdType, new CountDownLatch(1), exp, -1L, value, noreply, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createGetCommand(String key, byte[] keyBytes, CommandType cmdType, Transcoder transcoder)
/*     */   {
/* 172 */     return new TextGetOneCommand(key, keyBytes, cmdType, new CountDownLatch(1));
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final <T> Command createGetMultiCommand(Collection<String> keys, CountDownLatch latch, CommandType cmdType, Transcoder<T> transcoder)
/*     */   {
/* 187 */     StringBuilder sb = new StringBuilder(keys.size() * 5);
/* 188 */     for (String tmpKey : keys) {
/* 189 */       ByteUtils.checkKey(tmpKey);
/* 190 */       sb.append(tmpKey).append(" ");
/*     */     }
/* 192 */     String gatherKey = sb.toString();
/* 193 */     byte[] keyBytes = ByteUtils.getBytes(gatherKey.substring(0, gatherKey.length() - 1));
/*     */     
/* 195 */     return new TextGetMultiCommand((String)keys.iterator().next(), keyBytes, cmdType, latch, transcoder);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Command createIncrDecrCommand(String key, byte[] keyBytes, long amount, long initial, int exptime, CommandType cmdType, boolean noreply)
/*     */   {
/* 209 */     return new TextIncrDecrCommand(key, keyBytes, cmdType, new CountDownLatch(1), amount, initial, noreply);
/*     */   }
/*     */   
/*     */   public Command createAuthListMechanismsCommand(CountDownLatch latch)
/*     */   {
/* 214 */     throw new UnsupportedOperationException("SASL is only supported by binary protocol");
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createAuthStartCommand(String mechanism, CountDownLatch latch, byte[] authData)
/*     */   {
/* 220 */     throw new UnsupportedOperationException("SASL is only supported by binary protocol");
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createAuthStepCommand(String mechanism, CountDownLatch latch, byte[] authData)
/*     */   {
/* 226 */     throw new UnsupportedOperationException("SASL is only supported by binary protocol");
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createGetAndTouchCommand(String key, byte[] keyBytes, CountDownLatch latch, int exp, boolean noreply)
/*     */   {
/* 232 */     throw new UnsupportedOperationException("GAT is only supported by binary protocol");
/*     */   }
/*     */   
/*     */ 
/*     */   public Command createTouchCommand(String key, byte[] keyBytes, CountDownLatch latch, int exp, boolean noreply)
/*     */   {
/* 238 */     return new TextTouchCommand(key, keyBytes, CommandType.TOUCH, latch, exp, noreply);
/*     */   }
/*     */   
/*     */   public Command createQuitCommand()
/*     */   {
/* 243 */     return new TextQuitCommand();
/*     */   }
/*     */   
/*     */   public Protocol getProtocol() {
/* 247 */     return Protocol.Text;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\net\rubyeye\xmemcached\command\TextCommandFactory.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */