/*     */ package net.rubyeye.xmemcached.command.binary;
/*     */ 
/*     */ import com.google.code.yanf4j.buffer.IoBuffer;
/*     */ import java.nio.ByteBuffer;
/*     */ import java.util.Collection;
/*     */ import java.util.HashMap;
/*     */ import java.util.Map;
/*     */ import java.util.concurrent.CountDownLatch;
/*     */ import net.rubyeye.xmemcached.command.Command;
/*     */ import net.rubyeye.xmemcached.command.CommandType;
/*     */ import net.rubyeye.xmemcached.command.MapReturnValueAware;
/*     */ import net.rubyeye.xmemcached.command.MergeCommandsAware;
/*     */ import net.rubyeye.xmemcached.transcoders.CachedData;
/*     */ import net.rubyeye.xmemcached.utils.ByteUtils;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class BinaryGetMultiCommand
/*     */   extends BaseBinaryCommand
/*     */   implements MergeCommandsAware, MapReturnValueAware
/*     */ {
/*     */   private boolean finished;
/*     */   private String responseKey;
/*     */   private long responseCAS;
/*     */   private int responseFlag;
/*     */   private Map<Object, Command> mergeCommands;
/*     */   
/*     */   public BinaryGetMultiCommand(String key, CommandType cmdType, CountDownLatch latch)
/*     */   {
/*  55 */     super(key, null, cmdType, latch, 0, 0L, null, false, null);
/*  56 */     this.result = new HashMap();
/*     */   }
/*     */   
/*     */   public Map<String, CachedData> getReturnValues() {
/*  60 */     return (Map)this.result;
/*     */   }
/*     */   
/*     */   protected boolean readOpCode(ByteBuffer buffer)
/*     */   {
/*  65 */     byte opCode = buffer.get();
/*     */     
/*  67 */     if (opCode == OpCode.GET_KEY.fieldValue()) {
/*  68 */       this.finished = true;
/*     */     }
/*  70 */     return true;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   protected void readHeader(ByteBuffer buffer)
/*     */   {
/*  78 */     super.readHeader(buffer);
/*  79 */     if ((this.responseStatus != ResponseStatus.NO_ERROR) && 
/*  80 */       (ByteUtils.stepBuffer(buffer, this.responseTotalBodyLength))) {
/*  81 */       this.decodeStatus = BinaryDecodeStatus.DONE;
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public void encode() {}
/*     */   
/*     */ 
/*     */ 
/*     */   protected boolean finish()
/*     */   {
/*  93 */     CachedData cachedData = (CachedData)((Map)this.result).get(this.responseKey);
/*     */     
/*  95 */     Map<Object, Command> mergetCommands = getMergeCommands();
/*  96 */     if (mergetCommands != null) {
/*  97 */       BinaryGetCommand command = (BinaryGetCommand)mergetCommands.remove(this.responseKey);
/*     */       
/*  99 */       if (command != null) {
/* 100 */         command.setResult(cachedData);
/* 101 */         command.countDownLatch();
/* 102 */         this.mergeCount -= 1;
/* 103 */         if (command.getAssocCommands() != null) {
/* 104 */           for (Command assocCommand : command.getAssocCommands()) {
/* 105 */             assocCommand.setResult(cachedData);
/* 106 */             assocCommand.countDownLatch();
/* 107 */             this.mergeCount -= 1;
/*     */           }
/*     */         }
/*     */       }
/*     */     }
/*     */     
/* 113 */     if (this.finished) {
/* 114 */       if (getMergeCommands() != null) {
/* 115 */         Collection<Command> mergeCommands = getMergeCommands().values();
/* 116 */         getIoBuffer().free();
/* 117 */         for (Command nextCommand : mergeCommands) {
/* 118 */           BinaryGetCommand command = (BinaryGetCommand)nextCommand;
/* 119 */           command.countDownLatch();
/* 120 */           if (command.getAssocCommands() != null) {
/* 121 */             for (Command assocCommand : command.getAssocCommands()) {
/* 122 */               assocCommand.countDownLatch();
/*     */             }
/*     */           }
/*     */         }
/*     */       }
/* 127 */       countDownLatch();
/*     */     }
/*     */     else {
/* 130 */       this.responseKey = null;
/*     */     }
/* 132 */     return this.finished;
/*     */   }
/*     */   
/*     */   protected boolean readKey(ByteBuffer buffer, int keyLength)
/*     */   {
/* 137 */     if (buffer.remaining() < keyLength) {
/* 138 */       return false;
/*     */     }
/* 140 */     if (keyLength > 0) {
/* 141 */       byte[] bytes = new byte[keyLength];
/* 142 */       buffer.get(bytes);
/* 143 */       this.responseKey = ByteUtils.getString(bytes);
/* 144 */       CachedData value = new CachedData();
/* 145 */       value.setCas(this.responseCAS);
/* 146 */       value.setFlag(this.responseFlag);
/* 147 */       ((Map)this.result).put(this.responseKey, value);
/*     */     }
/*     */     
/* 150 */     return true;
/*     */   }
/*     */   
/*     */ 
/*     */   protected boolean readValue(ByteBuffer buffer, int bodyLength, int keyLength, int extrasLength)
/*     */   {
/* 156 */     if (this.responseStatus == ResponseStatus.NO_ERROR) {
/* 157 */       int valueLength = bodyLength - keyLength - extrasLength;
/* 158 */       CachedData responseValue = (CachedData)((Map)this.result).get(this.responseKey);
/*     */       
/* 160 */       if ((valueLength >= 0) && (responseValue.getCapacity() < 0)) {
/* 161 */         responseValue.setCapacity(valueLength);
/* 162 */         responseValue.setData(new byte[valueLength]);
/*     */       }
/* 164 */       int remainingCapacity = responseValue.remainingCapacity();
/* 165 */       int remaining = buffer.remaining();
/* 166 */       if (remaining < remainingCapacity) {
/* 167 */         int length = remaining > remainingCapacity ? remainingCapacity : remaining;
/*     */         
/* 169 */         responseValue.fillData(buffer, length);
/* 170 */         return false; }
/* 171 */       if (remainingCapacity > 0) {
/* 172 */         responseValue.fillData(buffer, remainingCapacity);
/*     */       }
/* 174 */       return true;
/*     */     }
/* 176 */     ((Map)this.result).remove(this.responseKey);
/* 177 */     return true;
/*     */   }
/*     */   
/*     */ 
/*     */   protected boolean readExtras(ByteBuffer buffer, int extrasLength)
/*     */   {
/* 183 */     if (buffer.remaining() < extrasLength) {
/* 184 */       return false;
/*     */     }
/* 186 */     if (extrasLength == 4)
/*     */     {
/* 188 */       this.responseFlag = buffer.getInt();
/*     */     }
/* 190 */     return true;
/*     */   }
/*     */   
/*     */   protected long readCAS(ByteBuffer buffer)
/*     */   {
/* 195 */     this.responseCAS = buffer.getLong();
/* 196 */     return this.responseCAS;
/*     */   }
/*     */   
/*     */   public Map<Object, Command> getMergeCommands() {
/* 200 */     return this.mergeCommands;
/*     */   }
/*     */   
/*     */   public void setMergeCommands(Map<Object, Command> mergeCommands) {
/* 204 */     this.mergeCommands = mergeCommands;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\net\rubyeye\xmemcached\command\binary\BinaryGetMultiCommand.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */