/*     */ package net.rubyeye.xmemcached.transcoders;
/*     */ 
/*     */ import org.slf4j.Logger;
/*     */ 
/*     */ public class SerializingTranscoder extends BaseSerializingTranscoder implements Transcoder<Object> {
/*     */   private final int maxSize;
/*     */   private boolean primitiveAsString;
/*     */   public static final int SERIALIZED = 1;
/*     */   public static final int COMPRESSED = 2;
/*     */   public static final int SPECIAL_MASK = 65280;
/*     */   public static final int SPECIAL_BOOLEAN = 256;
/*     */   
/*     */   public void setPackZeros(boolean packZeros) {
/*  14 */     this.transcoderUtils.setPackZeros(packZeros);
/*     */   }
/*     */   
/*     */   public void setPrimitiveAsString(boolean primitiveAsString)
/*     */   {
/*  19 */     this.primitiveAsString = primitiveAsString;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public final int getMaxSize()
/*     */   {
/*  27 */     return this.maxSize;
/*     */   }
/*     */   
/*     */ 
/*     */   public static final int SPECIAL_INT = 512;
/*     */   
/*     */   public static final int SPECIAL_LONG = 768;
/*     */   
/*     */   public static final int SPECIAL_DATE = 1024;
/*     */   
/*     */   public static final int SPECIAL_BYTE = 1280;
/*     */   
/*     */   public static final int SPECIAL_FLOAT = 1536;
/*     */   
/*     */   public static final int SPECIAL_DOUBLE = 1792;
/*     */   
/*     */   public static final int SPECIAL_BYTEARRAY = 2048;
/*     */   
/*  45 */   private final TranscoderUtils transcoderUtils = new TranscoderUtils(true);
/*     */   
/*     */   public TranscoderUtils getTranscoderUtils() {
/*  48 */     return this.transcoderUtils;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public SerializingTranscoder()
/*     */   {
/*  55 */     this(CachedData.MAX_SIZE);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public SerializingTranscoder(int max)
/*     */   {
/*  62 */     this.maxSize = max;
/*     */   }
/*     */   
/*     */   public boolean isPackZeros() {
/*  66 */     return this.transcoderUtils.isPackZeros();
/*     */   }
/*     */   
/*     */   public boolean isPrimitiveAsString() {
/*  70 */     return this.primitiveAsString;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final Object decode(CachedData d)
/*     */   {
/*  79 */     byte[] data = d.getData();
/*     */     
/*  81 */     int flags = d.getFlag();
/*  82 */     if ((flags & 0x2) != 0) {
/*  83 */       data = decompress(d.getData());
/*     */     }
/*  85 */     flags &= 0xFF00;
/*  86 */     return decode0(d, data, flags);
/*     */   }
/*     */   
/*     */   protected final Object decode0(CachedData cachedData, byte[] data, int flags) {
/*  90 */     Object rv = null;
/*  91 */     if (((cachedData.getFlag() & 0x1) != 0) && (data != null)) {
/*  92 */       rv = deserialize(data);
/*     */     } else {
/*  94 */       if ((this.primitiveAsString) && 
/*  95 */         (flags == 0)) {
/*  96 */         return decodeString(data);
/*     */       }
/*     */       
/*  99 */       if ((flags != 0) && (data != null)) {}
/* 100 */       switch (flags) {
/*     */       case 256: 
/* 102 */         rv = Boolean.valueOf(this.transcoderUtils.decodeBoolean(data));
/*     */         
/* 104 */         break;
/*     */       case 512: 
/* 106 */         rv = Integer.valueOf(this.transcoderUtils.decodeInt(data));
/* 107 */         break;
/*     */       case 768: 
/* 109 */         rv = Long.valueOf(this.transcoderUtils.decodeLong(data));
/* 110 */         break;
/*     */       case 1280: 
/* 112 */         rv = Byte.valueOf(this.transcoderUtils.decodeByte(data));
/* 113 */         break;
/*     */       case 1536: 
/* 115 */         rv = new Float(Float.intBitsToFloat(this.transcoderUtils.decodeInt(data)));
/*     */         
/* 117 */         break;
/*     */       case 1792: 
/* 119 */         rv = new Double(Double.longBitsToDouble(this.transcoderUtils.decodeLong(data)));
/*     */         
/*     */ 
/* 122 */         break;
/*     */       case 1024: 
/* 124 */         rv = new java.util.Date(this.transcoderUtils.decodeLong(data));
/* 125 */         break;
/*     */       case 2048: 
/* 127 */         rv = data;
/* 128 */         break;
/*     */       default: 
/* 130 */         log.warn(String.format("Undecodeable with flags %x", new Object[] { Integer.valueOf(flags) })); break;
/*     */         
/*     */ 
/*     */ 
/*     */ 
/* 135 */         rv = decodeString(data);
/*     */       }
/*     */     }
/* 138 */     return rv;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final CachedData encode(Object o)
/*     */   {
/* 147 */     byte[] b = null;
/* 148 */     int flags = 0;
/* 149 */     if ((o instanceof String)) {
/* 150 */       b = encodeString((String)o);
/* 151 */     } else if ((o instanceof Long)) {
/* 152 */       if (this.primitiveAsString) {
/* 153 */         b = encodeString(o.toString());
/*     */       } else {
/* 155 */         b = this.transcoderUtils.encodeLong(((Long)o).longValue());
/*     */       }
/* 157 */       flags |= 0x300;
/* 158 */     } else if ((o instanceof Integer)) {
/* 159 */       if (this.primitiveAsString) {
/* 160 */         b = encodeString(o.toString());
/*     */       } else {
/* 162 */         b = this.transcoderUtils.encodeInt(((Integer)o).intValue());
/*     */       }
/* 164 */       flags |= 0x200;
/* 165 */     } else if ((o instanceof Boolean)) {
/* 166 */       if (this.primitiveAsString) {
/* 167 */         b = encodeString(o.toString());
/*     */       } else {
/* 169 */         b = this.transcoderUtils.encodeBoolean(((Boolean)o).booleanValue());
/*     */       }
/* 171 */       flags |= 0x100;
/* 172 */     } else if ((o instanceof java.util.Date)) {
/* 173 */       b = this.transcoderUtils.encodeLong(((java.util.Date)o).getTime());
/* 174 */       flags |= 0x400;
/* 175 */     } else if ((o instanceof Byte)) {
/* 176 */       if (this.primitiveAsString) {
/* 177 */         b = encodeString(o.toString());
/*     */       } else {
/* 179 */         b = this.transcoderUtils.encodeByte(((Byte)o).byteValue());
/*     */       }
/* 181 */       flags |= 0x500;
/* 182 */     } else if ((o instanceof Float)) {
/* 183 */       if (this.primitiveAsString) {
/* 184 */         b = encodeString(o.toString());
/*     */       } else {
/* 186 */         b = this.transcoderUtils.encodeInt(Float.floatToRawIntBits(((Float)o).floatValue()));
/*     */       }
/*     */       
/* 189 */       flags |= 0x600;
/* 190 */     } else if ((o instanceof Double)) {
/* 191 */       if (this.primitiveAsString) {
/* 192 */         b = encodeString(o.toString());
/*     */       } else {
/* 194 */         b = this.transcoderUtils.encodeLong(Double.doubleToRawLongBits(((Double)o).doubleValue()));
/*     */       }
/*     */       
/* 197 */       flags |= 0x700;
/* 198 */     } else if ((o instanceof byte[])) {
/* 199 */       b = (byte[])o;
/* 200 */       flags |= 0x800;
/*     */     } else {
/* 202 */       b = serialize(o);
/* 203 */       flags |= 0x1;
/*     */     }
/* 205 */     assert (b != null);
/* 206 */     if (this.primitiveAsString)
/*     */     {
/* 208 */       if ((flags & 0x1) == 0) {
/* 209 */         flags = 0;
/*     */       }
/*     */     }
/* 212 */     if (b.length > this.compressionThreshold) {
/* 213 */       byte[] compressed = compress(b);
/* 214 */       if (compressed.length < b.length) {
/* 215 */         if (log.isDebugEnabled()) {
/* 216 */           log.debug("Compressed " + o.getClass().getName() + " from " + b.length + " to " + compressed.length);
/*     */         }
/*     */         
/* 219 */         b = compressed;
/* 220 */         flags |= 0x2;
/*     */       }
/* 222 */       else if (log.isDebugEnabled()) {
/* 223 */         log.debug("Compression increased the size of " + o.getClass().getName() + " from " + b.length + " to " + compressed.length);
/*     */       }
/*     */     }
/*     */     
/*     */ 
/*     */ 
/* 229 */     return new CachedData(flags, b, this.maxSize, -1L);
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\net\rubyeye\xmemcached\transcoders\SerializingTranscoder.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */