/*     */ package org.apache.avro.io;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.nio.ByteBuffer;
/*     */ import org.apache.avro.AvroTypeException;
/*     */ import org.apache.avro.Schema;
/*     */ import org.apache.avro.io.parsing.Parser;
/*     */ import org.apache.avro.io.parsing.Parser.ActionHandler;
/*     */ import org.apache.avro.io.parsing.Symbol;
/*     */ import org.apache.avro.io.parsing.Symbol.Alternative;
/*     */ import org.apache.avro.io.parsing.Symbol.IntCheckAction;
/*     */ import org.apache.avro.io.parsing.ValidatingGrammarGenerator;
/*     */ import org.apache.avro.util.Utf8;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class ValidatingEncoder
/*     */   extends ParsingEncoder
/*     */   implements Parser.ActionHandler
/*     */ {
/*     */   protected Encoder out;
/*     */   protected final Parser parser;
/*     */   
/*     */   ValidatingEncoder(Symbol root, Encoder out)
/*     */     throws IOException
/*     */   {
/*  48 */     this.out = out;
/*  49 */     this.parser = new Parser(root, this);
/*     */   }
/*     */   
/*     */   ValidatingEncoder(Schema schema, Encoder in) throws IOException {
/*  53 */     this(new ValidatingGrammarGenerator().generate(schema), in);
/*     */   }
/*     */   
/*     */   public void flush() throws IOException
/*     */   {
/*  58 */     this.out.flush();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public ValidatingEncoder configure(Encoder encoder)
/*     */   {
/*  69 */     this.parser.reset();
/*  70 */     this.out = encoder;
/*  71 */     return this;
/*     */   }
/*     */   
/*     */   public void writeNull() throws IOException
/*     */   {
/*  76 */     this.parser.advance(Symbol.NULL);
/*  77 */     this.out.writeNull();
/*     */   }
/*     */   
/*     */   public void writeBoolean(boolean b) throws IOException
/*     */   {
/*  82 */     this.parser.advance(Symbol.BOOLEAN);
/*  83 */     this.out.writeBoolean(b);
/*     */   }
/*     */   
/*     */   public void writeInt(int n) throws IOException
/*     */   {
/*  88 */     this.parser.advance(Symbol.INT);
/*  89 */     this.out.writeInt(n);
/*     */   }
/*     */   
/*     */   public void writeLong(long n) throws IOException
/*     */   {
/*  94 */     this.parser.advance(Symbol.LONG);
/*  95 */     this.out.writeLong(n);
/*     */   }
/*     */   
/*     */   public void writeFloat(float f) throws IOException
/*     */   {
/* 100 */     this.parser.advance(Symbol.FLOAT);
/* 101 */     this.out.writeFloat(f);
/*     */   }
/*     */   
/*     */   public void writeDouble(double d) throws IOException
/*     */   {
/* 106 */     this.parser.advance(Symbol.DOUBLE);
/* 107 */     this.out.writeDouble(d);
/*     */   }
/*     */   
/*     */   public void writeString(Utf8 utf8) throws IOException
/*     */   {
/* 112 */     this.parser.advance(Symbol.STRING);
/* 113 */     this.out.writeString(utf8);
/*     */   }
/*     */   
/*     */   public void writeString(String str) throws IOException
/*     */   {
/* 118 */     this.parser.advance(Symbol.STRING);
/* 119 */     this.out.writeString(str);
/*     */   }
/*     */   
/*     */   public void writeString(CharSequence charSequence) throws IOException
/*     */   {
/* 124 */     this.parser.advance(Symbol.STRING);
/* 125 */     this.out.writeString(charSequence);
/*     */   }
/*     */   
/*     */   public void writeBytes(ByteBuffer bytes) throws IOException
/*     */   {
/* 130 */     this.parser.advance(Symbol.BYTES);
/* 131 */     this.out.writeBytes(bytes);
/*     */   }
/*     */   
/*     */   public void writeBytes(byte[] bytes, int start, int len) throws IOException
/*     */   {
/* 136 */     this.parser.advance(Symbol.BYTES);
/* 137 */     this.out.writeBytes(bytes, start, len);
/*     */   }
/*     */   
/*     */   public void writeFixed(byte[] bytes, int start, int len) throws IOException
/*     */   {
/* 142 */     this.parser.advance(Symbol.FIXED);
/* 143 */     Symbol.IntCheckAction top = (Symbol.IntCheckAction)this.parser.popSymbol();
/* 144 */     if (len != top.size) {
/* 145 */       throw new AvroTypeException("Incorrect length for fixed binary: expected " + top.size + " but received " + len + " bytes.");
/*     */     }
/*     */     
/*     */ 
/* 149 */     this.out.writeFixed(bytes, start, len);
/*     */   }
/*     */   
/*     */   public void writeEnum(int e) throws IOException
/*     */   {
/* 154 */     this.parser.advance(Symbol.ENUM);
/* 155 */     Symbol.IntCheckAction top = (Symbol.IntCheckAction)this.parser.popSymbol();
/* 156 */     if ((e < 0) || (e >= top.size)) {
/* 157 */       throw new AvroTypeException("Enumeration out of range: max is " + top.size + " but received " + e);
/*     */     }
/*     */     
/*     */ 
/* 161 */     this.out.writeEnum(e);
/*     */   }
/*     */   
/*     */   public void writeArrayStart() throws IOException
/*     */   {
/* 166 */     push();
/* 167 */     this.parser.advance(Symbol.ARRAY_START);
/* 168 */     this.out.writeArrayStart();
/*     */   }
/*     */   
/*     */   public void writeArrayEnd() throws IOException
/*     */   {
/* 173 */     this.parser.advance(Symbol.ARRAY_END);
/* 174 */     this.out.writeArrayEnd();
/* 175 */     pop();
/*     */   }
/*     */   
/*     */   public void writeMapStart() throws IOException
/*     */   {
/* 180 */     push();
/* 181 */     this.parser.advance(Symbol.MAP_START);
/* 182 */     this.out.writeMapStart();
/*     */   }
/*     */   
/*     */   public void writeMapEnd() throws IOException
/*     */   {
/* 187 */     this.parser.advance(Symbol.MAP_END);
/* 188 */     this.out.writeMapEnd();
/* 189 */     pop();
/*     */   }
/*     */   
/*     */   public void setItemCount(long itemCount) throws IOException
/*     */   {
/* 194 */     super.setItemCount(itemCount);
/* 195 */     this.out.setItemCount(itemCount);
/*     */   }
/*     */   
/*     */   public void startItem() throws IOException
/*     */   {
/* 200 */     super.startItem();
/* 201 */     this.out.startItem();
/*     */   }
/*     */   
/*     */   public void writeIndex(int unionIndex) throws IOException
/*     */   {
/* 206 */     this.parser.advance(Symbol.UNION);
/* 207 */     Symbol.Alternative top = (Symbol.Alternative)this.parser.popSymbol();
/* 208 */     this.parser.pushSymbol(top.getSymbol(unionIndex));
/* 209 */     this.out.writeIndex(unionIndex);
/*     */   }
/*     */   
/*     */   public Symbol doAction(Symbol input, Symbol top) throws IOException
/*     */   {
/* 214 */     return null;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\apache\avro\io\ValidatingEncoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */