/*     */ package org.codehaus.jackson.map.ser;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.lang.reflect.ParameterizedType;
/*     */ import java.lang.reflect.Type;
/*     */ import java.util.Collection;
/*     */ import java.util.EnumSet;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import org.codehaus.jackson.JsonGenerationException;
/*     */ import org.codehaus.jackson.JsonGenerator;
/*     */ import org.codehaus.jackson.JsonNode;
/*     */ import org.codehaus.jackson.map.BeanProperty;
/*     */ import org.codehaus.jackson.map.JsonMappingException;
/*     */ import org.codehaus.jackson.map.JsonSerializer;
/*     */ import org.codehaus.jackson.map.ResolvableSerializer;
/*     */ import org.codehaus.jackson.map.SerializerProvider;
/*     */ import org.codehaus.jackson.map.TypeSerializer;
/*     */ import org.codehaus.jackson.map.annotate.JacksonStdImpl;
/*     */ import org.codehaus.jackson.map.ser.impl.PropertySerializerMap;
/*     */ import org.codehaus.jackson.map.ser.impl.PropertySerializerMap.SerializerAndMapResult;
/*     */ import org.codehaus.jackson.node.ObjectNode;
/*     */ import org.codehaus.jackson.schema.JsonSchema;
/*     */ import org.codehaus.jackson.schema.SchemaAware;
/*     */ import org.codehaus.jackson.type.JavaType;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class ContainerSerializers
/*     */ {
/*     */   public static ContainerSerializerBase<?> indexedListSerializer(JavaType elemType, boolean staticTyping, TypeSerializer vts, BeanProperty property, JsonSerializer<Object> valueSerializer)
/*     */   {
/*  41 */     return new IndexedListSerializer(elemType, staticTyping, vts, property, valueSerializer);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public static ContainerSerializerBase<?> collectionSerializer(JavaType elemType, boolean staticTyping, TypeSerializer vts, BeanProperty property, JsonSerializer<Object> valueSerializer)
/*     */   {
/*  48 */     return new CollectionSerializer(elemType, staticTyping, vts, property, valueSerializer);
/*     */   }
/*     */   
/*     */ 
/*     */   public static ContainerSerializerBase<?> iteratorSerializer(JavaType elemType, boolean staticTyping, TypeSerializer vts, BeanProperty property)
/*     */   {
/*  54 */     return new IteratorSerializer(elemType, staticTyping, vts, property);
/*     */   }
/*     */   
/*     */ 
/*     */   public static ContainerSerializerBase<?> iterableSerializer(JavaType elemType, boolean staticTyping, TypeSerializer vts, BeanProperty property)
/*     */   {
/*  60 */     return new IterableSerializer(elemType, staticTyping, vts, property);
/*     */   }
/*     */   
/*     */   public static JsonSerializer<?> enumSetSerializer(JavaType enumType, BeanProperty property)
/*     */   {
/*  65 */     return new EnumSetSerializer(enumType, property);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public static abstract class AsArraySerializer<T>
/*     */     extends ContainerSerializerBase<T>
/*     */     implements ResolvableSerializer
/*     */   {
/*     */     protected final boolean _staticTyping;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     protected final JavaType _elementType;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     protected final TypeSerializer _valueTypeSerializer;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     protected JsonSerializer<Object> _elementSerializer;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     protected final BeanProperty _property;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     protected PropertySerializerMap _dynamicSerializers;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     @Deprecated
/*     */     protected AsArraySerializer(Class<?> cls, JavaType et, boolean staticTyping, TypeSerializer vts, BeanProperty property)
/*     */     {
/* 120 */       this(cls, et, staticTyping, vts, property, null);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */     protected AsArraySerializer(Class<?> cls, JavaType et, boolean staticTyping, TypeSerializer vts, BeanProperty property, JsonSerializer<Object> elementSerializer)
/*     */     {
/* 127 */       super(false);
/* 128 */       this._elementType = et;
/*     */       
/* 130 */       this._staticTyping = ((staticTyping) || ((et != null) && (et.isFinal())));
/* 131 */       this._valueTypeSerializer = vts;
/* 132 */       this._property = property;
/* 133 */       this._elementSerializer = elementSerializer;
/* 134 */       this._dynamicSerializers = PropertySerializerMap.emptyMap();
/*     */     }
/*     */     
/*     */ 
/*     */     public final void serialize(T value, JsonGenerator jgen, SerializerProvider provider)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 141 */       jgen.writeStartArray();
/* 142 */       serializeContents(value, jgen, provider);
/* 143 */       jgen.writeEndArray();
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */     public final void serializeWithType(T value, JsonGenerator jgen, SerializerProvider provider, TypeSerializer typeSer)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 151 */       typeSer.writeTypePrefixForArray(value, jgen);
/* 152 */       serializeContents(value, jgen, provider);
/* 153 */       typeSer.writeTypeSuffixForArray(value, jgen);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */     protected abstract void serializeContents(T paramT, JsonGenerator paramJsonGenerator, SerializerProvider paramSerializerProvider)
/*     */       throws IOException, JsonGenerationException;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */     public JsonNode getSchema(SerializerProvider provider, Type typeHint)
/*     */       throws JsonMappingException
/*     */     {
/* 168 */       ObjectNode o = createSchemaNode("array", true);
/* 169 */       JavaType contentType = null;
/* 170 */       if (typeHint != null) {
/* 171 */         JavaType javaType = provider.constructType(typeHint);
/* 172 */         contentType = javaType.getContentType();
/* 173 */         if ((contentType == null) && 
/* 174 */           ((typeHint instanceof ParameterizedType))) {
/* 175 */           Type[] typeArgs = ((ParameterizedType)typeHint).getActualTypeArguments();
/* 176 */           if (typeArgs.length == 1) {
/* 177 */             contentType = provider.constructType(typeArgs[0]);
/*     */           }
/*     */         }
/*     */       }
/*     */       
/* 182 */       if ((contentType == null) && (this._elementType != null)) {
/* 183 */         contentType = this._elementType;
/*     */       }
/* 185 */       if (contentType != null) {
/* 186 */         JsonNode schemaNode = null;
/*     */         
/* 188 */         if (contentType.getRawClass() != Object.class) {
/* 189 */           JsonSerializer<Object> ser = provider.findValueSerializer(contentType, this._property);
/* 190 */           if ((ser instanceof SchemaAware)) {
/* 191 */             schemaNode = ((SchemaAware)ser).getSchema(provider, null);
/*     */           }
/*     */         }
/* 194 */         if (schemaNode == null) {
/* 195 */           schemaNode = JsonSchema.getDefaultSchemaNode();
/*     */         }
/* 197 */         o.put("items", schemaNode);
/*     */       }
/* 199 */       return o;
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     public void resolve(SerializerProvider provider)
/*     */       throws JsonMappingException
/*     */     {
/* 210 */       if ((this._staticTyping) && (this._elementType != null) && (this._elementSerializer == null)) {
/* 211 */         this._elementSerializer = provider.findValueSerializer(this._elementType, this._property);
/*     */       }
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */     protected final JsonSerializer<Object> _findAndAddDynamic(PropertySerializerMap map, Class<?> type, SerializerProvider provider)
/*     */       throws JsonMappingException
/*     */     {
/* 221 */       PropertySerializerMap.SerializerAndMapResult result = map.findAndAddSerializer(type, provider, this._property);
/*     */       
/* 223 */       if (map != result.map) {
/* 224 */         this._dynamicSerializers = result.map;
/*     */       }
/* 226 */       return result.serializer;
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */     protected final JsonSerializer<Object> _findAndAddDynamic(PropertySerializerMap map, JavaType type, SerializerProvider provider)
/*     */       throws JsonMappingException
/*     */     {
/* 235 */       PropertySerializerMap.SerializerAndMapResult result = map.findAndAddSerializer(type, provider, this._property);
/* 236 */       if (map != result.map) {
/* 237 */         this._dynamicSerializers = result.map;
/*     */       }
/* 239 */       return result.serializer;
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   @JacksonStdImpl
/*     */   public static class IndexedListSerializer
/*     */     extends ContainerSerializers.AsArraySerializer<List<?>>
/*     */   {
/*     */     public IndexedListSerializer(JavaType elemType, boolean staticTyping, TypeSerializer vts, BeanProperty property, JsonSerializer<Object> valueSerializer)
/*     */     {
/* 261 */       super(elemType, staticTyping, vts, property, valueSerializer);
/*     */     }
/*     */     
/*     */     public ContainerSerializerBase<?> _withValueTypeSerializer(TypeSerializer vts)
/*     */     {
/* 266 */       return new IndexedListSerializer(this._elementType, this._staticTyping, vts, this._property, this._elementSerializer);
/*     */     }
/*     */     
/*     */ 
/*     */     public void serializeContents(List<?> value, JsonGenerator jgen, SerializerProvider provider)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 273 */       if (this._elementSerializer != null) {
/* 274 */         serializeContentsUsing(value, jgen, provider, this._elementSerializer);
/* 275 */         return;
/*     */       }
/* 277 */       if (this._valueTypeSerializer != null) {
/* 278 */         serializeTypedContents(value, jgen, provider);
/* 279 */         return;
/*     */       }
/* 281 */       int len = value.size();
/* 282 */       if (len == 0) {
/* 283 */         return;
/*     */       }
/* 285 */       int i = 0;
/*     */       try {
/* 287 */         PropertySerializerMap serializers = this._dynamicSerializers;
/* 288 */         for (; i < len; i++) {
/* 289 */           Object elem = value.get(i);
/* 290 */           if (elem == null) {
/* 291 */             provider.defaultSerializeNull(jgen);
/*     */           } else {
/* 293 */             Class<?> cc = elem.getClass();
/* 294 */             JsonSerializer<Object> serializer = serializers.serializerFor(cc);
/* 295 */             if (serializer == null)
/*     */             {
/* 297 */               if (this._elementType.hasGenericTypes()) {
/* 298 */                 serializer = _findAndAddDynamic(serializers, this._elementType.forcedNarrowBy(cc), provider);
/*     */               } else {
/* 300 */                 serializer = _findAndAddDynamic(serializers, cc, provider);
/*     */               }
/* 302 */               serializers = this._dynamicSerializers;
/*     */             }
/* 304 */             serializer.serialize(elem, jgen, provider);
/*     */           }
/*     */         }
/*     */       }
/*     */       catch (Exception e) {
/* 309 */         wrapAndThrow(provider, e, value, i);
/*     */       }
/*     */     }
/*     */     
/*     */ 
/*     */     public void serializeContentsUsing(List<?> value, JsonGenerator jgen, SerializerProvider provider, JsonSerializer<Object> ser)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 317 */       int len = value.size();
/* 318 */       if (len == 0) {
/* 319 */         return;
/*     */       }
/* 321 */       TypeSerializer typeSer = this._valueTypeSerializer;
/* 322 */       for (int i = 0; i < len; i++) {
/* 323 */         Object elem = value.get(i);
/*     */         try {
/* 325 */           if (elem == null) {
/* 326 */             provider.defaultSerializeNull(jgen);
/* 327 */           } else if (typeSer == null) {
/* 328 */             ser.serialize(elem, jgen, provider);
/*     */           } else {
/* 330 */             ser.serializeWithType(elem, jgen, provider, typeSer);
/*     */           }
/*     */         }
/*     */         catch (Exception e) {
/* 334 */           wrapAndThrow(provider, e, value, i);
/*     */         }
/*     */       }
/*     */     }
/*     */     
/*     */     public void serializeTypedContents(List<?> value, JsonGenerator jgen, SerializerProvider provider)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 342 */       int len = value.size();
/* 343 */       if (len == 0) {
/* 344 */         return;
/*     */       }
/* 346 */       int i = 0;
/*     */       try {
/* 348 */         TypeSerializer typeSer = this._valueTypeSerializer;
/* 349 */         PropertySerializerMap serializers = this._dynamicSerializers;
/* 350 */         for (; i < len; i++) {
/* 351 */           Object elem = value.get(i);
/* 352 */           if (elem == null) {
/* 353 */             provider.defaultSerializeNull(jgen);
/*     */           } else {
/* 355 */             Class<?> cc = elem.getClass();
/* 356 */             JsonSerializer<Object> serializer = serializers.serializerFor(cc);
/* 357 */             if (serializer == null)
/*     */             {
/* 359 */               if (this._elementType.hasGenericTypes()) {
/* 360 */                 serializer = _findAndAddDynamic(serializers, this._elementType.forcedNarrowBy(cc), provider);
/*     */               } else {
/* 362 */                 serializer = _findAndAddDynamic(serializers, cc, provider);
/*     */               }
/* 364 */               serializers = this._dynamicSerializers;
/*     */             }
/* 366 */             serializer.serializeWithType(elem, jgen, provider, typeSer);
/*     */           }
/*     */         }
/*     */       }
/*     */       catch (Exception e) {
/* 371 */         wrapAndThrow(provider, e, value, i);
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   @JacksonStdImpl
/*     */   public static class CollectionSerializer
/*     */     extends ContainerSerializers.AsArraySerializer<Collection<?>>
/*     */   {
/*     */     @Deprecated
/*     */     public CollectionSerializer(JavaType elemType, boolean staticTyping, TypeSerializer vts, BeanProperty property)
/*     */     {
/* 394 */       this(elemType, staticTyping, vts, property, null);
/*     */     }
/*     */     
/*     */ 
/*     */     public CollectionSerializer(JavaType elemType, boolean staticTyping, TypeSerializer vts, BeanProperty property, JsonSerializer<Object> valueSerializer)
/*     */     {
/* 400 */       super(elemType, staticTyping, vts, property, valueSerializer);
/*     */     }
/*     */     
/*     */     public ContainerSerializerBase<?> _withValueTypeSerializer(TypeSerializer vts)
/*     */     {
/* 405 */       return new CollectionSerializer(this._elementType, this._staticTyping, vts, this._property);
/*     */     }
/*     */     
/*     */ 
/*     */     public void serializeContents(Collection<?> value, JsonGenerator jgen, SerializerProvider provider)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 412 */       if (this._elementSerializer != null) {
/* 413 */         serializeContentsUsing(value, jgen, provider, this._elementSerializer);
/* 414 */         return;
/*     */       }
/* 416 */       Iterator<?> it = value.iterator();
/* 417 */       if (!it.hasNext()) {
/* 418 */         return;
/*     */       }
/* 420 */       PropertySerializerMap serializers = this._dynamicSerializers;
/* 421 */       TypeSerializer typeSer = this._valueTypeSerializer;
/*     */       
/* 423 */       int i = 0;
/*     */       try {
/*     */         do {
/* 426 */           Object elem = it.next();
/* 427 */           if (elem == null) {
/* 428 */             provider.defaultSerializeNull(jgen);
/*     */           } else {
/* 430 */             Class<?> cc = elem.getClass();
/* 431 */             JsonSerializer<Object> serializer = serializers.serializerFor(cc);
/* 432 */             if (serializer == null)
/*     */             {
/* 434 */               if (this._elementType.hasGenericTypes()) {
/* 435 */                 serializer = _findAndAddDynamic(serializers, this._elementType.forcedNarrowBy(cc), provider);
/*     */               } else {
/* 437 */                 serializer = _findAndAddDynamic(serializers, cc, provider);
/*     */               }
/* 439 */               serializers = this._dynamicSerializers;
/*     */             }
/* 441 */             if (typeSer == null) {
/* 442 */               serializer.serialize(elem, jgen, provider);
/*     */             } else {
/* 444 */               serializer.serializeWithType(elem, jgen, provider, typeSer);
/*     */             }
/*     */           }
/* 447 */           i++;
/* 448 */         } while (it.hasNext());
/*     */       }
/*     */       catch (Exception e) {
/* 451 */         wrapAndThrow(provider, e, value, i);
/*     */       }
/*     */     }
/*     */     
/*     */ 
/*     */     public void serializeContentsUsing(Collection<?> value, JsonGenerator jgen, SerializerProvider provider, JsonSerializer<Object> ser)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 459 */       Iterator<?> it = value.iterator();
/* 460 */       if (it.hasNext()) {
/* 461 */         TypeSerializer typeSer = this._valueTypeSerializer;
/* 462 */         int i = 0;
/*     */         do {
/* 464 */           Object elem = it.next();
/*     */           try {
/* 466 */             if (elem == null) {
/* 467 */               provider.defaultSerializeNull(jgen);
/*     */             }
/* 469 */             else if (typeSer == null) {
/* 470 */               ser.serialize(elem, jgen, provider);
/*     */             } else {
/* 472 */               ser.serializeWithType(elem, jgen, provider, typeSer);
/*     */             }
/*     */             
/* 475 */             i++;
/*     */           }
/*     */           catch (Exception e) {
/* 478 */             wrapAndThrow(provider, e, value, i);
/*     */           }
/* 480 */         } while (it.hasNext());
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   @JacksonStdImpl
/*     */   public static class IteratorSerializer
/*     */     extends ContainerSerializers.AsArraySerializer<Iterator<?>>
/*     */   {
/*     */     public IteratorSerializer(JavaType elemType, boolean staticTyping, TypeSerializer vts, BeanProperty property)
/*     */     {
/* 492 */       super(elemType, staticTyping, vts, property);
/*     */     }
/*     */     
/*     */     public ContainerSerializerBase<?> _withValueTypeSerializer(TypeSerializer vts)
/*     */     {
/* 497 */       return new IteratorSerializer(this._elementType, this._staticTyping, vts, this._property);
/*     */     }
/*     */     
/*     */ 
/*     */     public void serializeContents(Iterator<?> value, JsonGenerator jgen, SerializerProvider provider)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 504 */       if (value.hasNext()) {
/* 505 */         TypeSerializer typeSer = this._valueTypeSerializer;
/* 506 */         JsonSerializer<Object> prevSerializer = null;
/* 507 */         Class<?> prevClass = null;
/*     */         do {
/* 509 */           Object elem = value.next();
/* 510 */           if (elem == null) {
/* 511 */             provider.defaultSerializeNull(jgen);
/*     */           }
/*     */           else {
/* 514 */             Class<?> cc = elem.getClass();
/*     */             JsonSerializer<Object> currSerializer;
/* 516 */             JsonSerializer<Object> currSerializer; if (cc == prevClass) {
/* 517 */               currSerializer = prevSerializer;
/*     */             } else {
/* 519 */               currSerializer = provider.findValueSerializer(cc, this._property);
/* 520 */               prevSerializer = currSerializer;
/* 521 */               prevClass = cc;
/*     */             }
/* 523 */             if (typeSer == null) {
/* 524 */               currSerializer.serialize(elem, jgen, provider);
/*     */             } else {
/* 526 */               currSerializer.serializeWithType(elem, jgen, provider, typeSer);
/*     */             }
/*     */           }
/* 529 */         } while (value.hasNext());
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */   @JacksonStdImpl
/*     */   public static class IterableSerializer
/*     */     extends ContainerSerializers.AsArraySerializer<Iterable<?>>
/*     */   {
/*     */     public IterableSerializer(JavaType elemType, boolean staticTyping, TypeSerializer vts, BeanProperty property)
/*     */     {
/* 540 */       super(elemType, staticTyping, vts, property);
/*     */     }
/*     */     
/*     */     public ContainerSerializerBase<?> _withValueTypeSerializer(TypeSerializer vts)
/*     */     {
/* 545 */       return new IterableSerializer(this._elementType, this._staticTyping, vts, this._property);
/*     */     }
/*     */     
/*     */ 
/*     */     public void serializeContents(Iterable<?> value, JsonGenerator jgen, SerializerProvider provider)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 552 */       Iterator<?> it = value.iterator();
/* 553 */       if (it.hasNext()) {
/* 554 */         TypeSerializer typeSer = this._valueTypeSerializer;
/* 555 */         JsonSerializer<Object> prevSerializer = null;
/* 556 */         Class<?> prevClass = null;
/*     */         do
/*     */         {
/* 559 */           Object elem = it.next();
/* 560 */           if (elem == null) {
/* 561 */             provider.defaultSerializeNull(jgen);
/*     */           }
/*     */           else {
/* 564 */             Class<?> cc = elem.getClass();
/*     */             JsonSerializer<Object> currSerializer;
/* 566 */             JsonSerializer<Object> currSerializer; if (cc == prevClass) {
/* 567 */               currSerializer = prevSerializer;
/*     */             } else {
/* 569 */               currSerializer = provider.findValueSerializer(cc, this._property);
/* 570 */               prevSerializer = currSerializer;
/* 571 */               prevClass = cc;
/*     */             }
/* 573 */             if (typeSer == null) {
/* 574 */               currSerializer.serialize(elem, jgen, provider);
/*     */             } else {
/* 576 */               currSerializer.serializeWithType(elem, jgen, provider, typeSer);
/*     */             }
/*     */           }
/* 579 */         } while (it.hasNext());
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */   public static class EnumSetSerializer
/*     */     extends ContainerSerializers.AsArraySerializer<EnumSet<? extends Enum<?>>>
/*     */   {
/*     */     public EnumSetSerializer(JavaType elemType, BeanProperty property)
/*     */     {
/* 589 */       super(elemType, true, null, property);
/*     */     }
/*     */     
/*     */ 
/*     */     public ContainerSerializerBase<?> _withValueTypeSerializer(TypeSerializer vts)
/*     */     {
/* 595 */       return this;
/*     */     }
/*     */     
/*     */ 
/*     */     public void serializeContents(EnumSet<? extends Enum<?>> value, JsonGenerator jgen, SerializerProvider provider)
/*     */       throws IOException, JsonGenerationException
/*     */     {
/* 602 */       JsonSerializer<Object> enumSer = this._elementSerializer;
/*     */       
/*     */ 
/*     */ 
/*     */ 
/* 607 */       for (Enum<?> en : value) {
/* 608 */         if (enumSer == null)
/*     */         {
/*     */ 
/*     */ 
/* 612 */           enumSer = provider.findValueSerializer(en.getDeclaringClass(), this._property);
/*     */         }
/* 614 */         enumSer.serialize(en, jgen, provider);
/*     */       }
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\codehaus\jackson\map\ser\ContainerSerializers.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */