/*     */ package org.codehaus.jackson.map.type;
/*     */ 
/*     */ import java.util.Collection;
/*     */ import java.util.Map;
/*     */ import org.codehaus.jackson.type.JavaType;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class SimpleType
/*     */   extends TypeBase
/*     */ {
/*     */   protected final JavaType[] _typeParameters;
/*     */   protected final String[] _typeNames;
/*     */   
/*     */   protected SimpleType(Class<?> cls)
/*     */   {
/*  34 */     this(cls, null, null);
/*     */   }
/*     */   
/*     */   protected SimpleType(Class<?> cls, String[] typeNames, JavaType[] typeParams)
/*     */   {
/*  39 */     super(cls, 0);
/*  40 */     if ((typeNames == null) || (typeNames.length == 0)) {
/*  41 */       this._typeNames = null;
/*  42 */       this._typeParameters = null;
/*     */     } else {
/*  44 */       this._typeNames = typeNames;
/*  45 */       this._typeParameters = typeParams;
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public static SimpleType constructUnsafe(Class<?> raw)
/*     */   {
/*  56 */     return new SimpleType(raw, null, null);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected JavaType _narrow(Class<?> subclass)
/*     */   {
/*  67 */     if (this._class == Iterable.class)
/*     */     {
/*  69 */       if (Collection.class.isAssignableFrom(subclass)) {
/*  70 */         JavaType elemType = this._typeParameters == null ? constructUnsafe(Object.class) : this._typeParameters[0];
/*     */         
/*     */ 
/*  73 */         return CollectionType.construct(subclass, elemType);
/*     */       }
/*     */     }
/*  76 */     return new SimpleType(subclass, this._typeNames, this._typeParameters);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public JavaType narrowContentsBy(Class<?> subclass)
/*     */   {
/*  83 */     throw new IllegalArgumentException("Internal error: SimpleType.narrowContentsBy() should never be called");
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public JavaType widenContentsBy(Class<?> subclass)
/*     */   {
/*  90 */     throw new IllegalArgumentException("Internal error: SimpleType.widenContentsBy() should never be called");
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public static SimpleType construct(Class<?> cls)
/*     */   {
/*  98 */     if (Map.class.isAssignableFrom(cls)) {
/*  99 */       throw new IllegalArgumentException("Can not construct SimpleType for a Map (class: " + cls.getName() + ")");
/*     */     }
/* 101 */     if (Collection.class.isAssignableFrom(cls)) {
/* 102 */       throw new IllegalArgumentException("Can not construct SimpleType for a Collection (class: " + cls.getName() + ")");
/*     */     }
/*     */     
/* 105 */     if (cls.isArray()) {
/* 106 */       throw new IllegalArgumentException("Can not construct SimpleType for an array (class: " + cls.getName() + ")");
/*     */     }
/* 108 */     return new SimpleType(cls);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public SimpleType withTypeHandler(Object h)
/*     */   {
/* 115 */     SimpleType newInstance = new SimpleType(this._class, this._typeNames, this._typeParameters);
/* 116 */     newInstance._typeHandler = h;
/* 117 */     return newInstance;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public JavaType withContentTypeHandler(Object h)
/*     */   {
/* 125 */     throw new IllegalArgumentException("Simple types have no content types; can not call withContenTypeHandler()");
/*     */   }
/*     */   
/*     */ 
/*     */   protected String buildCanonicalName()
/*     */   {
/* 131 */     StringBuilder sb = new StringBuilder();
/* 132 */     sb.append(this._class.getName());
/* 133 */     if ((this._typeParameters != null) && (this._typeParameters.length > 0)) {
/* 134 */       sb.append('<');
/* 135 */       boolean first = true;
/* 136 */       for (JavaType t : this._typeParameters) {
/* 137 */         if (first) {
/* 138 */           first = false;
/*     */         } else {
/* 140 */           sb.append(',');
/*     */         }
/* 142 */         sb.append(t.toCanonical());
/*     */       }
/* 144 */       sb.append('>');
/*     */     }
/* 146 */     return sb.toString();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public boolean isContainerType()
/*     */   {
/* 156 */     return false;
/*     */   }
/*     */   
/*     */   public int containedTypeCount() {
/* 160 */     return this._typeParameters == null ? 0 : this._typeParameters.length;
/*     */   }
/*     */   
/*     */ 
/*     */   public JavaType containedType(int index)
/*     */   {
/* 166 */     if ((index < 0) || (this._typeParameters == null) || (index >= this._typeParameters.length)) {
/* 167 */       return null;
/*     */     }
/* 169 */     return this._typeParameters[index];
/*     */   }
/*     */   
/*     */ 
/*     */   public String containedTypeName(int index)
/*     */   {
/* 175 */     if ((index < 0) || (this._typeNames == null) || (index >= this._typeNames.length)) {
/* 176 */       return null;
/*     */     }
/* 178 */     return this._typeNames[index];
/*     */   }
/*     */   
/*     */   public StringBuilder getErasedSignature(StringBuilder sb)
/*     */   {
/* 183 */     return _classSignature(this._class, sb, true);
/*     */   }
/*     */   
/*     */ 
/*     */   public StringBuilder getGenericSignature(StringBuilder sb)
/*     */   {
/* 189 */     _classSignature(this._class, sb, false);
/* 190 */     if (this._typeParameters != null) {
/* 191 */       sb.append('<');
/* 192 */       for (JavaType param : this._typeParameters) {
/* 193 */         sb = param.getGenericSignature(sb);
/*     */       }
/* 195 */       sb.append('>');
/*     */     }
/* 197 */     sb.append(';');
/* 198 */     return sb;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public String toString()
/*     */   {
/* 210 */     StringBuilder sb = new StringBuilder(40);
/* 211 */     sb.append("[simple type, class ").append(buildCanonicalName()).append(']');
/* 212 */     return sb.toString();
/*     */   }
/*     */   
/*     */ 
/*     */   public boolean equals(Object o)
/*     */   {
/* 218 */     if (o == this) return true;
/* 219 */     if (o == null) return false;
/* 220 */     if (o.getClass() != getClass()) { return false;
/*     */     }
/* 222 */     SimpleType other = (SimpleType)o;
/*     */     
/*     */ 
/* 225 */     if (other._class != this._class) { return false;
/*     */     }
/*     */     
/* 228 */     JavaType[] p1 = this._typeParameters;
/* 229 */     JavaType[] p2 = other._typeParameters;
/* 230 */     if (p1 == null) {
/* 231 */       return (p2 == null) || (p2.length == 0);
/*     */     }
/* 233 */     if (p2 == null) { return false;
/*     */     }
/* 235 */     if (p1.length != p2.length) return false;
/* 236 */     int i = 0; for (int len = p1.length; i < len; i++) {
/* 237 */       if (!p1[i].equals(p2[i])) {
/* 238 */         return false;
/*     */       }
/*     */     }
/* 241 */     return true;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\codehaus\jackson\map\type\SimpleType.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */