/*      */ package org.codehaus.janino;
/*      */ 
/*      */ import java.util.ArrayList;
/*      */ import java.util.Collection;
/*      */ import java.util.Collections;
/*      */ import java.util.HashMap;
/*      */ import java.util.Iterator;
/*      */ import java.util.List;
/*      */ import java.util.Map;
/*      */ import java.util.SortedMap;
/*      */ import java.util.TreeMap;
/*      */ import org.codehaus.commons.compiler.CompileException;
/*      */ import org.codehaus.commons.compiler.Location;
/*      */ import org.codehaus.janino.util.Traverser;
/*      */ import org.codehaus.janino.util.iterator.ReverseListIterator;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public final class Java
/*      */ {
/*      */   public static abstract interface Scope
/*      */   {
/*      */     public abstract Scope getEnclosingScope();
/*      */   }
/*      */   
/*      */   public static abstract interface Locatable
/*      */   {
/*      */     public abstract Location getLocation();
/*      */     
/*      */     public abstract void throwCompileException(String paramString)
/*      */       throws CompileException;
/*      */   }
/*      */   
/*      */   public static abstract class Located
/*      */     implements Java.Locatable
/*      */   {
/*   86 */     public static Located NOWHERE = new Located(Location.NOWHERE) {};
/*      */     private final Location location;
/*      */     
/*      */     protected Located(Location location)
/*      */     {
/*   91 */       this.location = location;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*   96 */     public Location getLocation() { return this.location; }
/*      */     
/*   98 */     public void throwCompileException(String message) throws CompileException { throw new CompileException(message, this.location); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class CompilationUnit
/*      */     implements Java.Scope
/*      */   {
/*      */     public String optionalFileName;
/*      */     
/*  107 */     public Java.PackageDeclaration optionalPackageDeclaration = null;
/*  108 */     public final List importDeclarations = new ArrayList();
/*  109 */     public final List packageMemberTypeDeclarations = new ArrayList();
/*      */     
/*      */     public CompilationUnit(String optionalFileName) {
/*  112 */       this.optionalFileName = optionalFileName;
/*      */     }
/*      */     
/*      */     public Java.Scope getEnclosingScope()
/*      */     {
/*  117 */       throw new JaninoRuntimeException("A compilation unit has no enclosing scope");
/*      */     }
/*      */     
/*      */     public void setPackageDeclaration(Java.PackageDeclaration packageDeclaration) {
/*  121 */       if (this.optionalPackageDeclaration != null) {
/*  122 */         throw new JaninoRuntimeException("Re-setting package declaration");
/*      */       }
/*  124 */       this.optionalPackageDeclaration = packageDeclaration;
/*      */     }
/*      */     
/*      */ 
/*      */     public void addImportDeclaration(ImportDeclaration id)
/*      */     {
/*  130 */       this.importDeclarations.add(id);
/*      */     }
/*      */     
/*      */     public void addPackageMemberTypeDeclaration(Java.PackageMemberTypeDeclaration pmtd) {
/*  134 */       this.packageMemberTypeDeclarations.add(pmtd);
/*  135 */       pmtd.setDeclaringCompilationUnit(this);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     public Java.PackageMemberTypeDeclaration[] getPackageMemberTypeDeclarations()
/*      */     {
/*  142 */       return (Java.PackageMemberTypeDeclaration[])this.packageMemberTypeDeclarations.toArray(new Java.PackageMemberTypeDeclaration[this.packageMemberTypeDeclarations.size()]);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public Java.PackageMemberTypeDeclaration getPackageMemberTypeDeclaration(String name)
/*      */     {
/*  153 */       for (Iterator it = this.packageMemberTypeDeclarations.iterator(); it.hasNext();) {
/*  154 */         Java.PackageMemberTypeDeclaration pmtd = (Java.PackageMemberTypeDeclaration)it.next();
/*  155 */         if (pmtd.getName().equals(name)) return pmtd;
/*      */       }
/*  157 */       return null;
/*      */     }
/*      */     
/*      */ 
/*      */     public static class SingleTypeImportDeclaration
/*      */       extends Java.CompilationUnit.ImportDeclaration
/*      */     {
/*      */       public final String[] identifiers;
/*      */       
/*      */       public SingleTypeImportDeclaration(Location location, String[] identifiers)
/*      */       {
/*  168 */         super();
/*  169 */         this.identifiers = identifiers; }
/*      */       
/*  171 */       public final void accept(Visitor.ImportVisitor visitor) { visitor.visitSingleTypeImportDeclaration(this); }
/*      */       
/*  173 */       public String toString() { return "import " + Java.join(this.identifiers, ".") + ';'; }
/*      */     }
/*      */     
/*      */ 
/*      */     public static class TypeImportOnDemandDeclaration
/*      */       extends Java.CompilationUnit.ImportDeclaration
/*      */     {
/*      */       public final String[] identifiers;
/*      */       
/*      */ 
/*      */       public TypeImportOnDemandDeclaration(Location location, String[] identifiers)
/*      */       {
/*  185 */         super();
/*  186 */         this.identifiers = identifiers;
/*      */       }
/*      */       
/*  189 */       public final void accept(Visitor.ImportVisitor visitor) { visitor.visitTypeImportOnDemandDeclaration(this); }
/*      */       
/*      */       public String toString() {
/*  192 */         return "import " + Java.join(this.identifiers, ".") + ".*;";
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */     public static class SingleStaticImportDeclaration
/*      */       extends Java.CompilationUnit.ImportDeclaration
/*      */     {
/*      */       public final String[] identifiers;
/*      */       
/*      */       public SingleStaticImportDeclaration(Location location, String[] identifiers)
/*      */       {
/*  204 */         super();
/*  205 */         this.identifiers = identifiers;
/*      */       }
/*      */       
/*  208 */       public final void accept(Visitor.ImportVisitor visitor) { visitor.visitSingleStaticImportDeclaration(this); }
/*      */     }
/*      */     
/*      */ 
/*      */     public static class StaticImportOnDemandDeclaration
/*      */       extends Java.CompilationUnit.ImportDeclaration
/*      */     {
/*      */       public final String[] identifiers;
/*      */       
/*      */ 
/*      */       public StaticImportOnDemandDeclaration(Location location, String[] identifiers)
/*      */       {
/*  220 */         super();
/*  221 */         this.identifiers = identifiers;
/*      */       }
/*      */       
/*  224 */       public final void accept(Visitor.ImportVisitor visitor) { visitor.visitStaticImportOnDemandDeclaration(this); }
/*      */     }
/*      */     
/*      */     public static abstract class ImportDeclaration extends Java.Located
/*      */     {
/*      */       public ImportDeclaration(Location location) {
/*  230 */         super();
/*      */       }
/*      */       
/*      */       public abstract void accept(Visitor.ImportVisitor paramImportVisitor);
/*      */     }
/*      */   }
/*      */   
/*      */   public static class PackageDeclaration
/*      */     extends Java.Located
/*      */   {
/*      */     public final String packageName;
/*      */     
/*      */     public PackageDeclaration(Location location, String packageName)
/*      */     {
/*  244 */       super();
/*  245 */       this.packageName = packageName;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static abstract interface TypeDeclaration
/*      */     extends Java.Locatable, Java.Scope
/*      */   {
/*      */     public abstract short getModifiers();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract Java.MemberTypeDeclaration getMemberTypeDeclaration(String paramString);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract Collection getMemberTypeDeclarations();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract Java.MethodDeclarator getMethodDeclaration(String paramString);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract List getMethodDeclarations();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract String getClassName();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract String createLocalTypeName(String paramString);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract String createAnonymousClassName();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract void accept(Visitor.TypeDeclarationVisitor paramTypeDeclarationVisitor);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static abstract interface DocCommentable
/*      */   {
/*      */     public abstract String getDocComment();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract boolean hasDeprecatedDocTag();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static abstract interface PackageMemberTypeDeclaration
/*      */     extends Java.NamedTypeDeclaration
/*      */   {
/*      */     public abstract void setDeclaringCompilationUnit(Java.CompilationUnit paramCompilationUnit);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public abstract Java.CompilationUnit getDeclaringCompilationUnit();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static abstract interface MemberTypeDeclaration
/*      */     extends Java.NamedTypeDeclaration, Java.TypeBodyDeclaration
/*      */   {}
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static abstract interface NamedTypeDeclaration
/*      */     extends Java.TypeDeclaration
/*      */   {
/*      */     public abstract String getName();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   static abstract interface InnerClassDeclaration
/*      */     extends Java.TypeDeclaration
/*      */   {
/*      */     public abstract void defineSyntheticField(IClass.IField paramIField)
/*      */       throws CompileException;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static abstract class AbstractTypeDeclaration
/*      */     implements Java.TypeDeclaration
/*      */   {
/*      */     private final Location location;
/*      */     
/*      */ 
/*      */ 
/*      */     private final short modifiers;
/*      */     
/*      */ 
/*      */ 
/*  372 */     private final List declaredMethods = new ArrayList();
/*  373 */     private final List declaredClassesAndInterfaces = new ArrayList();
/*  374 */     private Java.Scope enclosingScope = null;
/*      */     
/*  376 */     IClass resolvedType = null;
/*      */     
/*      */ 
/*      */ 
/*      */     public AbstractTypeDeclaration(Location location, short modifiers)
/*      */     {
/*  382 */       this.location = location;
/*  383 */       this.modifiers = modifiers;
/*      */     }
/*      */     
/*      */     public short getModifiers() {
/*  387 */       return this.modifiers;
/*      */     }
/*      */     
/*      */     public void setEnclosingScope(Java.Scope enclosingScope)
/*      */     {
/*  392 */       if ((this.enclosingScope != null) && (enclosingScope != this.enclosingScope)) {
/*  393 */         throw new JaninoRuntimeException("Enclosing scope is already set for type declaration \"" + toString() + "\" at " + getLocation());
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  400 */       this.enclosingScope = enclosingScope;
/*      */     }
/*      */     
/*  403 */     public Java.Scope getEnclosingScope() { return this.enclosingScope; }
/*      */     
/*      */     public void invalidateMethodCaches()
/*      */     {
/*  407 */       if (this.resolvedType != null) {
/*  408 */         this.resolvedType.declaredIMethods = null;
/*  409 */         this.resolvedType.declaredIMethodCache = null;
/*      */       }
/*      */     }
/*      */     
/*      */     public void addMemberTypeDeclaration(Java.MemberTypeDeclaration mcoid)
/*      */     {
/*  415 */       this.declaredClassesAndInterfaces.add(mcoid);
/*  416 */       mcoid.setDeclaringType(this);
/*      */     }
/*      */     
/*  419 */     public Collection getMemberTypeDeclarations() { return this.declaredClassesAndInterfaces; }
/*      */     
/*      */     public Java.MemberTypeDeclaration getMemberTypeDeclaration(String name) {
/*  422 */       for (Iterator it = this.declaredClassesAndInterfaces.iterator(); it.hasNext();) {
/*  423 */         Java.MemberTypeDeclaration mtd = (Java.MemberTypeDeclaration)it.next();
/*  424 */         if (mtd.getName().equals(name)) return mtd;
/*      */       }
/*  426 */       return null;
/*      */     }
/*      */     
/*      */     public void addDeclaredMethod(Java.MethodDeclarator method) {
/*  430 */       this.declaredMethods.add(method);
/*  431 */       method.setDeclaringType(this);
/*      */     }
/*      */     
/*      */     public Java.MethodDeclarator getMethodDeclaration(String name) {
/*  435 */       for (Iterator it = this.declaredMethods.iterator(); it.hasNext();) {
/*  436 */         Java.MethodDeclarator md = (Java.MethodDeclarator)it.next();
/*  437 */         if (md.name.equals(name)) return md;
/*      */       }
/*  439 */       return null;
/*      */     }
/*      */     
/*      */     public List getMethodDeclarations() {
/*  443 */       return this.declaredMethods;
/*      */     }
/*      */     
/*      */     public String createLocalTypeName(String localTypeName) {
/*  447 */       return getClassName() + '$' + ++this.localClassCount + '$' + localTypeName;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public String createAnonymousClassName()
/*      */     {
/*  456 */       return getClassName() + '$' + ++this.anonymousClassCount;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  464 */     public Location getLocation() { return this.location; }
/*      */     
/*  466 */     public void throwCompileException(String message) throws CompileException { throw new CompileException(message, this.location); }
/*      */     
/*      */     public abstract String toString();
/*      */     
/*      */     public abstract void accept(Visitor.TypeDeclarationVisitor paramTypeDeclarationVisitor);
/*  471 */     public int anonymousClassCount = 0;
/*  472 */     public int localClassCount = 0;
/*      */     
/*      */     public abstract String getClassName(); }
/*      */   
/*  476 */   public static abstract class ClassDeclaration extends Java.AbstractTypeDeclaration { public final List constructors = new ArrayList();
/*  477 */     public final List variableDeclaratorsAndInitializers = new ArrayList();
/*      */     
/*      */ 
/*      */ 
/*      */     public ClassDeclaration(Location location, short modifiers)
/*      */     {
/*  483 */       super(modifiers);
/*      */     }
/*      */     
/*      */     public void addConstructor(Java.ConstructorDeclarator cd) {
/*  487 */       this.constructors.add(cd);
/*  488 */       cd.setDeclaringType(this);
/*      */     }
/*      */     
/*  491 */     public void addVariableDeclaratorOrInitializer(Java.TypeBodyDeclaration tbd) { this.variableDeclaratorsAndInitializers.add(tbd);
/*  492 */       tbd.setDeclaringType(this);
/*      */       
/*      */ 
/*  495 */       if (this.resolvedType != null) { this.resolvedType.clearIFieldCaches();
/*      */       }
/*      */     }
/*      */     
/*      */     public void defineSyntheticField(IClass.IField iField)
/*      */       throws CompileException
/*      */     {
/*  502 */       if (!(this instanceof Java.InnerClassDeclaration)) { throw new JaninoRuntimeException();
/*      */       }
/*  504 */       IClass.IField if2 = (IClass.IField)this.syntheticFields.get(iField.getName());
/*  505 */       if (if2 != null) {
/*  506 */         if (iField.getType() != if2.getType()) throw new JaninoRuntimeException();
/*  507 */         return;
/*      */       }
/*  509 */       this.syntheticFields.put(iField.getName(), iField);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     Java.ConstructorDeclarator[] getConstructors()
/*      */     {
/*  516 */       if (this.constructors.isEmpty()) {
/*  517 */         Java.ConstructorDeclarator defaultConstructor = new Java.ConstructorDeclarator(getLocation(), null, (short)1, new Java.FunctionDeclarator.FormalParameter[0], new Java.Type[0], null, Collections.EMPTY_LIST);
/*      */         
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  526 */         defaultConstructor.setDeclaringType(this);
/*  527 */         return new Java.ConstructorDeclarator[] { defaultConstructor };
/*      */       }
/*      */       
/*  530 */       return (Java.ConstructorDeclarator[])this.constructors.toArray(new Java.ConstructorDeclarator[this.constructors.size()]);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*  536 */     final SortedMap syntheticFields = new TreeMap();
/*      */   }
/*      */   
/*      */   public static final class AnonymousClassDeclaration
/*      */     extends Java.ClassDeclaration implements Java.InnerClassDeclaration
/*      */   {
/*      */     public final Java.Type baseType;
/*      */     
/*      */     public AnonymousClassDeclaration(Location location, Java.Type baseType)
/*      */     {
/*  546 */       super((short)18);
/*      */       
/*      */ 
/*      */ 
/*  550 */       (this.baseType = baseType).setEnclosingScope(new Java.EnclosingScopeOfTypeDeclaration(this));
/*      */     }
/*      */     
/*      */     public void accept(Visitor.TypeDeclarationVisitor visitor) {
/*  554 */       visitor.visitAnonymousClassDeclaration(this);
/*      */     }
/*      */     
/*      */     public String getClassName()
/*      */     {
/*  559 */       if (this.myName == null) {
/*  560 */         Java.Scope s = getEnclosingScope();
/*  561 */         while (!(s instanceof Java.TypeDeclaration)) s = s.getEnclosingScope();
/*  562 */         this.myName = ((Java.TypeDeclaration)s).createAnonymousClassName();
/*      */       }
/*  564 */       return this.myName; }
/*      */     
/*  566 */     private String myName = null;
/*  567 */     public String toString() { return getClassName(); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static abstract class NamedClassDeclaration
/*      */     extends Java.ClassDeclaration
/*      */     implements Java.NamedTypeDeclaration, Java.DocCommentable
/*      */   {
/*      */     private final String optionalDocComment;
/*      */     
/*      */     public final String name;
/*      */     
/*      */     public final Java.Type optionalExtendedType;
/*      */     
/*      */     public final Java.Type[] implementedTypes;
/*      */     
/*      */ 
/*      */     public NamedClassDeclaration(Location location, String optionalDocComment, short modifiers, String name, Java.Type optionalExtendedType, Java.Type[] implementedTypes)
/*      */     {
/*  586 */       super(modifiers);
/*  587 */       this.optionalDocComment = optionalDocComment;
/*  588 */       this.name = name;
/*  589 */       this.optionalExtendedType = optionalExtendedType;
/*  590 */       if (optionalExtendedType != null) {
/*  591 */         optionalExtendedType.setEnclosingScope(new Java.EnclosingScopeOfTypeDeclaration(this));
/*      */       }
/*  593 */       this.implementedTypes = implementedTypes;
/*  594 */       for (int i = 0; i < implementedTypes.length; i++)
/*  595 */         implementedTypes[i].setEnclosingScope(new Java.EnclosingScopeOfTypeDeclaration(this));
/*      */     }
/*      */     
/*      */     public String toString() {
/*  599 */       return this.name;
/*      */     }
/*      */     
/*  602 */     public String getName() { return this.name; }
/*      */     
/*      */ 
/*  605 */     public String getDocComment() { return this.optionalDocComment; }
/*      */     
/*  607 */     public boolean hasDeprecatedDocTag() { return (this.optionalDocComment != null) && (this.optionalDocComment.indexOf("@deprecated") != -1); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class EnclosingScopeOfTypeDeclaration
/*      */     implements Java.Scope
/*      */   {
/*      */     public final Java.TypeDeclaration typeDeclaration;
/*      */     
/*      */ 
/*      */ 
/*  619 */     public EnclosingScopeOfTypeDeclaration(Java.TypeDeclaration typeDeclaration) { this.typeDeclaration = typeDeclaration; }
/*      */     
/*  621 */     public Java.Scope getEnclosingScope() { return this.typeDeclaration.getEnclosingScope(); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class MemberClassDeclaration
/*      */     extends Java.NamedClassDeclaration
/*      */     implements Java.MemberTypeDeclaration, Java.InnerClassDeclaration
/*      */   {
/*      */     public MemberClassDeclaration(Location location, String optionalDocComment, short modifiers, String name, Java.Type optionalExtendedType, Java.Type[] implementedTypes)
/*      */     {
/*  635 */       super(optionalDocComment, modifiers, name, optionalExtendedType, implementedTypes);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public void setDeclaringType(Java.TypeDeclaration declaringType)
/*      */     {
/*  647 */       setEnclosingScope(declaringType);
/*      */     }
/*      */     
/*  650 */     public Java.TypeDeclaration getDeclaringType() { return (Java.TypeDeclaration)getEnclosingScope(); }
/*      */     
/*      */     public boolean isStatic() {
/*  653 */       return (getModifiers() & 0x8) != 0;
/*      */     }
/*      */     
/*      */     public String getClassName()
/*      */     {
/*  658 */       return getDeclaringType().getClassName() + '$' + getName();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  665 */     public void accept(Visitor.TypeDeclarationVisitor visitor) { visitor.visitMemberClassDeclaration(this); }
/*  666 */     public void accept(Visitor.TypeBodyDeclarationVisitor visitor) { visitor.visitMemberClassDeclaration(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class LocalClassDeclaration
/*      */     extends Java.NamedClassDeclaration
/*      */     implements Java.InnerClassDeclaration
/*      */   {
/*      */     public LocalClassDeclaration(Location location, String optionalDocComment, short modifiers, String name, Java.Type optionalExtendedType, Java.Type[] implementedTypes)
/*      */     {
/*  678 */       super(optionalDocComment, modifiers, name, optionalExtendedType, implementedTypes);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     protected IClass getOuterIClass2()
/*      */     {
/*  690 */       Java.Scope s = getEnclosingScope();
/*  691 */       while (!(s instanceof Java.FunctionDeclarator)) s = s.getEnclosingScope();
/*  692 */       if (((s instanceof Java.MethodDeclarator)) && ((((Java.MethodDeclarator)s).modifiers & 0x8) != 0))
/*      */       {
/*      */ 
/*  695 */         return null; }
/*  696 */       while (!(s instanceof Java.TypeDeclaration)) s = s.getEnclosingScope();
/*  697 */       return ((Java.AbstractTypeDeclaration)s).resolvedType;
/*      */     }
/*      */     
/*      */     public String getClassName()
/*      */     {
/*  702 */       for (Java.Scope s = getEnclosingScope();; s = s.getEnclosingScope()) {
/*  703 */         if ((s instanceof Java.TypeDeclaration))
/*  704 */           return ((Java.TypeDeclaration)s).getClassName() + '$' + this.name;
/*      */       }
/*      */     }
/*      */     
/*      */     public void accept(Visitor.TypeDeclarationVisitor visitor) {
/*  709 */       visitor.visitLocalClassDeclaration(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class PackageMemberClassDeclaration
/*      */     extends Java.NamedClassDeclaration
/*      */     implements Java.PackageMemberTypeDeclaration
/*      */   {
/*      */     public PackageMemberClassDeclaration(Location location, String optionalDocComment, short modifiers, String name, Java.Type optionalExtendedType, Java.Type[] implementedTypes)
/*      */       throws CompileException
/*      */     {
/*  723 */       super(optionalDocComment, modifiers, name, optionalExtendedType, implementedTypes);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  733 */       if ((modifiers & 0xE) != 0)
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*  738 */         throwCompileException("Modifiers \"protected\", \"private\" and \"static\" not allowed in package member class declaration");
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public void setDeclaringCompilationUnit(Java.CompilationUnit declaringCompilationUnit)
/*      */     {
/*  747 */       setEnclosingScope(declaringCompilationUnit);
/*      */     }
/*      */     
/*  750 */     public Java.CompilationUnit getDeclaringCompilationUnit() { return (Java.CompilationUnit)getEnclosingScope(); }
/*      */     
/*      */ 
/*      */     protected IClass getOuterIClass2()
/*      */     {
/*  755 */       return null;
/*      */     }
/*      */     
/*      */     public String getClassName()
/*      */     {
/*  760 */       String className = getName();
/*      */       
/*  762 */       Java.CompilationUnit compilationUnit = (Java.CompilationUnit)getEnclosingScope();
/*  763 */       if (compilationUnit.optionalPackageDeclaration != null) {
/*  764 */         className = compilationUnit.optionalPackageDeclaration.packageName + '.' + className;
/*      */       }
/*      */       
/*  767 */       return className;
/*      */     }
/*      */     
/*  770 */     public void accept(Visitor.TypeDeclarationVisitor visitor) { visitor.visitPackageMemberClassDeclaration(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static abstract class InterfaceDeclaration
/*      */     extends Java.AbstractTypeDeclaration
/*      */     implements Java.NamedTypeDeclaration, Java.DocCommentable
/*      */   {
/*      */     private final String optionalDocComment;
/*      */     
/*      */     public String name;
/*      */     
/*      */     public Java.Type[] extendedTypes;
/*      */     
/*      */     protected InterfaceDeclaration(Location location, String optionalDocComment, short modifiers, String name, Java.Type[] extendedTypes)
/*      */     {
/*  786 */       super(modifiers);
/*  787 */       this.optionalDocComment = optionalDocComment;
/*  788 */       this.name = name;
/*  789 */       this.extendedTypes = extendedTypes;
/*  790 */       for (int i = 0; i < extendedTypes.length; i++) {
/*  791 */         extendedTypes[i].setEnclosingScope(new Java.EnclosingScopeOfTypeDeclaration(this));
/*      */       }
/*      */     }
/*      */     
/*  795 */     public String toString() { return this.name; }
/*      */     
/*      */     public void addConstantDeclaration(Java.FieldDeclaration fd) {
/*  798 */       this.constantDeclarations.add(fd);
/*  799 */       fd.setDeclaringType(this);
/*      */       
/*      */ 
/*  802 */       if (this.resolvedType != null) { this.resolvedType.clearIFieldCaches();
/*      */       }
/*      */     }
/*      */     
/*  806 */     public final List constantDeclarations = new ArrayList();
/*      */     
/*      */ 
/*  809 */     IClass[] interfaces = null;
/*      */     
/*      */     public String getName() {
/*  812 */       return this.name;
/*      */     }
/*      */     
/*  815 */     public String getDocComment() { return this.optionalDocComment; }
/*      */     
/*  817 */     public boolean hasDeprecatedDocTag() { return (this.optionalDocComment != null) && (this.optionalDocComment.indexOf("@deprecated") != -1); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class MemberInterfaceDeclaration
/*      */     extends Java.InterfaceDeclaration
/*      */     implements Java.MemberTypeDeclaration
/*      */   {
/*      */     public MemberInterfaceDeclaration(Location location, String optionalDocComment, short modifiers, String name, Java.Type[] extendedTypes)
/*      */     {
/*  829 */       super(optionalDocComment, modifiers, name, extendedTypes);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public String getClassName()
/*      */     {
/*  840 */       Java.NamedTypeDeclaration declaringType = (Java.NamedTypeDeclaration)getEnclosingScope();
/*  841 */       return declaringType.getClassName() + '$' + getName();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  849 */     public void setDeclaringType(Java.TypeDeclaration declaringType) { setEnclosingScope(declaringType); }
/*      */     
/*  851 */     public Java.TypeDeclaration getDeclaringType() { return (Java.TypeDeclaration)getEnclosingScope(); }
/*      */     
/*      */     public boolean isStatic() {
/*  854 */       return (getModifiers() & 0x8) != 0;
/*      */     }
/*      */     
/*      */     public void accept(Visitor.TypeDeclarationVisitor visitor) {
/*  858 */       visitor.visitMemberInterfaceDeclaration(this);
/*      */     }
/*      */     
/*  861 */     public void accept(Visitor.TypeBodyDeclarationVisitor visitor) { visitor.visitMemberInterfaceDeclaration(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class PackageMemberInterfaceDeclaration
/*      */     extends Java.InterfaceDeclaration
/*      */     implements Java.PackageMemberTypeDeclaration
/*      */   {
/*      */     public PackageMemberInterfaceDeclaration(Location location, String optionalDocComment, short modifiers, String name, Java.Type[] extendedTypes)
/*      */       throws CompileException
/*      */     {
/*  875 */       super(optionalDocComment, modifiers, name, extendedTypes);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  884 */       if ((modifiers & 0xE) != 0)
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*  889 */         throwCompileException("Modifiers \"protected\", \"private\" and \"static\" not allowed in package member interface declaration");
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public void setDeclaringCompilationUnit(Java.CompilationUnit declaringCompilationUnit)
/*      */     {
/*  898 */       setEnclosingScope(declaringCompilationUnit);
/*      */     }
/*      */     
/*      */     public Java.CompilationUnit getDeclaringCompilationUnit() {
/*  902 */       return (Java.CompilationUnit)getEnclosingScope();
/*      */     }
/*      */     
/*      */     public String getClassName()
/*      */     {
/*  907 */       String className = getName();
/*      */       
/*  909 */       Java.CompilationUnit compilationUnit = (Java.CompilationUnit)getEnclosingScope();
/*  910 */       if (compilationUnit.optionalPackageDeclaration != null) {
/*  911 */         className = compilationUnit.optionalPackageDeclaration.packageName + '.' + className;
/*      */       }
/*      */       
/*  914 */       return className;
/*      */     }
/*      */     
/*      */     public void accept(Visitor.TypeDeclarationVisitor visitor) {
/*  918 */       visitor.visitPackageMemberInterfaceDeclaration(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public static abstract interface TypeBodyDeclaration
/*      */     extends Java.Locatable, Java.Scope
/*      */   {
/*      */     public abstract void setDeclaringType(Java.TypeDeclaration paramTypeDeclaration);
/*      */     
/*      */ 
/*      */     public abstract Java.TypeDeclaration getDeclaringType();
/*      */     
/*      */ 
/*      */     public abstract boolean isStatic();
/*      */     
/*      */     public abstract void accept(Visitor.TypeBodyDeclarationVisitor paramTypeBodyDeclarationVisitor);
/*      */   }
/*      */   
/*      */   public static abstract class AbstractTypeBodyDeclaration
/*      */     extends Java.Located
/*      */     implements Java.TypeBodyDeclaration
/*      */   {
/*      */     private Java.TypeDeclaration declaringType;
/*      */     public final boolean statiC;
/*      */     
/*      */     protected AbstractTypeBodyDeclaration(Location location, boolean statiC)
/*      */     {
/*  946 */       super();
/*  947 */       this.statiC = statiC;
/*      */     }
/*      */     
/*      */     public void setDeclaringType(Java.TypeDeclaration declaringType)
/*      */     {
/*  952 */       if ((this.declaringType != null) && (declaringType != null)) {
/*  953 */         throw new JaninoRuntimeException("Declaring type for type body declaration \"" + toString() + "\"at " + getLocation() + " is already set");
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  961 */       this.declaringType = declaringType;
/*      */     }
/*      */     
/*  964 */     public Java.TypeDeclaration getDeclaringType() { return this.declaringType; }
/*      */     
/*      */     public boolean isStatic()
/*      */     {
/*  968 */       return this.statiC;
/*      */     }
/*      */     
/*      */     public void setEnclosingScope(Java.Scope enclosingScope)
/*      */     {
/*  973 */       this.declaringType = ((Java.TypeDeclaration)enclosingScope);
/*      */     }
/*      */     
/*  976 */     public Java.Scope getEnclosingScope() { return this.declaringType; }
/*      */     
/*      */ 
/*      */     public abstract void accept(Visitor.TypeBodyDeclarationVisitor paramTypeBodyDeclarationVisitor);
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class Initializer
/*      */     extends Java.AbstractTypeBodyDeclaration
/*      */     implements Java.BlockStatement
/*      */   {
/*      */     public final Java.Block block;
/*      */     
/*      */     public Initializer(Location location, boolean statiC, Java.Block block)
/*      */     {
/*  991 */       super(statiC);
/*  992 */       (this.block = block).setEnclosingScope(this);
/*      */     }
/*      */     
/*  995 */     public String toString() { return this.statiC ? "static " + this.block : this.block.toString(); }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1000 */     public void accept(Visitor.TypeBodyDeclarationVisitor visitor) { visitor.visitInitializer(this); }
/* 1001 */     public void accept(Visitor.BlockStatementVisitor visitor) { visitor.visitInitializer(this); }
/*      */     
/*      */     public Java.LocalVariable findLocalVariable(String name) {
/* 1004 */       return this.block.findLocalVariable(name);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static abstract class FunctionDeclarator
/*      */     extends Java.AbstractTypeBodyDeclaration
/*      */     implements Java.DocCommentable
/*      */   {
/*      */     private final String optionalDocComment;
/*      */     
/*      */     public final short modifiers;
/*      */     
/*      */     public final Java.Type type;
/*      */     
/*      */     public final String name;
/*      */     
/*      */     public final FormalParameter[] formalParameters;
/*      */     
/*      */     public final Java.Type[] thrownExceptions;
/*      */     
/*      */     public final List optionalStatements;
/*      */     
/*      */ 
/*      */     public FunctionDeclarator(Location location, String optionalDocComment, short modifiers, Java.Type type, String name, FormalParameter[] formalParameters, Java.Type[] thrownExceptions, List optionalStatements)
/*      */     {
/* 1031 */       super((modifiers & 0x8) != 0);
/* 1032 */       this.optionalDocComment = optionalDocComment;
/* 1033 */       this.modifiers = modifiers;
/* 1034 */       (this.type = type).setEnclosingScope(this);
/* 1035 */       this.name = name;
/* 1036 */       this.formalParameters = formalParameters;
/* 1037 */       for (int i = 0; i < formalParameters.length; i++) formalParameters[i].type.setEnclosingScope(this);
/* 1038 */       this.thrownExceptions = thrownExceptions;
/* 1039 */       for (int i = 0; i < thrownExceptions.length; i++) thrownExceptions[i].setEnclosingScope(this);
/* 1040 */       this.optionalStatements = optionalStatements;
/* 1041 */       Iterator it; if (optionalStatements != null) {
/* 1042 */         for (it = optionalStatements.iterator(); it.hasNext();) {
/* 1043 */           Java.BlockStatement bs = (Java.BlockStatement)it.next();
/*      */           
/*      */ 
/*      */ 
/* 1047 */           if (((!"<init>".equals(name)) && (!"<clinit>".equals(name))) || (bs.getEnclosingScope() == null))
/*      */           {
/* 1049 */             bs.setEnclosingScope(this);
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */     public Java.Scope getEnclosingScope() {
/* 1056 */       return getDeclaringType();
/*      */     }
/*      */     
/*      */ 
/* 1060 */     IClass returnType = null;
/*      */     
/*      */ 
/* 1063 */     public String getDocComment() { return this.optionalDocComment; }
/*      */     
/* 1065 */     public boolean hasDeprecatedDocTag() { return (this.optionalDocComment != null) && (this.optionalDocComment.indexOf("@deprecated") != -1); }
/*      */     
/*      */ 
/*      */     public static final class FormalParameter
/*      */       extends Java.Located
/*      */     {
/*      */       public final boolean finaL;
/*      */       
/*      */       public final Java.Type type;
/*      */       
/*      */       public final String name;
/*      */       
/*      */       public FormalParameter(Location location, boolean finaL, Java.Type type, String name)
/*      */       {
/* 1079 */         super();
/* 1080 */         this.finaL = finaL;
/* 1081 */         this.type = type;
/* 1082 */         this.name = name;
/*      */       }
/*      */       
/*      */       public String toString() {
/* 1086 */         return this.type.toString() + ' ' + this.name;
/*      */       }
/*      */       
/*      */ 
/*      */ 
/* 1091 */       public Java.LocalVariable localVariable = null;
/*      */     }
/*      */     
/*      */ 
/* 1095 */     public Map localVariables = null;
/*      */   }
/*      */   
/*      */   public static final class ConstructorDeclarator extends Java.FunctionDeclarator {
/* 1099 */     IClass.IConstructor iConstructor = null;
/* 1100 */     public Java.ConstructorInvocation optionalConstructorInvocation = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public ConstructorDeclarator(Location location, String optionalDocComment, short modifiers, Java.FunctionDeclarator.FormalParameter[] formalParameters, Java.Type[] thrownExceptions, Java.ConstructorInvocation optionalConstructorInvocation, List statements)
/*      */     {
/* 1111 */       super(optionalDocComment, modifiers, new Java.BasicType(location, 0), "<init>", formalParameters, thrownExceptions, statements);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1121 */       this.optionalConstructorInvocation = optionalConstructorInvocation;
/* 1122 */       if (optionalConstructorInvocation != null) optionalConstructorInvocation.setEnclosingScope(this);
/*      */     }
/*      */     
/*      */     public Java.ClassDeclaration getDeclaringClass() {
/* 1126 */       return (Java.ClassDeclaration)getEnclosingScope();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 1131 */     Map syntheticParameters = new HashMap();
/*      */     
/*      */ 
/*      */     public String toString()
/*      */     {
/* 1136 */       StringBuffer sb = new StringBuffer(getDeclaringClass().getClassName());
/* 1137 */       sb.append('(');
/* 1138 */       Java.FunctionDeclarator.FormalParameter[] fps = this.formalParameters;
/* 1139 */       for (int i = 0; i < fps.length; i++) {
/* 1140 */         if (i > 0) sb.append(", ");
/* 1141 */         sb.append(fps[i].toString());
/*      */       }
/* 1143 */       sb.append(')');
/* 1144 */       return sb.toString();
/*      */     }
/*      */     
/*      */     public void accept(Visitor.TypeBodyDeclarationVisitor visitor) {
/* 1148 */       visitor.visitConstructorDeclarator(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class MethodDeclarator
/*      */     extends Java.FunctionDeclarator
/*      */   {
/*      */     public MethodDeclarator(Location location, String optionalDocComment, short modifiers, Java.Type type, String name, Java.FunctionDeclarator.FormalParameter[] formalParameters, Java.Type[] thrownExceptions, List optionalStatements)
/*      */     {
/* 1163 */       super(optionalDocComment, modifiers, type, name, formalParameters, thrownExceptions, optionalStatements);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public String toString()
/*      */     {
/* 1176 */       StringBuffer sb = new StringBuffer(this.name);
/* 1177 */       sb.append('(');
/* 1178 */       Java.FunctionDeclarator.FormalParameter[] fps = this.formalParameters;
/* 1179 */       for (int i = 0; i < fps.length; i++) {
/* 1180 */         if (i > 0) sb.append(", ");
/* 1181 */         sb.append(fps[i].toString());
/*      */       }
/* 1183 */       sb.append(')');
/* 1184 */       return sb.toString();
/*      */     }
/*      */     
/* 1187 */     public void accept(Visitor.TypeBodyDeclarationVisitor visitor) { visitor.visitMethodDeclarator(this); }
/*      */     
/* 1189 */     IClass.IMethod iMethod = null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class FieldDeclaration
/*      */     extends Java.Statement
/*      */     implements Java.TypeBodyDeclaration, Java.DocCommentable
/*      */   {
/*      */     private final String optionalDocComment;
/*      */     
/*      */ 
/*      */     public final short modifiers;
/*      */     
/*      */     public final Java.Type type;
/*      */     
/*      */     public final Java.VariableDeclarator[] variableDeclarators;
/*      */     
/*      */ 
/*      */     public FieldDeclaration(Location location, String optionalDocComment, short modifiers, Java.Type type, Java.VariableDeclarator[] variableDeclarators)
/*      */     {
/* 1210 */       super();
/* 1211 */       this.optionalDocComment = optionalDocComment;
/* 1212 */       this.modifiers = modifiers;
/* 1213 */       (this.type = type).setEnclosingScope(this);
/* 1214 */       this.variableDeclarators = variableDeclarators;
/* 1215 */       for (int i = 0; i < variableDeclarators.length; i++) {
/* 1216 */         Java.VariableDeclarator vd = variableDeclarators[i];
/* 1217 */         if (vd.optionalInitializer != null) Java.setEnclosingBlockStatement(vd.optionalInitializer, this);
/*      */       }
/*      */     }
/*      */     
/*      */     public void setDeclaringType(Java.TypeDeclaration declaringType)
/*      */     {
/* 1223 */       setEnclosingScope(declaringType);
/*      */     }
/*      */     
/* 1226 */     public Java.TypeDeclaration getDeclaringType() { return (Java.TypeDeclaration)getEnclosingScope(); }
/*      */     
/*      */     public boolean isStatic() {
/* 1229 */       return (this.modifiers & 0x8) != 0;
/*      */     }
/*      */     
/*      */     public String toString() {
/* 1233 */       StringBuffer sb = new StringBuffer();
/* 1234 */       sb.append(Mod.shortToString(this.modifiers)).append(' ').append(this.type).append(' ');
/* 1235 */       sb.append(this.variableDeclarators[0]);
/* 1236 */       for (int i = 1; i < this.variableDeclarators.length; i++) {
/* 1237 */         sb.append(", ").append(this.variableDeclarators[i]);
/*      */       }
/* 1239 */       return sb.toString();
/*      */     }
/*      */     
/* 1242 */     public void accept(Visitor.TypeBodyDeclarationVisitor visitor) { visitor.visitFieldDeclaration(this); }
/* 1243 */     public void accept(Visitor.BlockStatementVisitor visitor) { visitor.visitFieldDeclaration(this); }
/*      */     
/*      */ 
/* 1246 */     public String getDocComment() { return this.optionalDocComment; }
/*      */     
/* 1248 */     public boolean hasDeprecatedDocTag() { return (this.optionalDocComment != null) && (this.optionalDocComment.indexOf("@deprecated") != -1); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private static void setEnclosingBlockStatement(ArrayInitializerOrRvalue aiorv, BlockStatement enclosingBlockStatement)
/*      */   {
/* 1255 */     if ((aiorv instanceof Rvalue)) {
/* 1256 */       ((Rvalue)aiorv).setEnclosingBlockStatement(enclosingBlockStatement);
/*      */     }
/* 1258 */     else if ((aiorv instanceof ArrayInitializer)) {
/* 1259 */       ArrayInitializerOrRvalue[] values = ((ArrayInitializer)aiorv).values;
/* 1260 */       for (int i = 0; i < values.length; i++) setEnclosingBlockStatement(values[i], enclosingBlockStatement);
/*      */     }
/*      */     else {
/* 1263 */       throw new JaninoRuntimeException("Unexpected array or initializer class " + aiorv.getClass().getName());
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class VariableDeclarator
/*      */     extends Java.Located
/*      */   {
/*      */     public final String name;
/*      */     
/*      */     public final int brackets;
/*      */     
/*      */     public final Java.ArrayInitializerOrRvalue optionalInitializer;
/*      */     
/*      */     public VariableDeclarator(Location location, String name, int brackets, Java.ArrayInitializerOrRvalue optionalInitializer)
/*      */     {
/* 1279 */       super();
/* 1280 */       this.name = name;
/* 1281 */       this.brackets = brackets;
/* 1282 */       this.optionalInitializer = optionalInitializer;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     public String toString()
/*      */     {
/* 1289 */       StringBuffer sb = new StringBuffer();
/* 1290 */       sb.append(this.name);
/* 1291 */       for (int i = 0; i < this.brackets; i++) sb.append("[]");
/* 1292 */       if (this.optionalInitializer != null) sb.append(" = ").append(this.optionalInitializer);
/* 1293 */       return sb.toString();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1299 */     public Java.LocalVariable localVariable = null;
/*      */   }
/*      */   
/*      */   public static abstract interface BlockStatement extends Java.Locatable, Java.Scope
/*      */   {
/*      */     public abstract void setEnclosingScope(Java.Scope paramScope);
/*      */     
/*      */     public abstract Java.Scope getEnclosingScope();
/*      */     
/*      */     public abstract void accept(Visitor.BlockStatementVisitor paramBlockStatementVisitor);
/*      */     
/*      */     public abstract Java.LocalVariable findLocalVariable(String paramString);
/*      */   }
/*      */   
/*      */   public static abstract class Statement extends Java.Located implements Java.BlockStatement {
/* 1314 */     private Java.Scope enclosingScope = null;
/*      */     
/*      */     protected Statement(Location location) {
/* 1317 */       super();
/*      */     }
/*      */     
/*      */     public void setEnclosingScope(Java.Scope enclosingScope)
/*      */     {
/* 1322 */       if ((this.enclosingScope != null) && (enclosingScope != this.enclosingScope)) {
/* 1323 */         throw new JaninoRuntimeException("Enclosing scope is already set for statement \"" + toString() + "\" at " + getLocation());
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1330 */       this.enclosingScope = enclosingScope; }
/*      */     
/* 1332 */     public Java.Scope getEnclosingScope() { return this.enclosingScope; }
/*      */     
/*      */ 
/* 1335 */     public Map localVariables = null;
/*      */     
/* 1337 */     public Java.LocalVariable findLocalVariable(String name) { if (this.localVariables == null) return null;
/* 1338 */       return (Java.LocalVariable)this.localVariables.get(name);
/*      */     }
/*      */     
/*      */     public abstract void accept(Visitor.BlockStatementVisitor paramBlockStatementVisitor);
/*      */   }
/*      */   
/*      */   public static final class LabeledStatement extends Java.BreakableStatement
/*      */   {
/*      */     public final String label;
/*      */     public final Java.Statement body;
/*      */     
/*      */     public LabeledStatement(Location location, String label, Java.Statement body)
/*      */     {
/* 1351 */       super();
/* 1352 */       this.label = label;
/* 1353 */       (this.body = body).setEnclosingScope(this);
/*      */     }
/*      */     
/* 1356 */     public String toString() { return this.label + ": " + this.body; }
/*      */     
/*      */ 
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1361 */       visitor.visitLabeledStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class Block
/*      */     extends Java.Statement
/*      */   {
/* 1370 */     public final List statements = new ArrayList();
/*      */     
/*      */     public Block(Location location) {
/* 1373 */       super();
/*      */     }
/*      */     
/*      */     public void addStatement(Java.BlockStatement statement) {
/* 1377 */       this.statements.add(statement);
/* 1378 */       statement.setEnclosingScope(this);
/*      */     }
/*      */     
/*      */ 
/*      */     public void addStatements(List statements)
/*      */     {
/* 1384 */       this.statements.addAll(statements);
/* 1385 */       for (Iterator it = statements.iterator(); it.hasNext();) {
/* 1386 */         ((Java.BlockStatement)it.next()).setEnclosingScope(this);
/*      */       }
/*      */     }
/*      */     
/*      */     public Java.BlockStatement[] getStatements() {
/* 1391 */       return (Java.BlockStatement[])this.statements.toArray(new Java.BlockStatement[this.statements.size()]);
/*      */     }
/*      */     
/*      */     public void accept(Visitor.BlockStatementVisitor visitor) {
/* 1395 */       visitor.visitBlock(this);
/*      */     }
/*      */     
/* 1398 */     public String toString() { return "{ ... }"; }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static abstract class BreakableStatement
/*      */     extends Java.Statement
/*      */   {
/*      */     protected BreakableStatement(Location location)
/*      */     {
/* 1412 */       super();
/*      */     }
/*      */     
/* 1415 */     CodeContext.Offset whereToBreak = null;
/*      */   }
/*      */   
/*      */   public static abstract class ContinuableStatement extends Java.BreakableStatement {
/*      */     protected ContinuableStatement(Location location) {
/* 1420 */       super();
/*      */     }
/*      */     
/* 1423 */     protected CodeContext.Offset whereToContinue = null;
/* 1424 */     protected boolean bodyHasContinue = false;
/*      */   }
/*      */   
/*      */   public static final class ExpressionStatement extends Java.Statement {
/*      */     public final Java.Rvalue rvalue;
/*      */     
/*      */     public ExpressionStatement(Java.Rvalue rvalue) throws CompileException {
/* 1431 */       super();
/* 1432 */       if ((!(rvalue instanceof Java.Assignment)) && (!(rvalue instanceof Java.Crement)) && (!(rvalue instanceof Java.MethodInvocation)) && (!(rvalue instanceof Java.SuperclassMethodInvocation)) && (!(rvalue instanceof Java.NewClassInstance)) && (!(rvalue instanceof Java.NewAnonymousClassInstance)))
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1440 */         String expressionType = rvalue.getClass().getName();
/* 1441 */         expressionType = expressionType.substring(expressionType.lastIndexOf('.') + 1);
/* 1442 */         throwCompileException(expressionType + " is not allowed as an expression statement. " + "Expressions statements must be one of assignments, method invocations, or object allocations.");
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/* 1448 */       (this.rvalue = rvalue).setEnclosingBlockStatement(this);
/*      */     }
/*      */     
/*      */     public String toString() {
/* 1452 */       return this.rvalue.toString() + ';';
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 1457 */     public void accept(Visitor.BlockStatementVisitor visitor) { visitor.visitExpressionStatement(this); }
/*      */   }
/*      */   
/*      */   public static final class LocalClassDeclarationStatement extends Java.Statement {
/*      */     public final Java.LocalClassDeclaration lcd;
/*      */     
/*      */     public LocalClassDeclarationStatement(Java.LocalClassDeclaration lcd) {
/* 1464 */       super();
/* 1465 */       (this.lcd = lcd).setEnclosingScope(this);
/*      */     }
/*      */     
/* 1468 */     public String toString() { return this.lcd.toString(); }
/*      */     
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1472 */       visitor.visitLocalClassDeclarationStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class IfStatement
/*      */     extends Java.Statement
/*      */   {
/*      */     public final Java.Rvalue condition;
/*      */     
/*      */ 
/*      */     public final Java.BlockStatement thenStatement;
/*      */     
/*      */     public final Java.BlockStatement optionalElseStatement;
/*      */     
/*      */ 
/*      */     public IfStatement(Location location, Java.Rvalue condition, Java.BlockStatement thenStatement, Java.BlockStatement optionalElseStatement)
/*      */     {
/* 1491 */       super();
/* 1492 */       (this.condition = condition).setEnclosingBlockStatement(this);
/* 1493 */       (this.thenStatement = thenStatement).setEnclosingScope(this);
/* 1494 */       this.optionalElseStatement = optionalElseStatement;
/* 1495 */       if (optionalElseStatement != null) optionalElseStatement.setEnclosingScope(this);
/*      */     }
/*      */     
/*      */     public String toString() {
/* 1499 */       return this.optionalElseStatement == null ? "if" : "if ... else";
/*      */     }
/*      */     
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1504 */       visitor.visitIfStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class ForStatement
/*      */     extends Java.ContinuableStatement
/*      */   {
/*      */     public final Java.BlockStatement optionalInit;
/*      */     
/*      */     public final Java.Rvalue optionalCondition;
/*      */     public final Java.Rvalue[] optionalUpdate;
/*      */     public final Java.BlockStatement body;
/*      */     
/*      */     public ForStatement(Location location, Java.BlockStatement optionalInit, Java.Rvalue optionalCondition, Java.Rvalue[] optionalUpdate, Java.BlockStatement body)
/*      */     {
/* 1520 */       super();
/* 1521 */       this.optionalInit = optionalInit;
/* 1522 */       if (optionalInit != null) optionalInit.setEnclosingScope(this);
/* 1523 */       this.optionalCondition = optionalCondition;
/* 1524 */       if (optionalCondition != null) optionalCondition.setEnclosingBlockStatement(this);
/* 1525 */       this.optionalUpdate = optionalUpdate;
/* 1526 */       if (optionalUpdate != null) {
/* 1527 */         for (int i = 0; i < optionalUpdate.length; i++) optionalUpdate[i].setEnclosingBlockStatement(this);
/*      */       }
/* 1529 */       (this.body = body).setEnclosingScope(this);
/*      */     }
/*      */     
/* 1532 */     public String toString() { return "for (...; ...; ...) ..."; }
/*      */     
/*      */ 
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1537 */       visitor.visitForStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */   public static final class WhileStatement
/*      */     extends Java.ContinuableStatement
/*      */   {
/*      */     public final Java.Rvalue condition;
/*      */     public final Java.BlockStatement body;
/*      */     
/*      */     public WhileStatement(Location location, Java.Rvalue condition, Java.BlockStatement body)
/*      */     {
/* 1549 */       super();
/* 1550 */       (this.condition = condition).setEnclosingBlockStatement(this);
/* 1551 */       (this.body = body).setEnclosingScope(this);
/*      */     }
/*      */     
/* 1554 */     public String toString() { return "while (" + this.condition + ") " + this.body + ';'; }
/*      */     
/*      */ 
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1559 */       visitor.visitWhileStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class TryStatement
/*      */     extends Java.Statement
/*      */   {
/*      */     public final Java.BlockStatement body;
/*      */     public final List catchClauses;
/*      */     public final Java.Block optionalFinally;
/*      */     
/*      */     public TryStatement(Location location, Java.BlockStatement body, List catchClauses, Java.Block optionalFinally)
/*      */     {
/* 1573 */       super();
/* 1574 */       (this.body = body).setEnclosingScope(this);
/* 1575 */       this.catchClauses = catchClauses;
/* 1576 */       for (Iterator it = catchClauses.iterator(); it.hasNext();) {
/* 1577 */         ((Java.CatchClause)it.next()).setEnclosingTryStatement(this);
/*      */       }
/* 1579 */       this.optionalFinally = optionalFinally;
/* 1580 */       if (optionalFinally != null) optionalFinally.setEnclosingScope(this);
/*      */     }
/*      */     
/* 1583 */     public String toString() { return "try ... " + this.catchClauses.size() + (this.optionalFinally == null ? " catches" : " catches ... finally"); }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1592 */     public void accept(Visitor.BlockStatementVisitor visitor) { visitor.visitTryStatement(this); }
/*      */     
/* 1594 */     CodeContext.Offset finallyOffset = null;
/*      */   }
/*      */   
/*      */   public static class CatchClause extends Java.Located implements Java.Scope {
/*      */     public final Java.FunctionDeclarator.FormalParameter caughtException;
/*      */     public final Java.Block body;
/* 1600 */     private Java.TryStatement enclosingTryStatement = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public CatchClause(Location location, Java.FunctionDeclarator.FormalParameter caughtException, Java.Block body)
/*      */     {
/* 1607 */       super();
/* 1608 */       (this.caughtException = caughtException).type.setEnclosingScope(this);
/* 1609 */       (this.body = body).setEnclosingScope(this);
/*      */     }
/*      */     
/*      */     public void setEnclosingTryStatement(Java.TryStatement enclosingTryStatement) {
/* 1613 */       if ((this.enclosingTryStatement != null) && (enclosingTryStatement != this.enclosingTryStatement)) {
/* 1614 */         throw new JaninoRuntimeException("Enclosing TYR statement already set for catch clause " + toString() + " at " + getLocation());
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1621 */       this.enclosingTryStatement = enclosingTryStatement; }
/*      */     
/* 1623 */     public Java.Scope getEnclosingScope() { return this.enclosingTryStatement; }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class SwitchStatement
/*      */     extends Java.BreakableStatement
/*      */   {
/*      */     public final Java.Rvalue condition;
/*      */     
/*      */     public final List sbsgs;
/*      */     
/*      */ 
/*      */     public SwitchStatement(Location location, Java.Rvalue condition, List sbsgs)
/*      */     {
/* 1638 */       super();
/* 1639 */       (this.condition = condition).setEnclosingBlockStatement(this);
/* 1640 */       this.sbsgs = sbsgs;
/* 1641 */       for (Iterator it = sbsgs.iterator(); it.hasNext();) {
/* 1642 */         SwitchBlockStatementGroup sbsg = (SwitchBlockStatementGroup)it.next();
/* 1643 */         for (Iterator it2 = sbsg.caseLabels.iterator(); it2.hasNext();) {
/* 1644 */           ((Java.Rvalue)it2.next()).setEnclosingBlockStatement(this);
/*      */         }
/* 1646 */         for (it2 = sbsg.blockStatements.iterator(); it2.hasNext();)
/* 1647 */           ((Java.BlockStatement)it2.next()).setEnclosingScope(this);
/*      */       }
/*      */       Iterator it2;
/*      */     }
/*      */     
/* 1652 */     public String toString() { return "switch (" + this.condition + ") { (" + this.sbsgs.size() + " statement groups) }"; }
/*      */     
/*      */ 
/*      */     public static class SwitchBlockStatementGroup
/*      */       extends Java.Located
/*      */     {
/*      */       public final List caseLabels;
/*      */       
/*      */       public final boolean hasDefaultLabel;
/*      */       
/*      */       public final List blockStatements;
/*      */       
/*      */       public SwitchBlockStatementGroup(Location location, List caseLabels, boolean hasDefaultLabel, List blockStatements)
/*      */       {
/* 1666 */         super();
/* 1667 */         this.caseLabels = caseLabels;
/* 1668 */         this.hasDefaultLabel = hasDefaultLabel;
/* 1669 */         this.blockStatements = blockStatements;
/*      */       }
/*      */       
/* 1672 */       public String toString() { return this.caseLabels.size() + (this.hasDefaultLabel ? " case label(s) plus DEFAULT" : " case label(s)"); }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1681 */     public void accept(Visitor.BlockStatementVisitor visitor) { visitor.visitSwitchStatement(this); }
/*      */   }
/*      */   
/*      */   static class Padder extends CodeContext.Inserter implements CodeContext.FixUp {
/* 1685 */     public Padder(CodeContext codeContext) { super(); }
/*      */     
/*      */     public void fixUp() {
/* 1688 */       int x = this.offset % 4;
/* 1689 */       if (x != 0) {
/* 1690 */         CodeContext ca = getCodeContext();
/* 1691 */         ca.pushInserter(this);
/* 1692 */         ca.makeSpace((short)-1, 4 - x);
/* 1693 */         ca.popInserter();
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class SynchronizedStatement
/*      */     extends Java.Statement
/*      */   {
/*      */     public final Java.Rvalue expression;
/*      */     public final Java.BlockStatement body;
/*      */     
/*      */     public SynchronizedStatement(Location location, Java.Rvalue expression, Java.BlockStatement body)
/*      */     {
/* 1707 */       super();
/* 1708 */       (this.expression = expression).setEnclosingBlockStatement(this);
/* 1709 */       (this.body = body).setEnclosingScope(this);
/*      */     }
/*      */     
/* 1712 */     public String toString() { return "synchronized(" + this.expression + ") " + this.body; }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1717 */     public void accept(Visitor.BlockStatementVisitor visitor) { visitor.visitSynchronizedStatement(this); }
/*      */     
/* 1719 */     short monitorLvIndex = -1;
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class DoStatement
/*      */     extends Java.ContinuableStatement
/*      */   {
/*      */     public final Java.BlockStatement body;
/*      */     public final Java.Rvalue condition;
/*      */     
/*      */     public DoStatement(Location location, Java.BlockStatement body, Java.Rvalue condition)
/*      */     {
/* 1731 */       super();
/* 1732 */       (this.body = body).setEnclosingScope(this);
/* 1733 */       (this.condition = condition).setEnclosingBlockStatement(this);
/*      */     }
/*      */     
/* 1736 */     public String toString() { return "do " + this.body + " while(" + this.condition + ");"; }
/*      */     
/*      */ 
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1741 */       visitor.visitDoStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class LocalVariableDeclarationStatement
/*      */     extends Java.Statement
/*      */   {
/*      */     public final short modifiers;
/*      */     
/*      */     public final Java.Type type;
/*      */     
/*      */     public final Java.VariableDeclarator[] variableDeclarators;
/*      */     
/*      */ 
/*      */     public LocalVariableDeclarationStatement(Location location, short modifiers, Java.Type type, Java.VariableDeclarator[] variableDeclarators)
/*      */     {
/* 1758 */       super();
/* 1759 */       this.modifiers = modifiers;
/* 1760 */       (this.type = type).setEnclosingScope(this);
/* 1761 */       this.variableDeclarators = variableDeclarators;
/* 1762 */       for (int i = 0; i < variableDeclarators.length; i++) {
/* 1763 */         Java.VariableDeclarator vd = variableDeclarators[i];
/* 1764 */         if (vd.optionalInitializer != null) { Java.setEnclosingBlockStatement(vd.optionalInitializer, this);
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1771 */       visitor.visitLocalVariableDeclarationStatement(this);
/*      */     }
/*      */     
/*      */     public String toString() {
/* 1775 */       StringBuffer sb = new StringBuffer();
/* 1776 */       if (this.modifiers != 0) sb.append(Mod.shortToString(this.modifiers)).append(' ');
/* 1777 */       sb.append(this.type).append(' ').append(this.variableDeclarators[0].toString());
/* 1778 */       for (int i = 1; i < this.variableDeclarators.length; i++) {
/* 1779 */         sb.append(", ").append(this.variableDeclarators[i].toString());
/*      */       }
/* 1781 */       return ';';
/*      */     }
/*      */   }
/*      */   
/*      */   public static final class ReturnStatement
/*      */     extends Java.Statement
/*      */   {
/*      */     public final Java.Rvalue optionalReturnValue;
/*      */     
/*      */     public ReturnStatement(Location location, Java.Rvalue optionalReturnValue)
/*      */     {
/* 1792 */       super();
/* 1793 */       this.optionalReturnValue = optionalReturnValue;
/* 1794 */       if (optionalReturnValue != null) optionalReturnValue.setEnclosingBlockStatement(this);
/*      */     }
/*      */     
/*      */     public String toString() {
/* 1798 */       return "return " + this.optionalReturnValue + ';';
/*      */     }
/*      */     
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1803 */       visitor.visitReturnStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */   public static final class ThrowStatement extends Java.Statement
/*      */   {
/*      */     public final Java.Rvalue expression;
/*      */     
/*      */     public ThrowStatement(Location location, Java.Rvalue expression)
/*      */     {
/* 1813 */       super();
/* 1814 */       (this.expression = expression).setEnclosingBlockStatement(this);
/*      */     }
/*      */     
/* 1817 */     public String toString() { return "throw " + this.expression + ';'; }
/*      */     
/*      */ 
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1822 */       visitor.visitThrowStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class BreakStatement
/*      */     extends Java.Statement
/*      */   {
/*      */     public final String optionalLabel;
/*      */     
/*      */ 
/*      */     public BreakStatement(Location location, String optionalLabel)
/*      */     {
/* 1835 */       super();
/* 1836 */       this.optionalLabel = optionalLabel;
/*      */     }
/*      */     
/* 1839 */     public String toString() { return "break " + this.optionalLabel + ';'; }
/*      */     
/*      */ 
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1844 */       visitor.visitBreakStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class ContinueStatement
/*      */     extends Java.Statement
/*      */   {
/*      */     public final String optionalLabel;
/*      */     
/*      */ 
/*      */     public ContinueStatement(Location location, String optionalLabel)
/*      */     {
/* 1858 */       super();
/* 1859 */       this.optionalLabel = optionalLabel;
/*      */     }
/*      */     
/* 1862 */     public String toString() { return "continue " + this.optionalLabel + ';'; }
/*      */     
/*      */ 
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 1867 */       visitor.visitContinueStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */   public static final class EmptyStatement extends Java.Statement
/*      */   {
/*      */     public EmptyStatement(Location location)
/*      */     {
/* 1875 */       super();
/*      */     }
/*      */     
/* 1878 */     public String toString() { return ";"; }
/*      */     
/*      */     public void accept(Visitor.BlockStatementVisitor visitor) {
/* 1881 */       visitor.visitEmptyStatement(this);
/*      */     }
/*      */   }
/*      */   
/*      */   public static abstract class Atom
/*      */     extends Java.Located
/*      */   {
/*      */     public Atom(Location location)
/*      */     {
/* 1890 */       super();
/*      */     }
/*      */     
/* 1893 */     public Java.Type toType() { return null; }
/* 1894 */     public Java.Rvalue toRvalue() { return null; }
/* 1895 */     public Java.Lvalue toLvalue() { return null; }
/*      */     
/*      */     public abstract String toString();
/*      */     
/*      */     public final Java.Type toTypeOrPE()
/*      */       throws CompileException
/*      */     {
/* 1902 */       Java.Type result = toType();
/* 1903 */       if (result == null) throwCompileException("Expression \"" + toString() + "\" is not a type");
/* 1904 */       return result;
/*      */     }
/*      */     
/* 1907 */     public final Java.Rvalue toRvalueOrPE() throws CompileException { Java.Rvalue result = toRvalue();
/* 1908 */       if (result == null) throwCompileException("Expression \"" + toString() + "\" is not an rvalue");
/* 1909 */       return result;
/*      */     }
/*      */     
/* 1912 */     public final Java.Lvalue toLvalueOrPE() throws CompileException { Java.Lvalue result = toLvalue();
/* 1913 */       if (result == null) throwCompileException("Expression \"" + toString() + "\" is not an lvalue");
/* 1914 */       return result;
/*      */     }
/*      */     
/*      */ 
/*      */     public abstract void accept(Visitor.AtomVisitor paramAtomVisitor);
/*      */   }
/*      */   
/*      */   public static abstract class Type
/*      */     extends Java.Atom
/*      */   {
/* 1924 */     private Java.Scope enclosingScope = null;
/*      */     
/*      */     protected Type(Location location) {
/* 1927 */       super();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public void setEnclosingScope(Java.Scope enclosingScope)
/*      */     {
/* 1935 */       if ((this.enclosingScope != null) && (enclosingScope != this.enclosingScope)) {
/* 1936 */         throw new JaninoRuntimeException("Enclosing scope already set for type \"" + toString() + "\" at " + getLocation());
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1943 */       this.enclosingScope = enclosingScope;
/*      */     }
/*      */     
/* 1946 */     public Java.Scope getEnclosingScope() { return this.enclosingScope; }
/*      */     
/* 1948 */     public Type toType() { return this; }
/*      */     
/*      */     public abstract void accept(Visitor.TypeVisitor paramTypeVisitor);
/*      */   }
/*      */   
/*      */   public static final class SimpleType extends Java.Type {
/*      */     public final IClass iClass;
/*      */     
/*      */     public SimpleType(Location location, IClass iClass) {
/* 1957 */       super();
/* 1958 */       this.iClass = iClass; }
/*      */     
/* 1960 */     public String toString() { return this.iClass.toString(); }
/*      */     
/* 1962 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitSimpleType(this); }
/* 1963 */     public void accept(Visitor.TypeVisitor visitor) { visitor.visitSimpleType(this); }
/*      */   }
/*      */   
/*      */   public static final class BasicType extends Java.Type {
/*      */     public int index;
/*      */     public static final int VOID = 0;
/*      */     public static final int BYTE = 1;
/*      */     public static final int SHORT = 2;
/*      */     public static final int CHAR = 3;
/*      */     
/*      */     public BasicType(Location location, int index) {
/* 1974 */       super();
/* 1975 */       this.index = index;
/*      */     }
/*      */     
/*      */     public String toString() {
/* 1979 */       switch (this.index) {
/* 1980 */       case 0:  return "void";
/* 1981 */       case 1:  return "byte";
/* 1982 */       case 2:  return "short";
/* 1983 */       case 3:  return "char";
/* 1984 */       case 4:  return "int";
/* 1985 */       case 5:  return "long";
/* 1986 */       case 6:  return "float";
/* 1987 */       case 7:  return "double";
/* 1988 */       case 8:  return "boolean"; }
/* 1989 */       throw new JaninoRuntimeException("Invalid index " + this.index);
/*      */     }
/*      */     
/*      */ 
/* 1993 */     public void accept(Visitor.TypeVisitor visitor) { visitor.visitBasicType(this); }
/* 1994 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitBasicType(this); }
/*      */     
/*      */ 
/*      */     public static final int INT = 4;
/*      */     
/*      */     public static final int LONG = 5;
/*      */     
/*      */     public static final int FLOAT = 6;
/*      */     
/*      */     public static final int DOUBLE = 7;
/*      */     public static final int BOOLEAN = 8;
/*      */   }
/*      */   
/*      */   public static final class ReferenceType
/*      */     extends Java.Type
/*      */   {
/*      */     public final String[] identifiers;
/*      */     
/*      */     public ReferenceType(Location location, String[] identifiers)
/*      */     {
/* 2014 */       super();
/* 2015 */       this.identifiers = identifiers;
/*      */     }
/*      */     
/* 2018 */     public String toString() { return Java.join(this.identifiers, "."); }
/*      */     
/* 2020 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitReferenceType(this); }
/* 2021 */     public void accept(Visitor.TypeVisitor visitor) { visitor.visitReferenceType(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class RvalueMemberType
/*      */     extends Java.Type
/*      */   {
/*      */     public final Java.Rvalue rvalue;
/*      */     
/*      */ 
/*      */     public final String identifier;
/*      */     
/*      */ 
/*      */     public RvalueMemberType(Location location, Java.Rvalue rvalue, String identifier)
/*      */     {
/* 2037 */       super();
/* 2038 */       this.rvalue = rvalue;
/* 2039 */       this.identifier = identifier;
/*      */     }
/*      */     
/* 2042 */     public String toString() { return this.identifier; }
/*      */     
/* 2044 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitRvalueMemberType(this); }
/* 2045 */     public void accept(Visitor.TypeVisitor visitor) { visitor.visitRvalueMemberType(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class ArrayType
/*      */     extends Java.Type
/*      */   {
/*      */     public final Java.Type componentType;
/*      */     
/*      */     public ArrayType(Java.Type componentType)
/*      */     {
/* 2056 */       super();
/* 2057 */       this.componentType = componentType;
/*      */     }
/*      */     
/*      */     public void setEnclosingScope(Java.Scope enclosingScope) {
/* 2061 */       super.setEnclosingScope(enclosingScope);
/* 2062 */       this.componentType.setEnclosingScope(enclosingScope);
/*      */     }
/*      */     
/* 2065 */     public String toString() { return this.componentType.toString() + "[]"; }
/*      */     
/*      */ 
/* 2068 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitArrayType(this); }
/* 2069 */     public void accept(Visitor.TypeVisitor visitor) { visitor.visitArrayType(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static abstract class Rvalue
/*      */     extends Java.Atom
/*      */     implements Java.ArrayInitializerOrRvalue
/*      */   {
/* 2078 */     private Java.BlockStatement enclosingBlockStatement = null;
/*      */     
/*      */     protected Rvalue(Location location) {
/* 2081 */       super();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public final void setEnclosingBlockStatement(Java.BlockStatement enclosingBlockStatement)
/*      */     {
/* 2089 */       accept(new Traverser() { private final Java.BlockStatement val$enclosingBlockStatement;
/*      */         
/* 2091 */         public void traverseRvalue(Java.Rvalue rv) { if ((rv.enclosingBlockStatement != null) && (this.val$enclosingBlockStatement != rv.enclosingBlockStatement)) {
/* 2092 */             throw new JaninoRuntimeException("Enclosing block statement for rvalue \"" + rv + "\" at " + rv.getLocation() + " is already set");
/*      */           }
/*      */           
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2100 */           rv.enclosingBlockStatement = this.val$enclosingBlockStatement;
/* 2101 */           super.traverseRvalue(rv);
/*      */         }
/*      */         
/* 2104 */         public void traverseAnonymousClassDeclaration(Java.AnonymousClassDeclaration acd) { acd.setEnclosingScope(this.val$enclosingBlockStatement); }
/*      */         
/*      */         public void traverseType(Java.Type t)
/*      */         {
/* 2108 */           if ((Java.Type.access$200(t) != null) && (this.val$enclosingBlockStatement != Java.Type.access$200(t))) {
/* 2109 */             throw new JaninoRuntimeException("Enclosing scope already set for type \"" + toString() + "\" at " + t.getLocation());
/*      */           }
/*      */           
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2116 */           Java.Type.access$202(t, this.val$enclosingBlockStatement);
/*      */           
/* 2118 */           super.traverseType(t);
/*      */         }
/*      */       }.comprehensiveVisitor());
/*      */     }
/*      */     
/* 2123 */     public Java.BlockStatement getEnclosingBlockStatement() { return this.enclosingBlockStatement; }
/*      */     
/* 2125 */     public Rvalue toRvalue() { return this; }
/*      */     
/* 2127 */     static final Object CONSTANT_VALUE_UNKNOWN = new Object();
/* 2128 */     Object constantValue = CONSTANT_VALUE_UNKNOWN;
/* 2129 */     public static final Object CONSTANT_VALUE_NULL = new Throwable();
/*      */     
/*      */     public static final boolean JUMP_IF_TRUE = true;
/*      */     
/*      */     public static final boolean JUMP_IF_FALSE = false;
/*      */     
/*      */     public abstract void accept(Visitor.RvalueVisitor paramRvalueVisitor);
/*      */   }
/*      */   
/*      */   public static abstract class BooleanRvalue
/*      */     extends Java.Rvalue
/*      */   {
/*      */     protected BooleanRvalue(Location location)
/*      */     {
/* 2143 */       super();
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static abstract class Lvalue
/*      */     extends Java.Rvalue
/*      */   {
/*      */     protected Lvalue(Location location)
/*      */     {
/* 2154 */       super();
/*      */     }
/*      */     
/* 2157 */     public Lvalue toLvalue() { return this; }
/*      */     
/*      */ 
/*      */     public abstract void accept(Visitor.LvalueVisitor paramLvalueVisitor);
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class AmbiguousName
/*      */     extends Java.Lvalue
/*      */   {
/*      */     public final String[] identifiers;
/*      */     
/*      */     public final int n;
/*      */     
/*      */ 
/*      */     public AmbiguousName(Location location, String[] identifiers)
/*      */     {
/* 2174 */       this(location, identifiers, identifiers.length);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     public AmbiguousName(Location location, String[] identifiers, int n)
/*      */     {
/* 2181 */       super();
/* 2182 */       this.identifiers = identifiers;
/* 2183 */       this.n = n;
/*      */     }
/*      */     
/*      */ 
/* 2187 */     private Java.Type type = null;
/*      */     
/* 2189 */     public Java.Type toType() { if (this.type == null) {
/* 2190 */         String[] is = new String[this.n];
/* 2191 */         System.arraycopy(this.identifiers, 0, is, 0, this.n);
/* 2192 */         this.type = new Java.ReferenceType(getLocation(), is);
/* 2193 */         this.type.setEnclosingScope(getEnclosingBlockStatement());
/*      */       }
/* 2195 */       return this.type;
/*      */     }
/*      */     
/*      */ 
/*      */     public String toString()
/*      */     {
/* 2201 */       return Java.join(this.identifiers, ".", 0, this.n);
/*      */     }
/*      */     
/*      */     public Java.Lvalue toLvalue() {
/* 2205 */       if (this.reclassified != null) return this.reclassified.toLvalue();
/* 2206 */       return this;
/*      */     }
/*      */     
/*      */     public Java.Rvalue toRvalue() {
/* 2210 */       if (this.reclassified != null) return this.reclassified.toRvalue();
/* 2211 */       return this;
/*      */     }
/*      */     
/* 2214 */     Java.Atom reclassified = null;
/*      */     
/* 2216 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitAmbiguousName(this); }
/* 2217 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitAmbiguousName(this); }
/* 2218 */     public void accept(Visitor.LvalueVisitor visitor) { visitor.visitAmbiguousName(this); }
/*      */   }
/*      */   
/*      */   public static final class Package extends Java.Atom
/*      */   {
/*      */     public final String name;
/*      */     
/*      */     public Package(Location location, String name) {
/* 2226 */       super();
/* 2227 */       this.name = name; }
/*      */     
/* 2229 */     public String toString() { return this.name; }
/*      */     
/* 2231 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitPackage(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class LocalVariableAccess
/*      */     extends Java.Lvalue
/*      */   {
/*      */     public Java.LocalVariable localVariable;
/*      */     
/*      */ 
/*      */     public LocalVariableAccess(Location location, Java.LocalVariable localVariable)
/*      */     {
/* 2244 */       super();
/* 2245 */       this.localVariable = localVariable;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2250 */     public String toString() { return this.localVariable.toString(); }
/*      */     
/* 2252 */     public void accept(Visitor.LvalueVisitor visitor) { visitor.visitLocalVariableAccess(this); }
/* 2253 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitLocalVariableAccess(this); }
/* 2254 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitLocalVariableAccess(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class FieldAccess
/*      */     extends Java.Lvalue
/*      */   {
/*      */     public final Java.Atom lhs;
/*      */     
/*      */ 
/*      */     public final IClass.IField field;
/*      */     
/*      */ 
/*      */     public FieldAccess(Location location, Java.Atom lhs, IClass.IField field)
/*      */     {
/* 2270 */       super();
/* 2271 */       this.lhs = lhs;
/* 2272 */       this.field = field;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2278 */     public String toString() { return this.lhs.toString() + '.' + this.field.getName(); }
/*      */     
/* 2280 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitFieldAccess(this); }
/* 2281 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitFieldAccess(this); }
/* 2282 */     public void accept(Visitor.LvalueVisitor visitor) { visitor.visitFieldAccess(this); }
/*      */   }
/*      */   
/*      */   public static final class ArrayLength
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Rvalue lhs;
/*      */     
/*      */     public ArrayLength(Location location, Java.Rvalue lhs)
/*      */     {
/* 2292 */       super();
/* 2293 */       this.lhs = lhs;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2299 */     public String toString() { return this.lhs.toString() + ".length"; }
/*      */     
/* 2301 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitArrayLength(this); }
/* 2302 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitArrayLength(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class ThisReference
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public ThisReference(Location location)
/*      */     {
/* 2314 */       super();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2319 */     IClass iClass = null;
/*      */     
/*      */ 
/* 2322 */     public String toString() { return "this"; }
/*      */     
/* 2324 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitThisReference(this); }
/* 2325 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitThisReference(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class QualifiedThisReference
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Type qualification;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public QualifiedThisReference(Location location, Java.Type qualification)
/*      */     {
/* 2341 */       super();
/*      */       
/* 2343 */       if (qualification == null) throw new NullPointerException();
/* 2344 */       this.qualification = qualification;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2349 */     Java.ClassDeclaration declaringClass = null;
/* 2350 */     Java.TypeBodyDeclaration declaringTypeBodyDeclaration = null;
/* 2351 */     IClass targetIClass = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public String toString()
/*      */     {
/* 2373 */       return this.qualification.toString() + ".this";
/*      */     }
/*      */     
/* 2376 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitQualifiedThisReference(this); }
/* 2377 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitQualifiedThisReference(this); }
/*      */   }
/*      */   
/*      */   public static final class ClassLiteral
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Type type;
/*      */     
/*      */     public ClassLiteral(Location location, Java.Type type)
/*      */     {
/* 2387 */       super();
/* 2388 */       this.type = type;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2394 */     public String toString() { return this.type.toString() + ".class"; }
/*      */     
/* 2396 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitClassLiteral(this); }
/* 2397 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitClassLiteral(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class Assignment
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Lvalue lhs;
/*      */     
/*      */     public final String operator;
/*      */     public final Java.Rvalue rhs;
/*      */     
/*      */     public Assignment(Location location, Java.Lvalue lhs, String operator, Java.Rvalue rhs)
/*      */     {
/* 2411 */       super();
/* 2412 */       this.lhs = lhs;
/* 2413 */       this.operator = operator;
/* 2414 */       this.rhs = rhs;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2420 */     public String toString() { return this.lhs.toString() + ' ' + this.operator + ' ' + this.rhs.toString(); }
/*      */     
/* 2422 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitAssignment(this); }
/* 2423 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitAssignment(this); }
/*      */   }
/*      */   
/*      */   public static final class ConditionalExpression
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Rvalue lhs;
/*      */     public final Java.Rvalue mhs;
/*      */     public final Java.Rvalue rhs;
/*      */     
/*      */     public ConditionalExpression(Location location, Java.Rvalue lhs, Java.Rvalue mhs, Java.Rvalue rhs)
/*      */     {
/* 2435 */       super();
/* 2436 */       this.lhs = lhs;
/* 2437 */       this.mhs = mhs;
/* 2438 */       this.rhs = rhs;
/*      */     }
/*      */     
/*      */     public String toString()
/*      */     {
/* 2443 */       return this.lhs.toString() + " ? " + this.mhs.toString() + " : " + this.rhs.toString();
/*      */     }
/*      */     
/* 2446 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitConditionalExpression(this); }
/* 2447 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitConditionalExpression(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class Crement
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final boolean pre;
/*      */     public final String operator;
/*      */     public final Java.Lvalue operand;
/*      */     
/*      */     public Crement(Location location, String operator, Java.Lvalue operand)
/*      */     {
/* 2460 */       super();
/* 2461 */       this.pre = true;
/* 2462 */       this.operator = operator;
/* 2463 */       this.operand = operand;
/*      */     }
/*      */     
/* 2466 */     public Crement(Location location, Java.Lvalue operand, String operator) { super();
/* 2467 */       this.pre = false;
/* 2468 */       this.operator = operator;
/* 2469 */       this.operand = operand;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     public String toString()
/*      */     {
/* 2476 */       return this.operand + this.operator;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2483 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitCrement(this); }
/* 2484 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitCrement(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class ArrayAccessExpression
/*      */     extends Java.Lvalue
/*      */   {
/*      */     public final Java.Rvalue lhs;
/*      */     
/*      */     public final Java.Rvalue index;
/*      */     
/*      */ 
/*      */     public ArrayAccessExpression(Location location, Java.Rvalue lhs, Java.Rvalue index)
/*      */     {
/* 2499 */       super();
/* 2500 */       this.lhs = lhs;
/* 2501 */       this.index = index;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2507 */     public String toString() { return this.lhs.toString() + '[' + this.index + ']'; }
/*      */     
/* 2509 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitArrayAccessExpression(this); }
/* 2510 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitArrayAccessExpression(this); }
/* 2511 */     public void accept(Visitor.LvalueVisitor visitor) { visitor.visitArrayAccessExpression(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class FieldAccessExpression
/*      */     extends Java.Lvalue
/*      */   {
/*      */     public final Java.Atom lhs;
/*      */     
/*      */ 
/*      */     public final String fieldName;
/*      */     
/*      */ 
/*      */     public FieldAccessExpression(Location location, Java.Atom lhs, String fieldName)
/*      */     {
/* 2527 */       super();
/* 2528 */       this.lhs = lhs;
/* 2529 */       this.fieldName = fieldName;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2535 */     public String toString() { return this.lhs.toString() + '.' + this.fieldName; }
/*      */     
/* 2537 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitFieldAccessExpression(this); }
/* 2538 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitFieldAccessExpression(this); }
/* 2539 */     public void accept(Visitor.LvalueVisitor visitor) { visitor.visitFieldAccessExpression(this); }
/*      */     
/* 2541 */     Java.Rvalue value = null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class SuperclassFieldAccessExpression
/*      */     extends Java.Lvalue
/*      */   {
/*      */     public final Java.Type optionalQualification;
/*      */     
/*      */     public final String fieldName;
/*      */     
/*      */ 
/*      */     public SuperclassFieldAccessExpression(Location location, Java.Type optionalQualification, String fieldName)
/*      */     {
/* 2556 */       super();
/* 2557 */       this.optionalQualification = optionalQualification;
/* 2558 */       this.fieldName = fieldName;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     public String toString()
/*      */     {
/* 2565 */       return (this.optionalQualification == null ? "super." : new StringBuffer().append(this.optionalQualification.toString()).append(".super.").toString()) + this.fieldName;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2572 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitSuperclassFieldAccessExpression(this); }
/* 2573 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitSuperclassFieldAccessExpression(this); }
/* 2574 */     public void accept(Visitor.LvalueVisitor visitor) { visitor.visitSuperclassFieldAccessExpression(this); }
/*      */     
/* 2576 */     Java.Rvalue value = null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class UnaryOperation
/*      */     extends Java.BooleanRvalue
/*      */   {
/*      */     public final String operator;
/*      */     
/*      */     public final Java.Rvalue operand;
/*      */     
/*      */ 
/*      */     public UnaryOperation(Location location, String operator, Java.Rvalue operand)
/*      */     {
/* 2591 */       super();
/* 2592 */       this.operator = operator;
/* 2593 */       this.operand = operand;
/*      */     }
/*      */     
/*      */ 
/* 2597 */     public String toString() { return this.operator + this.operand.toString(); }
/*      */     
/* 2599 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitUnaryOperation(this); }
/* 2600 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitUnaryOperation(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class Instanceof
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Rvalue lhs;
/*      */     public final Java.Type rhs;
/*      */     
/*      */     public Instanceof(Location location, Java.Rvalue lhs, Java.Type rhs)
/*      */     {
/* 2612 */       super();
/* 2613 */       this.lhs = lhs;
/* 2614 */       this.rhs = rhs;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2620 */     public String toString() { return this.lhs.toString() + " instanceof " + this.rhs.toString(); }
/*      */     
/* 2622 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitInstanceof(this); }
/* 2623 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitInstanceof(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class BinaryOperation
/*      */     extends Java.BooleanRvalue
/*      */   {
/*      */     public final Java.Rvalue lhs;
/*      */     
/*      */ 
/*      */ 
/*      */     public final String op;
/*      */     
/*      */ 
/*      */ 
/*      */     public final Java.Rvalue rhs;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     public BinaryOperation(Location location, Java.Rvalue lhs, String op, Java.Rvalue rhs)
/*      */     {
/* 2647 */       super();
/* 2648 */       this.lhs = lhs;
/* 2649 */       this.op = op;
/* 2650 */       this.rhs = rhs;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     public String toString()
/*      */     {
/* 2657 */       return this.lhs.toString() + ' ' + this.op + ' ' + this.rhs.toString();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     public Iterator unrollLeftAssociation()
/*      */     {
/* 2664 */       List operands = new ArrayList();
/* 2665 */       BinaryOperation x = this;
/*      */       for (;;) {
/* 2667 */         operands.add(x.rhs);
/* 2668 */         Java.Rvalue lhs = x.lhs;
/* 2669 */         if (((lhs instanceof BinaryOperation)) && (((BinaryOperation)lhs).op == this.op))
/*      */         {
/*      */ 
/*      */ 
/* 2673 */           x = (BinaryOperation)lhs;
/*      */         } else {
/* 2675 */           operands.add(lhs);
/* 2676 */           break;
/*      */         }
/*      */       }
/* 2679 */       return new ReverseListIterator(operands.listIterator(operands.size()));
/*      */     }
/*      */     
/* 2682 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitBinaryOperation(this); }
/* 2683 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitBinaryOperation(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class Cast
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Type targetType;
/*      */     public final Java.Rvalue value;
/*      */     
/*      */     public Cast(Location location, Java.Type targetType, Java.Rvalue value)
/*      */     {
/* 2695 */       super();
/* 2696 */       this.targetType = targetType;
/* 2697 */       this.value = value;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2703 */     public String toString() { return '(' + this.targetType.toString() + ") " + this.value.toString(); }
/*      */     
/* 2705 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitCast(this); }
/* 2706 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitCast(this); }
/*      */   }
/*      */   
/*      */   public static final class ParenthesizedExpression extends Java.Lvalue {
/*      */     public final Java.Rvalue value;
/*      */     
/*      */     public ParenthesizedExpression(Location location, Java.Rvalue value) {
/* 2713 */       super();
/* 2714 */       this.value = value;
/*      */     }
/*      */     
/*      */ 
/* 2718 */     public String toString() { return '(' + this.value.toString() + ')'; }
/*      */     
/* 2720 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitParenthesizedExpression(this); }
/* 2721 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitParenthesizedExpression(this); }
/* 2722 */     public void accept(Visitor.LvalueVisitor visitor) { visitor.visitParenthesizedExpression(this); }
/*      */   }
/*      */   
/*      */   public static abstract class ConstructorInvocation extends Java.Atom implements Java.BlockStatement {
/*      */     public final Java.Rvalue[] arguments;
/* 2727 */     private Java.Scope enclosingScope = null;
/*      */     
/*      */ 
/*      */ 
/*      */     protected ConstructorInvocation(Location location, Java.Rvalue[] arguments)
/*      */     {
/* 2733 */       super();
/* 2734 */       this.arguments = arguments;
/* 2735 */       for (int i = 0; i < arguments.length; i++) arguments[i].setEnclosingBlockStatement(this);
/*      */     }
/*      */     
/*      */     public void setEnclosingScope(Java.Scope enclosingScope)
/*      */     {
/* 2740 */       if ((this.enclosingScope != null) && (enclosingScope != null)) {
/* 2741 */         throw new JaninoRuntimeException("Enclosing scope is already set for statement \"" + toString() + "\" at " + getLocation());
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2748 */       this.enclosingScope = enclosingScope; }
/*      */     
/* 2750 */     public Java.Scope getEnclosingScope() { return this.enclosingScope; }
/*      */     
/*      */ 
/* 2753 */     public Map localVariables = null;
/*      */     
/* 2755 */     public Java.LocalVariable findLocalVariable(String name) { if (this.localVariables == null) return null;
/* 2756 */       return (Java.LocalVariable)this.localVariables.get(name);
/*      */     }
/*      */     
/*      */     public abstract void accept(Visitor.BlockStatementVisitor paramBlockStatementVisitor);
/*      */   }
/*      */   
/*      */   public static final class AlternateConstructorInvocation extends Java.ConstructorInvocation
/*      */   {
/*      */     public AlternateConstructorInvocation(Location location, Java.Rvalue[] arguments) {
/* 2765 */       super(arguments);
/*      */     }
/*      */     
/*      */ 
/* 2769 */     public String toString() { return "this()"; }
/*      */     
/* 2771 */     public void accept(Visitor.AtomVisitor visitor) { ((Visitor.BlockStatementVisitor)visitor).visitAlternateConstructorInvocation(this); }
/*      */     
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 2775 */       visitor.visitAlternateConstructorInvocation(this);
/*      */     }
/*      */   }
/*      */   
/*      */   public static final class SuperConstructorInvocation
/*      */     extends Java.ConstructorInvocation
/*      */   {
/*      */     public final Java.Rvalue optionalQualification;
/*      */     
/*      */     public SuperConstructorInvocation(Location location, Java.Rvalue optionalQualification, Java.Rvalue[] arguments)
/*      */     {
/* 2786 */       super(arguments);
/* 2787 */       this.optionalQualification = optionalQualification;
/* 2788 */       if (optionalQualification != null) { optionalQualification.setEnclosingBlockStatement(this);
/*      */       }
/*      */     }
/*      */     
/* 2792 */     public String toString() { return "super()"; }
/*      */     
/* 2794 */     public void accept(Visitor.AtomVisitor visitor) { ((Visitor.BlockStatementVisitor)visitor).visitSuperConstructorInvocation(this); }
/*      */     
/*      */     public void accept(Visitor.BlockStatementVisitor visitor)
/*      */     {
/* 2798 */       visitor.visitSuperConstructorInvocation(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class MethodInvocation
/*      */     extends Java.Invocation
/*      */   {
/*      */     public final Java.Atom optionalTarget;
/*      */     
/*      */     IClass.IMethod iMethod;
/*      */     
/*      */     public MethodInvocation(Location location, Java.Atom optionalTarget, String methodName, Java.Rvalue[] arguments)
/*      */     {
/* 2812 */       super(methodName, arguments);
/* 2813 */       this.optionalTarget = optionalTarget;
/*      */     }
/*      */     
/*      */ 
/*      */     public String toString()
/*      */     {
/* 2819 */       StringBuffer sb = new StringBuffer();
/* 2820 */       if (this.optionalTarget != null) sb.append(this.optionalTarget.toString()).append('.');
/* 2821 */       sb.append(this.methodName).append('(');
/* 2822 */       for (int i = 0; i < this.arguments.length; i++) {
/* 2823 */         if (i > 0) sb.append(", ");
/* 2824 */         sb.append(this.arguments[i].toString());
/*      */       }
/* 2826 */       sb.append(')');
/* 2827 */       return sb.toString();
/*      */     }
/*      */     
/* 2830 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitMethodInvocation(this); }
/* 2831 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitMethodInvocation(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class SuperclassMethodInvocation
/*      */     extends Java.Invocation
/*      */   {
/*      */     public SuperclassMethodInvocation(Location location, String methodName, Java.Rvalue[] arguments)
/*      */     {
/* 2840 */       super(methodName, arguments);
/*      */     }
/*      */     
/*      */ 
/* 2844 */     public String toString() { return "super." + this.methodName + "()"; }
/*      */     
/* 2846 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitSuperclassMethodInvocation(this); }
/* 2847 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitSuperclassMethodInvocation(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static abstract class Invocation
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Rvalue[] arguments;
/*      */     public final String methodName;
/*      */     
/*      */     protected Invocation(Location location, String methodName, Java.Rvalue[] arguments)
/*      */     {
/* 2859 */       super();
/* 2860 */       this.methodName = methodName;
/* 2861 */       this.arguments = arguments;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class NewClassInstance
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Rvalue optionalQualification;
/*      */     
/*      */     public final Java.Type type;
/*      */     public final Java.Rvalue[] arguments;
/*      */     
/*      */     public NewClassInstance(Location location, Java.Rvalue optionalQualification, Java.Type type, Java.Rvalue[] arguments)
/*      */     {
/* 2876 */       super();
/* 2877 */       this.optionalQualification = optionalQualification;
/* 2878 */       this.type = type;
/* 2879 */       this.arguments = arguments;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2884 */     protected IClass iClass = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public NewClassInstance(Location location, Java.Rvalue optionalQualification, IClass iClass, Java.Rvalue[] arguments)
/*      */     {
/* 2892 */       super();
/* 2893 */       this.optionalQualification = optionalQualification;
/* 2894 */       this.type = null;
/* 2895 */       this.arguments = arguments;
/* 2896 */       this.iClass = iClass;
/*      */     }
/*      */     
/*      */     public String toString()
/*      */     {
/* 2901 */       StringBuffer sb = new StringBuffer();
/* 2902 */       if (this.optionalQualification != null) sb.append(this.optionalQualification.toString()).append('.');
/* 2903 */       sb.append("new ");
/* 2904 */       if (this.type != null) {
/* 2905 */         sb.append(this.type.toString());
/*      */       }
/* 2907 */       else if (this.iClass != null) {
/* 2908 */         sb.append(this.iClass.toString());
/*      */       } else {
/* 2910 */         sb.append("???");
/*      */       }
/* 2912 */       sb.append('(');
/* 2913 */       for (int i = 0; i < this.arguments.length; i++) {
/* 2914 */         if (i > 0) sb.append(", ");
/* 2915 */         sb.append(this.arguments[i].toString());
/*      */       }
/* 2917 */       sb.append(')');
/* 2918 */       return sb.toString();
/*      */     }
/*      */     
/* 2921 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitNewClassInstance(this); }
/* 2922 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitNewClassInstance(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class NewAnonymousClassInstance
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Rvalue optionalQualification;
/*      */     
/*      */     public final Java.AnonymousClassDeclaration anonymousClassDeclaration;
/*      */     public final Java.Rvalue[] arguments;
/*      */     
/*      */     public NewAnonymousClassInstance(Location location, Java.Rvalue optionalQualification, Java.AnonymousClassDeclaration anonymousClassDeclaration, Java.Rvalue[] arguments)
/*      */     {
/* 2936 */       super();
/* 2937 */       this.optionalQualification = optionalQualification;
/* 2938 */       this.anonymousClassDeclaration = anonymousClassDeclaration;
/* 2939 */       this.arguments = arguments;
/*      */     }
/*      */     
/*      */     public String toString()
/*      */     {
/* 2944 */       StringBuffer sb = new StringBuffer();
/* 2945 */       if (this.optionalQualification != null) sb.append(this.optionalQualification.toString()).append('.');
/* 2946 */       sb.append("new ").append(this.anonymousClassDeclaration.baseType.toString()).append("() { ... }");
/* 2947 */       return sb.toString();
/*      */     }
/*      */     
/* 2950 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitNewAnonymousClassInstance(this); }
/* 2951 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitNewAnonymousClassInstance(this); }
/*      */   }
/*      */   
/*      */ 
/*      */   public static final class ParameterAccess
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.FunctionDeclarator.FormalParameter formalParameter;
/*      */     
/*      */     public ParameterAccess(Location location, Java.FunctionDeclarator.FormalParameter formalParameter)
/*      */     {
/* 2962 */       super();
/* 2963 */       this.formalParameter = formalParameter;
/*      */     }
/*      */     
/*      */ 
/* 2967 */     public String toString() { return this.formalParameter.name; }
/*      */     
/* 2969 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitParameterAccess(this); }
/* 2970 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitParameterAccess(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final class NewArray
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.Type type;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public final Java.Rvalue[] dimExprs;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public final int dims;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     public NewArray(Location location, Java.Type type, Java.Rvalue[] dimExprs, int dims)
/*      */     {
/* 3001 */       super();
/* 3002 */       this.type = type;
/* 3003 */       this.dimExprs = dimExprs;
/* 3004 */       this.dims = dims;
/*      */     }
/*      */     
/*      */ 
/* 3008 */     public String toString() { return "new " + this.type.toString() + "[]..."; }
/* 3009 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitNewArray(this); }
/*      */     
/*      */     public void accept(Visitor.RvalueVisitor visitor) {
/* 3012 */       visitor.visitNewArray(this);
/*      */     }
/*      */   }
/*      */   
/*      */   public static final class NewInitializedArray
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Java.ArrayType arrayType;
/*      */     public final Java.ArrayInitializer arrayInitializer;
/*      */     
/*      */     public NewInitializedArray(Location location, Java.ArrayType arrayType, Java.ArrayInitializer arrayInitializer)
/*      */     {
/* 3024 */       super();
/* 3025 */       this.arrayType = arrayType;
/* 3026 */       this.arrayInitializer = arrayInitializer;
/*      */     }
/*      */     
/*      */ 
/* 3030 */     public String toString() { return "new " + this.arrayType.toString() + " { ... }"; }
/* 3031 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitNewInitializedArray(this); }
/*      */     
/*      */     public void accept(Visitor.RvalueVisitor visitor) {
/* 3034 */       visitor.visitNewInitializedArray(this);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public static final class ArrayInitializer
/*      */     extends Java.Located
/*      */     implements Java.ArrayInitializerOrRvalue
/*      */   {
/*      */     public final Java.ArrayInitializerOrRvalue[] values;
/*      */     
/*      */ 
/*      */ 
/*      */     public ArrayInitializer(Location location, Java.ArrayInitializerOrRvalue[] values)
/*      */     {
/* 3050 */       super();
/* 3051 */       this.values = values;
/*      */     }
/*      */     
/* 3054 */     public String toString() { return " { (" + this.values.length + " values) }"; }
/*      */   }
/*      */   
/*      */ 
/*      */   public static abstract interface ArrayInitializerOrRvalue {}
/*      */   
/*      */ 
/*      */   public static final class Literal
/*      */     extends Java.Rvalue
/*      */   {
/*      */     public final Object value;
/*      */     
/*      */ 
/*      */     public Literal(Location location, Object value)
/*      */     {
/* 3069 */       super();
/* 3070 */       if ((!(value instanceof Integer)) && (!(value instanceof Long)) && (!(value instanceof Float)) && (!(value instanceof Double)) && (!(value instanceof String)) && (!(value instanceof Character)) && (!(value instanceof Boolean)) && (!(value instanceof Short)) && (!(value instanceof Byte)) && (value != null))
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3081 */         throw new IllegalArgumentException(value.getClass().getName()); }
/* 3082 */       this.value = value;
/*      */     }
/*      */     
/*      */ 
/* 3086 */     public String toString() { return Scanner.literalValueToString(this.value); }
/*      */     
/* 3088 */     public void accept(Visitor.AtomVisitor visitor) { visitor.visitLiteral(this); }
/* 3089 */     public void accept(Visitor.RvalueVisitor visitor) { visitor.visitLiteral(this); }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static class LocalVariableSlot
/*      */   {
/* 3099 */     private short slotIndex = -1;
/*      */     
/*      */     private String name;
/*      */     
/*      */     private IClass type;
/*      */     
/*      */     private CodeContext.Offset start;
/*      */     private CodeContext.Offset end;
/*      */     
/*      */     public LocalVariableSlot(String name, short slotNumber, IClass type)
/*      */     {
/* 3110 */       this.name = name;
/* 3111 */       this.slotIndex = slotNumber;
/* 3112 */       this.type = type;
/*      */     }
/*      */     
/*      */     public String toString() {
/* 3116 */       StringBuffer buf = new StringBuffer("local var(");
/*      */       
/* 3118 */       buf.append(this.name);
/* 3119 */       buf.append(", ").append(this.slotIndex);
/* 3120 */       if (this.name != null) {
/* 3121 */         buf.append(", ").append(this.type);
/* 3122 */         buf.append(", ").append(this.start.offset);
/* 3123 */         buf.append(", ").append(this.end.offset);
/*      */       }
/* 3125 */       buf.append(")");
/*      */       
/* 3127 */       return buf.toString();
/*      */     }
/*      */     
/* 3130 */     public short getSlotIndex() { return this.slotIndex; }
/* 3131 */     public void setSlotIndex(short slotIndex) { this.slotIndex = slotIndex; }
/*      */     
/* 3133 */     public String getName() { return this.name; }
/* 3134 */     public void setName(String name) { this.name = name; }
/*      */     
/* 3136 */     public CodeContext.Offset getStart() { return this.start; }
/* 3137 */     public void setStart(CodeContext.Offset start) { this.start = start; }
/*      */     
/* 3139 */     public CodeContext.Offset getEnd() { return this.end; }
/* 3140 */     public void setEnd(CodeContext.Offset end) { this.end = end; }
/*      */     
/* 3142 */     public IClass getType() { return this.type; }
/*      */   }
/*      */   
/*      */ 
/*      */   public static class LocalVariable
/*      */   {
/*      */     public final boolean finaL;
/*      */     
/*      */     public final IClass type;
/*      */     
/*      */     public Java.LocalVariableSlot slot;
/*      */     
/*      */ 
/*      */     public LocalVariable(boolean finaL, IClass type)
/*      */     {
/* 3157 */       this.finaL = finaL;
/* 3158 */       this.type = type;
/*      */     }
/*      */     
/*      */     public String toString() {
/* 3162 */       StringBuffer sb = new StringBuffer();
/*      */       
/* 3164 */       if (this.finaL) sb.append("final ");
/* 3165 */       sb.append(this.type).append(" ");
/*      */       
/* 3167 */       return sb.toString();
/*      */     }
/*      */     
/* 3170 */     public void setSlot(Java.LocalVariableSlot slot) { this.slot = slot; }
/*      */     
/*      */     public short getSlotIndex() {
/* 3173 */       if (this.slot == null) return -1;
/* 3174 */       return this.slot.getSlotIndex();
/*      */     }
/*      */   }
/*      */   
/*      */   public static String join(Object[] a, String separator) {
/* 3179 */     return join(a, separator, 0, a.length);
/*      */   }
/*      */   
/*      */   public static String join(Object[] a, String separator, int off, int len) {
/* 3183 */     if (a == null) return "(null)";
/* 3184 */     if (off >= len) return "";
/* 3185 */     StringBuffer sb = new StringBuffer(a[off].toString());
/* 3186 */     for (off++; off < len; off++) {
/* 3187 */       sb.append(separator);
/* 3188 */       sb.append(a[off]);
/*      */     }
/* 3190 */     return sb.toString();
/*      */   }
/*      */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\codehaus\janino\Java.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       0.7.1
 */