package prefuse.controls;

import java.awt.Cursor;
import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.geom.AffineTransform;
import javax.swing.SwingUtilities;
import prefuse.Display;
import prefuse.activity.Activity;
import prefuse.activity.SlowInSlowOutPacer;

public class ZoomingPanControl
  extends ControlAdapter
{
  private boolean repaint = true;
  private boolean started = false;
  private Point mouseDown;
  private Point mouseCur;
  private Point mouseUp;
  private int dx;
  private int dy;
  private double d = 0.0D;
  private double v0 = 75.0D;
  private double d0 = 50.0D;
  private double d1 = 400.0D;
  private double s0 = 0.1D;
  private UpdateActivity update = new UpdateActivity();
  private FinishActivity finish = new FinishActivity();
  
  public ZoomingPanControl()
  {
    this(true);
  }
  
  public ZoomingPanControl(boolean paramBoolean)
  {
    this.repaint = paramBoolean;
  }
  
  public void mousePressed(MouseEvent paramMouseEvent)
  {
    if (SwingUtilities.isLeftMouseButton(paramMouseEvent))
    {
      Display localDisplay = (Display)paramMouseEvent.getComponent();
      localDisplay.setCursor(Cursor.getPredefinedCursor(13));
      this.mouseDown = paramMouseEvent.getPoint();
    }
  }
  
  public void mouseDragged(MouseEvent paramMouseEvent)
  {
    if (SwingUtilities.isLeftMouseButton(paramMouseEvent))
    {
      this.mouseCur = paramMouseEvent.getPoint();
      this.dx = (this.mouseCur.x - this.mouseDown.x);
      this.dy = (this.mouseCur.y - this.mouseDown.y);
      this.d = Math.sqrt(this.dx * this.dx + this.dy * this.dy);
      if (!this.started)
      {
        Display localDisplay = (Display)paramMouseEvent.getComponent();
        this.update.setDisplay(localDisplay);
        this.update.run();
      }
    }
  }
  
  public void mouseReleased(MouseEvent paramMouseEvent)
  {
    if (SwingUtilities.isLeftMouseButton(paramMouseEvent))
    {
      this.update.cancel();
      this.started = false;
      Display localDisplay = (Display)paramMouseEvent.getComponent();
      this.mouseUp = paramMouseEvent.getPoint();
      this.finish.setDisplay(localDisplay);
      this.finish.run();
      localDisplay.setCursor(Cursor.getDefaultCursor());
    }
  }
  
  private class FinishActivity
    extends Activity
  {
    private Display display;
    private double scale;
    
    public FinishActivity()
    {
      super(15L, 0L);
      setPacingFunction(new SlowInSlowOutPacer());
    }
    
    public void setDisplay(Display paramDisplay)
    {
      this.display = paramDisplay;
      this.scale = paramDisplay.getTransform().getScaleX();
      double d = this.scale < 1.0D ? 1.0D / this.scale : this.scale;
      setDuration((500.0D + 500.0D * Math.log(1.0D + d)));
    }
    
    protected void run(long paramLong)
    {
      double d1 = getPace(paramLong);
      double d2 = this.display.getTransform().getScaleX();
      double d3 = (d1 + (1.0D - d1) * this.scale) / d2;
      this.display.zoom(ZoomingPanControl.this.mouseUp, d3);
      if (ZoomingPanControl.this.repaint) {
        this.display.repaint();
      }
    }
  }
  
  private class UpdateActivity
    extends Activity
  {
    private Display display;
    private long lastTime = 0L;
    
    public UpdateActivity()
    {
      super(15L, 0L);
    }
    
    public void setDisplay(Display paramDisplay)
    {
      this.display = paramDisplay;
    }
    
    protected void run(long paramLong)
    {
      double d1 = this.display.getTransform().getScaleX();
      double d2;
      double d3;
      if (ZoomingPanControl.this.d <= ZoomingPanControl.this.d0)
      {
        d2 = 1.0D;
        d3 = ZoomingPanControl.this.v0 * (ZoomingPanControl.this.d / ZoomingPanControl.this.d0);
      }
      else
      {
        d2 = ZoomingPanControl.this.d >= ZoomingPanControl.this.d1 ? ZoomingPanControl.this.s0 : Math.pow(ZoomingPanControl.this.s0, (ZoomingPanControl.this.d - ZoomingPanControl.this.d0) / (ZoomingPanControl.this.d1 - ZoomingPanControl.this.d0));
        d3 = ZoomingPanControl.this.v0;
      }
      d2 /= d1;
      double d4 = d3 * (paramLong - this.lastTime) / 1000.0D;
      this.lastTime = paramLong;
      double d5 = -d4 * ZoomingPanControl.this.dx / ZoomingPanControl.this.d;
      double d6 = -d4 * ZoomingPanControl.this.dy / ZoomingPanControl.this.d;
      this.display.pan(d5, d6);
      if (d2 != 1.0D) {
        this.display.zoom(ZoomingPanControl.this.mouseCur, d2);
      }
      if (ZoomingPanControl.this.repaint) {
        this.display.repaint();
      }
    }
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\controls\ZoomingPanControl.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */