package prefuse.data.query;

import javax.swing.DefaultBoundedRangeModel;
import prefuse.util.TypeLib;
import prefuse.util.ui.ValuedRangeModel;

public class NumberRangeModel
  extends DefaultBoundedRangeModel
  implements ValuedRangeModel
{
  protected Class m_type;
  protected Number m_min;
  protected Number m_max;
  protected Number m_lo;
  protected Number m_hi;
  
  public NumberRangeModel(int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    this(new Integer(paramInt1), new Integer(paramInt2), new Integer(paramInt3), new Integer(paramInt2));
  }
  
  public NumberRangeModel(long paramLong1, long paramLong2, long paramLong3, long paramLong4)
  {
    this(new Long(paramLong1), new Long(paramLong2), new Long(paramLong3), new Long(paramLong4));
  }
  
  public NumberRangeModel(float paramFloat1, float paramFloat2, float paramFloat3, float paramFloat4)
  {
    this(new Float(paramFloat1), new Float(paramFloat2), new Float(paramFloat3), new Float(paramFloat4));
  }
  
  public NumberRangeModel(double paramDouble1, double paramDouble2, double paramDouble3, double paramDouble4)
  {
    this(new Double(paramDouble1), new Double(paramDouble2), new Double(paramDouble3), new Double(paramDouble4));
  }
  
  public NumberRangeModel(Number paramNumber1, Number paramNumber2, Number paramNumber3, Number paramNumber4)
  {
    this.m_type = TypeLib.getPrimitiveType(paramNumber3.getClass());
    setValueRange(paramNumber1, paramNumber2, paramNumber3, paramNumber4);
  }
  
  protected void updateRange()
  {
    if (this.m_type == Integer.TYPE)
    {
      setRange(this.m_lo.intValue(), this.m_hi.intValue() - this.m_lo.intValue(), this.m_min.intValue(), this.m_max.intValue());
    }
    else
    {
      int i;
      int j;
      if (this.m_type == Long.TYPE)
      {
        i = 10000 * (int)((this.m_lo.longValue() - this.m_min.longValue()) / (this.m_max.longValue() - this.m_min.longValue()));
        j = 10000 * (int)((this.m_hi.longValue() - this.m_min.longValue()) / (this.m_max.longValue() - this.m_min.longValue())) - i;
        setRange(i, j, 0, 10000);
      }
      else
      {
        i = 10000 * (int)((this.m_lo.doubleValue() - this.m_min.doubleValue()) / (this.m_max.doubleValue() - this.m_min.doubleValue()));
        j = 10000 * (int)((this.m_hi.doubleValue() - this.m_min.doubleValue()) / (this.m_max.doubleValue() - this.m_min.doubleValue())) - i;
        setRange(i, j, 0, 10000);
      }
    }
  }
  
  protected void setRange(int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    super.setRangeProperties(paramInt1, paramInt2, paramInt3, paramInt4, false);
  }
  
  public void setRangeProperties(int paramInt1, int paramInt2, int paramInt3, int paramInt4, boolean paramBoolean)
  {
    if ((paramInt3 != getMinimum()) || (paramInt4 != getMaximum())) {
      throw new IllegalArgumentException("Can not change min or max.");
    }
    this.m_lo = null;
    this.m_hi = null;
    super.setRangeProperties(paramInt1, paramInt2, paramInt3, paramInt4, paramBoolean);
  }
  
  public void setValueRange(Number paramNumber1, Number paramNumber2, Number paramNumber3, Number paramNumber4)
  {
    this.m_lo = paramNumber1;
    this.m_hi = paramNumber2;
    this.m_min = paramNumber3;
    this.m_max = paramNumber4;
    updateRange();
  }
  
  public void setValueRange(double paramDouble1, double paramDouble2, double paramDouble3, double paramDouble4)
  {
    this.m_lo = new Double(paramDouble1);
    this.m_hi = new Double(paramDouble2);
    this.m_min = new Double(paramDouble3);
    this.m_max = new Double(paramDouble4);
    updateRange();
  }
  
  public void setValueRange(int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    this.m_lo = new Integer(paramInt1);
    this.m_hi = new Integer(paramInt2);
    this.m_min = new Integer(paramInt3);
    this.m_max = new Integer(paramInt4);
    updateRange();
  }
  
  public void setValueRange(long paramLong1, long paramLong2, long paramLong3, long paramLong4)
  {
    this.m_lo = new Long(paramLong1);
    this.m_hi = new Long(paramLong2);
    this.m_min = new Long(paramLong3);
    this.m_max = new Long(paramLong4);
    updateRange();
  }
  
  public Object getMinValue()
  {
    return this.m_min;
  }
  
  public void setMinValue(Number paramNumber)
  {
    setValueRange((Number)getLowValue(), (Number)getHighValue(), paramNumber, this.m_max);
  }
  
  public Object getMaxValue()
  {
    return this.m_max;
  }
  
  public void setMaxValue(Number paramNumber)
  {
    setValueRange((Number)getLowValue(), (Number)getHighValue(), this.m_min, paramNumber);
  }
  
  public Object getLowValue()
  {
    if (this.m_lo == null) {
      this.m_lo = ((Number)value(getValue()));
    }
    return this.m_lo;
  }
  
  public void setLowValue(Number paramNumber)
  {
    setValueRange(paramNumber, (Number)getHighValue(), this.m_min, this.m_max);
  }
  
  public Object getHighValue()
  {
    if (this.m_hi == null) {
      this.m_hi = ((Number)value(getValue() + getExtent()));
    }
    return this.m_hi;
  }
  
  public void setHighValue(Number paramNumber)
  {
    setValueRange((Number)getLowValue(), paramNumber, this.m_min, this.m_max);
  }
  
  protected Object value(int paramInt)
  {
    int i = getMinimum();
    int j = getMaximum();
    if ((this.m_type == Double.TYPE) || (this.m_type == Float.TYPE))
    {
      double d1 = (paramInt - i) / (j - i);
      double d2 = this.m_min.doubleValue();
      double d3 = d2 + d1 * (this.m_max.doubleValue() - d2);
      return this.m_type == Float.TYPE ? new Float((float)d3) : new Double(d3);
    }
    if (this.m_type == Long.TYPE)
    {
      long l1 = this.m_min.longValue();
      long l2 = l1 + (paramInt - i) * (this.m_max.longValue() - l1) / (j - i);
      return new Long(l2);
    }
    return new Integer(paramInt);
  }
  
  public void setMinimum(int paramInt)
  {
    throw new UnsupportedOperationException();
  }
  
  public void setMaximum(int paramInt)
  {
    throw new UnsupportedOperationException();
  }
  
  public void setValue(int paramInt)
  {
    this.m_lo = null;
    super.setValue(paramInt);
  }
  
  public void setExtent(int paramInt)
  {
    this.m_hi = null;
    super.setExtent(paramInt);
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\data\query\NumberRangeModel.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */