package prefuse.data.search;

import java.io.IOException;
import java.util.HashMap;
import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.index.IndexReader;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.queryParser.MultiFieldQueryParser;
import org.apache.lucene.queryParser.ParseException;
import org.apache.lucene.queryParser.QueryParser;
import org.apache.lucene.search.Hits;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.search.Query;
import org.apache.lucene.search.Searcher;
import org.apache.lucene.store.Directory;
import org.apache.lucene.store.RAMDirectory;

public class LuceneSearcher
{
  public static final String FIELD = "prefuse-text";
  public static final String ID = "prefuse-id";
  private Directory directory;
  private Analyzer analyzer;
  private String[] fields;
  private Searcher searcher;
  private IndexReader reader;
  private IndexWriter writer;
  private boolean m_readMode = true;
  private boolean m_readOnly = false;
  private HashMap m_hitCountCache = new HashMap();
  
  public LuceneSearcher()
  {
    this(new RAMDirectory(), "prefuse-text", false);
  }
  
  public LuceneSearcher(Directory paramDirectory)
  {
    this(paramDirectory, "prefuse-text", false);
  }
  
  public LuceneSearcher(Directory paramDirectory, String paramString, boolean paramBoolean)
  {
    this(paramDirectory, new String[] { paramString }, paramBoolean);
  }
  
  public LuceneSearcher(Directory paramDirectory, String[] paramArrayOfString, boolean paramBoolean)
  {
    this.directory = paramDirectory;
    this.analyzer = new StandardAnalyzer();
    this.fields = ((String[])paramArrayOfString.clone());
    try
    {
      this.writer = new IndexWriter(this.directory, this.analyzer, !paramBoolean);
      this.writer.close();
      this.writer = null;
    }
    catch (IOException localIOException)
    {
      localIOException.printStackTrace();
    }
    this.m_readOnly = paramBoolean;
    if (!paramBoolean)
    {
      setReadMode(false);
    }
    else
    {
      this.m_readMode = false;
      setReadMode(true);
    }
  }
  
  public boolean setReadMode(boolean paramBoolean)
  {
    if ((this.m_readOnly) && (!paramBoolean)) {
      return false;
    }
    if (this.m_readMode == paramBoolean) {
      return true;
    }
    if (!paramBoolean)
    {
      try
      {
        if (this.searcher != null) {
          this.searcher.close();
        }
        if (this.reader != null) {
          this.reader.close();
        }
      }
      catch (Exception localException1)
      {
        localException1.printStackTrace();
        return false;
      }
      try
      {
        this.writer = new IndexWriter(this.directory, this.analyzer, false);
      }
      catch (IOException localIOException1)
      {
        localIOException1.printStackTrace();
        return false;
      }
    }
    else
    {
      try
      {
        if (this.writer != null)
        {
          this.writer.optimize();
          this.writer.close();
        }
      }
      catch (IOException localIOException2)
      {
        localIOException2.printStackTrace();
        return false;
      }
      try
      {
        this.reader = IndexReader.open(this.directory);
        this.searcher = new IndexSearcher(this.reader);
      }
      catch (Exception localException2)
      {
        localException2.printStackTrace();
        return false;
      }
    }
    this.m_readMode = paramBoolean;
    return true;
  }
  
  public Hits search(String paramString)
    throws ParseException, IOException
  {
    if (this.m_readMode)
    {
      Query localQuery;
      if (this.fields.length == 1) {
        localQuery = QueryParser.parse(paramString, this.fields[0], this.analyzer);
      } else {
        localQuery = MultiFieldQueryParser.parse(paramString, this.fields, this.analyzer);
      }
      return this.searcher.search(localQuery);
    }
    throw new IllegalStateException("Searches can only be performed when the LuceneSearcher is in read mode");
  }
  
  public int numHits(String paramString)
    throws ParseException, IOException
  {
    Integer localInteger;
    if ((localInteger = (Integer)this.m_hitCountCache.get(paramString)) == null)
    {
      Hits localHits = search(paramString);
      localInteger = new Integer(localHits.length());
      this.m_hitCountCache.put(paramString, localInteger);
    }
    return localInteger.intValue();
  }
  
  public void addDocument(Document paramDocument)
  {
    if (!this.m_readMode) {
      try
      {
        this.writer.addDocument(paramDocument);
        this.m_hitCountCache.clear();
      }
      catch (IOException localIOException)
      {
        localIOException.printStackTrace();
      }
    } else {
      throw new IllegalStateException("Documents can not be added to the index unlessthe LuceneSearcher is not in read mode");
    }
  }
  
  public Analyzer getAnalyzer()
  {
    return this.analyzer;
  }
  
  public void setAnalyzer(Analyzer paramAnalyzer)
  {
    this.analyzer = paramAnalyzer;
  }
  
  public String[] getFields()
  {
    return (String[])this.fields.clone();
  }
  
  public void setFields(String[] paramArrayOfString)
  {
    this.fields = ((String[])paramArrayOfString.clone());
  }
  
  public IndexReader getIndexReader()
  {
    return this.reader;
  }
  
  public Searcher getIndexSearcher()
  {
    return this.searcher;
  }
  
  public boolean isReadOnly()
  {
    return this.m_readOnly;
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\data\search\LuceneSearcher.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */