package prefuse.util.collections;

import java.util.Comparator;
import prefuse.data.DataTypeException;

public class SortedMapFactory
{
  public static IntSortedMap getMap(Class paramClass, Comparator paramComparator, boolean paramBoolean)
    throws IncompatibleComparatorException
  {
    if (!comparatorCheck(paramClass, paramComparator)) {
      throw new IncompatibleComparatorException();
    }
    if (paramClass.equals(Integer.TYPE)) {
      return new IntIntTreeMap((LiteralComparator)paramComparator, !paramBoolean);
    }
    if (paramClass.equals(Long.TYPE)) {
      return new LongIntTreeMap((LiteralComparator)paramComparator, !paramBoolean);
    }
    if (paramClass.equals(Float.TYPE)) {
      return new FloatIntTreeMap((LiteralComparator)paramComparator, !paramBoolean);
    }
    if (paramClass.equals(Double.TYPE)) {
      return new DoubleIntTreeMap((LiteralComparator)paramComparator, !paramBoolean);
    }
    if (paramClass.equals(Boolean.TYPE)) {
      return new BooleanIntBitSetMap();
    }
    if (Object.class.isAssignableFrom(paramClass)) {
      return new ObjectIntTreeMap(paramComparator, !paramBoolean);
    }
    throw new DataTypeException("No map available for the provided type");
  }
  
  public static boolean comparatorCheck(Class paramClass, Comparator paramComparator)
  {
    if (paramComparator == null) {
      return true;
    }
    if (paramClass.equals(Integer.TYPE))
    {
      if (!(paramComparator instanceof LiteralIterator)) {
        return false;
      }
      try
      {
        ((LiteralComparator)paramComparator).compare(0, 0);
        return true;
      }
      catch (Exception localException1)
      {
        return false;
      }
    }
    if (paramClass.equals(Long.TYPE))
    {
      if (!(paramComparator instanceof LiteralIterator)) {
        return false;
      }
      try
      {
        ((LiteralComparator)paramComparator).compare(0L, 0L);
        return true;
      }
      catch (Exception localException2)
      {
        return false;
      }
    }
    if (paramClass.equals(Float.TYPE))
    {
      if (!(paramComparator instanceof LiteralIterator)) {
        return false;
      }
      try
      {
        ((LiteralComparator)paramComparator).compare(0.0F, 0.0F);
        return true;
      }
      catch (Exception localException3)
      {
        return false;
      }
    }
    if (paramClass.equals(Double.TYPE))
    {
      if (!(paramComparator instanceof LiteralIterator)) {
        return false;
      }
      try
      {
        ((LiteralComparator)paramComparator).compare(0.0D, 0.0D);
        return true;
      }
      catch (Exception localException4)
      {
        return false;
      }
    }
    if (paramClass.equals(Boolean.TYPE))
    {
      if (!(paramComparator instanceof LiteralIterator)) {
        return false;
      }
      try
      {
        ((LiteralComparator)paramComparator).compare(false, false);
        return true;
      }
      catch (Exception localException5)
      {
        return false;
      }
    }
    if (Object.class.isAssignableFrom(paramClass)) {
      return true;
    }
    throw new DataTypeException("No comparator available for the provided type");
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\util\collections\SortedMapFactory.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */